Module: Google::Apis::DatastreamV1
- Defined in:
- lib/google/apis/datastream_v1.rb,
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/service.rb,
lib/google/apis/datastream_v1/gem_version.rb,
lib/google/apis/datastream_v1/representations.rb
Overview
Datastream API
Defined Under Namespace
Classes: AppendOnly, AvroFileFormat, BackfillAllStrategy, BackfillJob, BackfillNoneStrategy, BasicEncryption, BigQueryClustering, BigQueryDestinationConfig, BigQueryPartitioning, BigQueryProfile, BinaryLogParser, BinaryLogPosition, BlmtConfig, CancelOperationRequest, CdcStrategy, ConnectionProfile, CustomizationRule, DatasetTemplate, DatastreamService, DestinationConfig, DiscoverConnectionProfileRequest, DiscoverConnectionProfileResponse, DropLargeObjects, Empty, EncryptionAndServerValidation, EncryptionNotEnforced, Error, EventFilter, FetchStaticIpsResponse, ForwardSshTunnelConnectivity, GcsDestinationConfig, GcsProfile, Gtid, HostAddress, IngestionTimePartition, IntegerRangePartition, JsonFileFormat, ListConnectionProfilesResponse, ListLocationsResponse, ListOperationsResponse, ListPrivateConnectionsResponse, ListRoutesResponse, ListStreamObjectsResponse, ListStreamsResponse, Location, LogFileDirectories, LogMiner, LookupStreamObjectRequest, Merge, MongodbChangeStreamPosition, MongodbCluster, MongodbCollection, MongodbDatabase, MongodbField, MongodbObjectIdentifier, MongodbProfile, MongodbSourceConfig, MongodbSslConfig, MostRecentStartPosition, MysqlColumn, MysqlDatabase, MysqlGtidPosition, MysqlLogPosition, MysqlObjectIdentifier, MysqlProfile, MysqlRdbms, MysqlSourceConfig, MysqlSslConfig, MysqlTable, NextAvailableStartPosition, Oauth2ClientCredentials, ObjectFilter, Operation, OperationMetadata, OracleAsmConfig, OracleAsmLogFileAccess, OracleColumn, OracleObjectIdentifier, OracleProfile, OracleRdbms, OracleSchema, OracleScnPosition, OracleSourceConfig, OracleSslConfig, OracleTable, PostgresqlColumn, PostgresqlObjectIdentifier, PostgresqlProfile, PostgresqlRdbms, PostgresqlSchema, PostgresqlSourceConfig, PostgresqlSslConfig, PostgresqlTable, PrivateConnection, PrivateConnectivity, PscInterfaceConfig, Route, RuleSet, RunStreamRequest, SalesforceField, SalesforceObject, SalesforceObjectIdentifier, SalesforceOrg, SalesforceProfile, SalesforceSourceConfig, ServerAndClientVerification, ServerVerification, SingleTargetDataset, SourceConfig, SourceHierarchyDatasets, SourceObjectIdentifier, SpecificStartPosition, SqlServerChangeTables, SqlServerColumn, SqlServerLsnPosition, SqlServerObjectIdentifier, SqlServerProfile, SqlServerRdbms, SqlServerSchema, SqlServerSourceConfig, SqlServerSslConfig, SqlServerTable, SqlServerTransactionLogs, SrvConnectionFormat, StandardConnectionFormat, StartBackfillJobRequest, StartBackfillJobResponse, StaticServiceIpConnectivity, Status, StopBackfillJobRequest, StopBackfillJobResponse, Stream, StreamLargeObjects, StreamObject, TimeUnitPartition, UserCredentials, Validation, ValidationMessage, ValidationResult, VpcPeeringConfig
Constant Summary collapse
- GEM_VERSION =
Version of the google-apis-datastream_v1 gem
"0.61.0"- GENERATOR_VERSION =
Version of the code generator used to generate this client
"0.18.0"- REVISION =
Revision of the discovery document this client was generated from
"20251231"- VERSION =
Version of the Datastream API this client connects to. This is NOT the gem version.
'V1'- AUTH_CLOUD_PLATFORM =
See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.
'https://www.googleapis.com/auth/cloud-platform'