Class: Google::Apis::DatastreamV1::BackfillJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

Represents a backfill job on a specific stream object.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackfillJob

Returns a new instance of BackfillJob.



148
149
150
# File 'lib/google/apis/datastream_v1/classes.rb', line 148

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorsArray<Google::Apis::DatastreamV1::Error>

Output only. Errors which caused the backfill job to fail. Corresponds to the JSON property errors



121
122
123
# File 'lib/google/apis/datastream_v1/classes.rb', line 121

def errors
  @errors
end

#event_filterGoogle::Apis::DatastreamV1::EventFilter

Represents a filter for included data on a stream object. Corresponds to the JSON property eventFilter



126
127
128
# File 'lib/google/apis/datastream_v1/classes.rb', line 126

def event_filter
  @event_filter
end

#last_end_timeString

Output only. Backfill job's end time. Corresponds to the JSON property lastEndTime

Returns:

  • (String)


131
132
133
# File 'lib/google/apis/datastream_v1/classes.rb', line 131

def last_end_time
  @last_end_time
end

#last_start_timeString

Output only. Backfill job's start time. Corresponds to the JSON property lastStartTime

Returns:

  • (String)


136
137
138
# File 'lib/google/apis/datastream_v1/classes.rb', line 136

def last_start_time
  @last_start_time
end

#stateString

Output only. Backfill job state. Corresponds to the JSON property state

Returns:

  • (String)


141
142
143
# File 'lib/google/apis/datastream_v1/classes.rb', line 141

def state
  @state
end

#triggerString

Backfill job's triggering reason. Corresponds to the JSON property trigger

Returns:

  • (String)


146
147
148
# File 'lib/google/apis/datastream_v1/classes.rb', line 146

def trigger
  @trigger
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



153
154
155
156
157
158
159
160
# File 'lib/google/apis/datastream_v1/classes.rb', line 153

def update!(**args)
  @errors = args[:errors] if args.key?(:errors)
  @event_filter = args[:event_filter] if args.key?(:event_filter)
  @last_end_time = args[:last_end_time] if args.key?(:last_end_time)
  @last_start_time = args[:last_start_time] if args.key?(:last_start_time)
  @state = args[:state] if args.key?(:state)
  @trigger = args[:trigger] if args.key?(:trigger)
end