Class: Google::Apis::DatastreamV1::BinaryLogParser
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1::BinaryLogParser
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb
Overview
Configuration to use Binary Log Parser CDC technique.
Instance Attribute Summary collapse
-
#log_file_directories ⇒ Google::Apis::DatastreamV1::LogFileDirectories
Configuration to specify the Oracle directories to access the log files.
-
#oracle_asm_log_file_access ⇒ Google::Apis::DatastreamV1::OracleAsmLogFileAccess
Configuration to use Oracle ASM to access the log files.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BinaryLogParser
constructor
A new instance of BinaryLogParser.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BinaryLogParser
Returns a new instance of BinaryLogParser.
341 342 343 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 341 def initialize(**args) update!(**args) end |
Instance Attribute Details
#log_file_directories ⇒ Google::Apis::DatastreamV1::LogFileDirectories
Configuration to specify the Oracle directories to access the log files.
Corresponds to the JSON property logFileDirectories
334 335 336 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 334 def log_file_directories @log_file_directories end |
#oracle_asm_log_file_access ⇒ Google::Apis::DatastreamV1::OracleAsmLogFileAccess
Configuration to use Oracle ASM to access the log files.
Corresponds to the JSON property oracleAsmLogFileAccess
339 340 341 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 339 def oracle_asm_log_file_access @oracle_asm_log_file_access end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
346 347 348 349 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 346 def update!(**args) @log_file_directories = args[:log_file_directories] if args.key?(:log_file_directories) @oracle_asm_log_file_access = args[:oracle_asm_log_file_access] if args.key?(:oracle_asm_log_file_access) end |