Class: Google::Apis::DatastreamV1::CdcStrategy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

The strategy that the stream uses for CDC replication.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CdcStrategy

Returns a new instance of CdcStrategy.



415
416
417
# File 'lib/google/apis/datastream_v1/classes.rb', line 415

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#most_recent_start_positionGoogle::Apis::DatastreamV1::MostRecentStartPosition

CDC strategy to start replicating from the most recent position in the source. Corresponds to the JSON property mostRecentStartPosition



402
403
404
# File 'lib/google/apis/datastream_v1/classes.rb', line 402

def most_recent_start_position
  @most_recent_start_position
end

#next_available_start_positionGoogle::Apis::DatastreamV1::NextAvailableStartPosition

CDC strategy to resume replication from the next available position in the source. Corresponds to the JSON property nextAvailableStartPosition



408
409
410
# File 'lib/google/apis/datastream_v1/classes.rb', line 408

def next_available_start_position
  @next_available_start_position
end

#specific_start_positionGoogle::Apis::DatastreamV1::SpecificStartPosition

CDC strategy to start replicating from a specific position in the source. Corresponds to the JSON property specificStartPosition



413
414
415
# File 'lib/google/apis/datastream_v1/classes.rb', line 413

def specific_start_position
  @specific_start_position
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



420
421
422
423
424
# File 'lib/google/apis/datastream_v1/classes.rb', line 420

def update!(**args)
  @most_recent_start_position = args[:most_recent_start_position] if args.key?(:most_recent_start_position)
  @next_available_start_position = args[:next_available_start_position] if args.key?(:next_available_start_position)
  @specific_start_position = args[:specific_start_position] if args.key?(:specific_start_position)
end