Class: Google::Apis::DatastreamV1::DatasetTemplate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

Dataset template used for dynamic dataset creation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DatasetTemplate

Returns a new instance of DatasetTemplate.



672
673
674
# File 'lib/google/apis/datastream_v1/classes.rb', line 672

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataset_id_prefixString

If supplied, every created dataset will have its name prefixed by the provided value. The prefix and name will be separated by an underscore. i.e. _. Corresponds to the JSON property datasetIdPrefix

Returns:

  • (String)


654
655
656
# File 'lib/google/apis/datastream_v1/classes.rb', line 654

def dataset_id_prefix
  @dataset_id_prefix
end

#kms_key_nameString

Describes the Cloud KMS encryption key that will be used to protect destination BigQuery table. The BigQuery Service Account associated with your project requires access to this encryption key. i.e. projects/project/ locations/location/keyRings/key_ring/cryptoKeys/cryptoKey. See https:// cloud.google.com/bigquery/docs/customer-managed-encryption for more information. Corresponds to the JSON property kmsKeyName

Returns:

  • (String)


664
665
666
# File 'lib/google/apis/datastream_v1/classes.rb', line 664

def kms_key_name
  @kms_key_name
end

#locationString

Required. The geographic location where the dataset should reside. See https:// cloud.google.com/bigquery/docs/locations for supported locations. Corresponds to the JSON property location

Returns:

  • (String)


670
671
672
# File 'lib/google/apis/datastream_v1/classes.rb', line 670

def location
  @location
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



677
678
679
680
681
# File 'lib/google/apis/datastream_v1/classes.rb', line 677

def update!(**args)
  @dataset_id_prefix = args[:dataset_id_prefix] if args.key?(:dataset_id_prefix)
  @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name)
  @location = args[:location] if args.key?(:location)
end