Class: Google::Apis::DatastreamV1::DiscoverConnectionProfileRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

Request message for 'discover' ConnectionProfile request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiscoverConnectionProfileRequest

Returns a new instance of DiscoverConnectionProfileRequest.



874
875
876
# File 'lib/google/apis/datastream_v1/classes.rb', line 874

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connection_profileGoogle::Apis::DatastreamV1::ConnectionProfile

A set of reusable connection configurations to be used as a source or destination for a stream. Corresponds to the JSON property connectionProfile



814
815
816
# File 'lib/google/apis/datastream_v1/classes.rb', line 814

def connection_profile
  @connection_profile
end

#connection_profile_nameString

Optional. A reference to an existing connection profile. Corresponds to the JSON property connectionProfileName

Returns:

  • (String)


819
820
821
# File 'lib/google/apis/datastream_v1/classes.rb', line 819

def connection_profile_name
  @connection_profile_name
end

#full_hierarchyBoolean Also known as: full_hierarchy?

Optional. Whether to retrieve the full hierarchy of data objects (TRUE) or only the current level (FALSE). Corresponds to the JSON property fullHierarchy

Returns:

  • (Boolean)


825
826
827
# File 'lib/google/apis/datastream_v1/classes.rb', line 825

def full_hierarchy
  @full_hierarchy
end

#hierarchy_depthFixnum

Optional. The number of hierarchy levels below the current level to be retrieved. Corresponds to the JSON property hierarchyDepth

Returns:

  • (Fixnum)


832
833
834
# File 'lib/google/apis/datastream_v1/classes.rb', line 832

def hierarchy_depth
  @hierarchy_depth
end

#mongodb_clusterGoogle::Apis::DatastreamV1::MongodbCluster

MongoDB Cluster structure. Corresponds to the JSON property mongodbCluster



837
838
839
# File 'lib/google/apis/datastream_v1/classes.rb', line 837

def mongodb_cluster
  @mongodb_cluster
end

#mysql_rdbmsGoogle::Apis::DatastreamV1::MysqlRdbms

MySQL database structure Corresponds to the JSON property mysqlRdbms



842
843
844
# File 'lib/google/apis/datastream_v1/classes.rb', line 842

def mysql_rdbms
  @mysql_rdbms
end

#oracle_rdbmsGoogle::Apis::DatastreamV1::OracleRdbms

Oracle database structure. Corresponds to the JSON property oracleRdbms



847
848
849
# File 'lib/google/apis/datastream_v1/classes.rb', line 847

def oracle_rdbms
  @oracle_rdbms
end

#postgresql_rdbmsGoogle::Apis::DatastreamV1::PostgresqlRdbms

PostgreSQL database structure. Corresponds to the JSON property postgresqlRdbms



852
853
854
# File 'lib/google/apis/datastream_v1/classes.rb', line 852

def postgresql_rdbms
  @postgresql_rdbms
end

#salesforce_orgGoogle::Apis::DatastreamV1::SalesforceOrg

Salesforce organization structure. Corresponds to the JSON property salesforceOrg



857
858
859
# File 'lib/google/apis/datastream_v1/classes.rb', line 857

def salesforce_org
  @salesforce_org
end

#source_catalogGoogle::Apis::DatastreamV1::SourceCatalog

Source catalog. Corresponds to the JSON property sourceCatalog



862
863
864
# File 'lib/google/apis/datastream_v1/classes.rb', line 862

def source_catalog
  @source_catalog
end

#spanner_databaseGoogle::Apis::DatastreamV1::SpannerDatabase

Spanner database structure. Corresponds to the JSON property spannerDatabase



867
868
869
# File 'lib/google/apis/datastream_v1/classes.rb', line 867

def spanner_database
  @spanner_database
end

#sql_server_rdbmsGoogle::Apis::DatastreamV1::SqlServerRdbms

SQLServer database structure. Corresponds to the JSON property sqlServerRdbms



872
873
874
# File 'lib/google/apis/datastream_v1/classes.rb', line 872

def sql_server_rdbms
  @sql_server_rdbms
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



879
880
881
882
883
884
885
886
887
888
889
890
891
892
# File 'lib/google/apis/datastream_v1/classes.rb', line 879

def update!(**args)
  @connection_profile = args[:connection_profile] if args.key?(:connection_profile)
  @connection_profile_name = args[:connection_profile_name] if args.key?(:connection_profile_name)
  @full_hierarchy = args[:full_hierarchy] if args.key?(:full_hierarchy)
  @hierarchy_depth = args[:hierarchy_depth] if args.key?(:hierarchy_depth)
  @mongodb_cluster = args[:mongodb_cluster] if args.key?(:mongodb_cluster)
  @mysql_rdbms = args[:mysql_rdbms] if args.key?(:mysql_rdbms)
  @oracle_rdbms = args[:oracle_rdbms] if args.key?(:oracle_rdbms)
  @postgresql_rdbms = args[:postgresql_rdbms] if args.key?(:postgresql_rdbms)
  @salesforce_org = args[:salesforce_org] if args.key?(:salesforce_org)
  @source_catalog = args[:source_catalog] if args.key?(:source_catalog)
  @spanner_database = args[:spanner_database] if args.key?(:spanner_database)
  @sql_server_rdbms = args[:sql_server_rdbms] if args.key?(:sql_server_rdbms)
end