Class: Google::Apis::DatastreamV1::EncryptionNotEnforced

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

Message to represent the option where encryption is not enforced. An empty message right now to allow future extensibility.

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EncryptionNotEnforced

Returns a new instance of EncryptionNotEnforced.



842
843
844
# File 'lib/google/apis/datastream_v1/classes.rb', line 842

def initialize(**args)
   update!(**args)
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



847
848
# File 'lib/google/apis/datastream_v1/classes.rb', line 847

def update!(**args)
end