Class: Google::Apis::DatastreamV1::Error

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

Represent a user-facing Error.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Error

Returns a new instance of Error.



1063
1064
1065
# File 'lib/google/apis/datastream_v1/classes.rb', line 1063

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detailsHash<String,String>

Additional information about the error. Corresponds to the JSON property details

Returns:

  • (Hash<String,String>)


1040
1041
1042
# File 'lib/google/apis/datastream_v1/classes.rb', line 1040

def details
  @details
end

#error_timeString

The time when the error occurred. Corresponds to the JSON property errorTime

Returns:

  • (String)


1045
1046
1047
# File 'lib/google/apis/datastream_v1/classes.rb', line 1045

def error_time
  @error_time
end

#error_uuidString

A unique identifier for this specific error, allowing it to be traced throughout the system in logs and API responses. Corresponds to the JSON property errorUuid

Returns:

  • (String)


1051
1052
1053
# File 'lib/google/apis/datastream_v1/classes.rb', line 1051

def error_uuid
  @error_uuid
end

#messageString

A message containing more information about the error that occurred. Corresponds to the JSON property message

Returns:

  • (String)


1056
1057
1058
# File 'lib/google/apis/datastream_v1/classes.rb', line 1056

def message
  @message
end

#reasonString

A title that explains the reason for the error. Corresponds to the JSON property reason

Returns:

  • (String)


1061
1062
1063
# File 'lib/google/apis/datastream_v1/classes.rb', line 1061

def reason
  @reason
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1068
1069
1070
1071
1072
1073
1074
# File 'lib/google/apis/datastream_v1/classes.rb', line 1068

def update!(**args)
  @details = args[:details] if args.key?(:details)
  @error_time = args[:error_time] if args.key?(:error_time)
  @error_uuid = args[:error_uuid] if args.key?(:error_uuid)
  @message = args[:message] if args.key?(:message)
  @reason = args[:reason] if args.key?(:reason)
end