Class: Google::Apis::DatastreamV1::EventFilter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

Represents a filter for included data on a stream object.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EventFilter

Returns a new instance of EventFilter.



905
906
907
# File 'lib/google/apis/datastream_v1/classes.rb', line 905

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#sql_where_clauseString

An SQL-query Where clause selecting which data should be included, not including the "WHERE" keyword. E.g., "t.key1 = 'value1' AND t.key2 = 'value2'". Corresponds to the JSON property sqlWhereClause

Returns:

  • (String)


903
904
905
# File 'lib/google/apis/datastream_v1/classes.rb', line 903

def sql_where_clause
  @sql_where_clause
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



910
911
912
# File 'lib/google/apis/datastream_v1/classes.rb', line 910

def update!(**args)
  @sql_where_clause = args[:sql_where_clause] if args.key?(:sql_where_clause)
end