Class: Google::Apis::DatastreamV1::GcsDestinationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

Google Cloud Storage destination configuration

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GcsDestinationConfig

Returns a new instance of GcsDestinationConfig.



1304
1305
1306
# File 'lib/google/apis/datastream_v1/classes.rb', line 1304

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#avro_file_formatGoogle::Apis::DatastreamV1::AvroFileFormat

AVRO file format configuration. Corresponds to the JSON property avroFileFormat



1280
1281
1282
# File 'lib/google/apis/datastream_v1/classes.rb', line 1280

def avro_file_format
  @avro_file_format
end

#file_rotation_intervalString

The maximum duration for which new events are added before a file is closed and a new file is created. Values within the range of 15-60 seconds are allowed. Corresponds to the JSON property fileRotationInterval

Returns:

  • (String)


1287
1288
1289
# File 'lib/google/apis/datastream_v1/classes.rb', line 1287

def file_rotation_interval
  @file_rotation_interval
end

#file_rotation_mbFixnum

The maximum file size to be saved in the bucket. Corresponds to the JSON property fileRotationMb

Returns:

  • (Fixnum)


1292
1293
1294
# File 'lib/google/apis/datastream_v1/classes.rb', line 1292

def file_rotation_mb
  @file_rotation_mb
end

#json_file_formatGoogle::Apis::DatastreamV1::JsonFileFormat

JSON file format configuration. Corresponds to the JSON property jsonFileFormat



1297
1298
1299
# File 'lib/google/apis/datastream_v1/classes.rb', line 1297

def json_file_format
  @json_file_format
end

#pathString

Path inside the Cloud Storage bucket to write data to. Corresponds to the JSON property path

Returns:

  • (String)


1302
1303
1304
# File 'lib/google/apis/datastream_v1/classes.rb', line 1302

def path
  @path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1309
1310
1311
1312
1313
1314
1315
# File 'lib/google/apis/datastream_v1/classes.rb', line 1309

def update!(**args)
  @avro_file_format = args[:avro_file_format] if args.key?(:avro_file_format)
  @file_rotation_interval = args[:file_rotation_interval] if args.key?(:file_rotation_interval)
  @file_rotation_mb = args[:file_rotation_mb] if args.key?(:file_rotation_mb)
  @json_file_format = args[:json_file_format] if args.key?(:json_file_format)
  @path = args[:path] if args.key?(:path)
end