Class: Google::Apis::DatastreamV1::MysqlColumn

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

MySQL Column.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MysqlColumn

Returns a new instance of MysqlColumn.



2251
2252
2253
# File 'lib/google/apis/datastream_v1/classes.rb', line 2251

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#collationString

Column collation. Corresponds to the JSON property collation

Returns:

  • (String)


2206
2207
2208
# File 'lib/google/apis/datastream_v1/classes.rb', line 2206

def collation
  @collation
end

#columnString

The column name. Corresponds to the JSON property column

Returns:

  • (String)


2211
2212
2213
# File 'lib/google/apis/datastream_v1/classes.rb', line 2211

def column
  @column
end

#data_typeString

The MySQL data type. Full data types list can be found here: https://dev.mysql. com/doc/refman/8.0/en/data-types.html Corresponds to the JSON property dataType

Returns:

  • (String)


2217
2218
2219
# File 'lib/google/apis/datastream_v1/classes.rb', line 2217

def data_type
  @data_type
end

#lengthFixnum

Column length. Corresponds to the JSON property length

Returns:

  • (Fixnum)


2222
2223
2224
# File 'lib/google/apis/datastream_v1/classes.rb', line 2222

def length
  @length
end

#nullableBoolean Also known as: nullable?

Whether or not the column can accept a null value. Corresponds to the JSON property nullable

Returns:

  • (Boolean)


2227
2228
2229
# File 'lib/google/apis/datastream_v1/classes.rb', line 2227

def nullable
  @nullable
end

#ordinal_positionFixnum

The ordinal position of the column in the table. Corresponds to the JSON property ordinalPosition

Returns:

  • (Fixnum)


2233
2234
2235
# File 'lib/google/apis/datastream_v1/classes.rb', line 2233

def ordinal_position
  @ordinal_position
end

#precisionFixnum

Column precision. Corresponds to the JSON property precision

Returns:

  • (Fixnum)


2238
2239
2240
# File 'lib/google/apis/datastream_v1/classes.rb', line 2238

def precision
  @precision
end

#primary_keyBoolean Also known as: primary_key?

Whether or not the column represents a primary key. Corresponds to the JSON property primaryKey

Returns:

  • (Boolean)


2243
2244
2245
# File 'lib/google/apis/datastream_v1/classes.rb', line 2243

def primary_key
  @primary_key
end

#scaleFixnum

Column scale. Corresponds to the JSON property scale

Returns:

  • (Fixnum)


2249
2250
2251
# File 'lib/google/apis/datastream_v1/classes.rb', line 2249

def scale
  @scale
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
2266
# File 'lib/google/apis/datastream_v1/classes.rb', line 2256

def update!(**args)
  @collation = args[:collation] if args.key?(:collation)
  @column = args[:column] if args.key?(:column)
  @data_type = args[:data_type] if args.key?(:data_type)
  @length = args[:length] if args.key?(:length)
  @nullable = args[:nullable] if args.key?(:nullable)
  @ordinal_position = args[:ordinal_position] if args.key?(:ordinal_position)
  @precision = args[:precision] if args.key?(:precision)
  @primary_key = args[:primary_key] if args.key?(:primary_key)
  @scale = args[:scale] if args.key?(:scale)
end