Class: Google::Apis::DatastreamV1::OauthClientCredentials

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

OAuth Client Credentials.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OauthClientCredentials

Returns a new instance of OauthClientCredentials.



2623
2624
2625
# File 'lib/google/apis/datastream_v1/classes.rb', line 2623

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_idString

Required. Client ID for OAuth Client Credentials. Corresponds to the JSON property clientId

Returns:

  • (String)


2615
2616
2617
# File 'lib/google/apis/datastream_v1/classes.rb', line 2615

def client_id
  @client_id
end

#client_secretGoogle::Apis::DatastreamV1::Secret

A confidential piece of information where the actual value is either directly specified in the message as a raw string or stored in GCP secret manager. Corresponds to the JSON property clientSecret



2621
2622
2623
# File 'lib/google/apis/datastream_v1/classes.rb', line 2621

def client_secret
  @client_secret
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2628
2629
2630
2631
# File 'lib/google/apis/datastream_v1/classes.rb', line 2628

def update!(**args)
  @client_id = args[:client_id] if args.key?(:client_id)
  @client_secret = args[:client_secret] if args.key?(:client_secret)
end