Class: Google::Apis::DatastreamV1::ObjectFilter
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1::ObjectFilter
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb
Overview
Object filter to apply the rules to.
Instance Attribute Summary collapse
-
#source_object_identifier ⇒ Google::Apis::DatastreamV1::SourceObjectIdentifier
Represents an identifier of an object in the data source.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ObjectFilter
constructor
A new instance of ObjectFilter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ObjectFilter
Returns a new instance of ObjectFilter.
2643 2644 2645 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 2643 def initialize(**args) update!(**args) end |
Instance Attribute Details
#source_object_identifier ⇒ Google::Apis::DatastreamV1::SourceObjectIdentifier
Represents an identifier of an object in the data source.
Corresponds to the JSON property sourceObjectIdentifier
2641 2642 2643 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 2641 def source_object_identifier @source_object_identifier end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2648 2649 2650 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 2648 def update!(**args) @source_object_identifier = args[:source_object_identifier] if args.key?(:source_object_identifier) end |