Class: Google::Apis::DatastreamV1::OracleColumn

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

Oracle Column.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OracleColumn

Returns a new instance of OracleColumn.



2939
2940
2941
# File 'lib/google/apis/datastream_v1/classes.rb', line 2939

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#columnString

The column name. Corresponds to the JSON property column

Returns:

  • (String)


2895
2896
2897
# File 'lib/google/apis/datastream_v1/classes.rb', line 2895

def column
  @column
end

#data_typeString

The Oracle data type. Corresponds to the JSON property dataType

Returns:

  • (String)


2900
2901
2902
# File 'lib/google/apis/datastream_v1/classes.rb', line 2900

def data_type
  @data_type
end

#encodingString

Column encoding. Corresponds to the JSON property encoding

Returns:

  • (String)


2905
2906
2907
# File 'lib/google/apis/datastream_v1/classes.rb', line 2905

def encoding
  @encoding
end

#lengthFixnum

Column length. Corresponds to the JSON property length

Returns:

  • (Fixnum)


2910
2911
2912
# File 'lib/google/apis/datastream_v1/classes.rb', line 2910

def length
  @length
end

#nullableBoolean Also known as: nullable?

Whether or not the column can accept a null value. Corresponds to the JSON property nullable

Returns:

  • (Boolean)


2915
2916
2917
# File 'lib/google/apis/datastream_v1/classes.rb', line 2915

def nullable
  @nullable
end

#ordinal_positionFixnum

The ordinal position of the column in the table. Corresponds to the JSON property ordinalPosition

Returns:

  • (Fixnum)


2921
2922
2923
# File 'lib/google/apis/datastream_v1/classes.rb', line 2921

def ordinal_position
  @ordinal_position
end

#precisionFixnum

Column precision. Corresponds to the JSON property precision

Returns:

  • (Fixnum)


2926
2927
2928
# File 'lib/google/apis/datastream_v1/classes.rb', line 2926

def precision
  @precision
end

#primary_keyBoolean Also known as: primary_key?

Whether or not the column represents a primary key. Corresponds to the JSON property primaryKey

Returns:

  • (Boolean)


2931
2932
2933
# File 'lib/google/apis/datastream_v1/classes.rb', line 2931

def primary_key
  @primary_key
end

#scaleFixnum

Column scale. Corresponds to the JSON property scale

Returns:

  • (Fixnum)


2937
2938
2939
# File 'lib/google/apis/datastream_v1/classes.rb', line 2937

def scale
  @scale
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2944
2945
2946
2947
2948
2949
2950
2951
2952
2953
2954
# File 'lib/google/apis/datastream_v1/classes.rb', line 2944

def update!(**args)
  @column = args[:column] if args.key?(:column)
  @data_type = args[:data_type] if args.key?(:data_type)
  @encoding = args[:encoding] if args.key?(:encoding)
  @length = args[:length] if args.key?(:length)
  @nullable = args[:nullable] if args.key?(:nullable)
  @ordinal_position = args[:ordinal_position] if args.key?(:ordinal_position)
  @precision = args[:precision] if args.key?(:precision)
  @primary_key = args[:primary_key] if args.key?(:primary_key)
  @scale = args[:scale] if args.key?(:scale)
end