Class: Google::Apis::DatastreamV1::OracleProfile
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1::OracleProfile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb
Overview
Profile for connecting to an Oracle source.
Instance Attribute Summary collapse
-
#connection_attributes ⇒ Hash<String,String>
Connection string attributes Corresponds to the JSON property
connectionAttributes. -
#database_service ⇒ String
Required.
-
#hostname ⇒ String
Required.
-
#oracle_asm_config ⇒ Google::Apis::DatastreamV1::OracleAsmConfig
Configuration for Oracle Automatic Storage Management (ASM) connection.
-
#oracle_ssl_config ⇒ Google::Apis::DatastreamV1::OracleSslConfig
Oracle SSL configuration information.
-
#password ⇒ String
Optional.
-
#port ⇒ Fixnum
Port for the Oracle connection, default value is 1521.
-
#secret_manager_stored_password ⇒ String
Optional.
-
#username ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OracleProfile
constructor
A new instance of OracleProfile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OracleProfile
Returns a new instance of OracleProfile.
3033 3034 3035 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3033 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connection_attributes ⇒ Hash<String,String>
Connection string attributes
Corresponds to the JSON property connectionAttributes
2989 2990 2991 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 2989 def connection_attributes @connection_attributes end |
#database_service ⇒ String
Required. Database for the Oracle connection.
Corresponds to the JSON property databaseService
2994 2995 2996 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 2994 def database_service @database_service end |
#hostname ⇒ String
Required. Hostname for the Oracle connection.
Corresponds to the JSON property hostname
2999 3000 3001 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 2999 def hostname @hostname end |
#oracle_asm_config ⇒ Google::Apis::DatastreamV1::OracleAsmConfig
Configuration for Oracle Automatic Storage Management (ASM) connection.
Corresponds to the JSON property oracleAsmConfig
3004 3005 3006 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3004 def oracle_asm_config @oracle_asm_config end |
#oracle_ssl_config ⇒ Google::Apis::DatastreamV1::OracleSslConfig
Oracle SSL configuration information.
Corresponds to the JSON property oracleSslConfig
3009 3010 3011 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3009 def oracle_ssl_config @oracle_ssl_config end |
#password ⇒ String
Optional. Password for the Oracle connection. Mutually exclusive with the
secret_manager_stored_password field.
Corresponds to the JSON property password
3015 3016 3017 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3015 def password @password end |
#port ⇒ Fixnum
Port for the Oracle connection, default value is 1521.
Corresponds to the JSON property port
3020 3021 3022 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3020 def port @port end |
#secret_manager_stored_password ⇒ String
Optional. A reference to a Secret Manager resource name storing the Oracle
connection password. Mutually exclusive with the password field.
Corresponds to the JSON property secretManagerStoredPassword
3026 3027 3028 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3026 def secret_manager_stored_password @secret_manager_stored_password end |
#username ⇒ String
Required. Username for the Oracle connection.
Corresponds to the JSON property username
3031 3032 3033 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3031 def username @username end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3038 3039 3040 3041 3042 3043 3044 3045 3046 3047 3048 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3038 def update!(**args) @connection_attributes = args[:connection_attributes] if args.key?(:connection_attributes) @database_service = args[:database_service] if args.key?(:database_service) @hostname = args[:hostname] if args.key?(:hostname) @oracle_asm_config = args[:oracle_asm_config] if args.key?(:oracle_asm_config) @oracle_ssl_config = args[:oracle_ssl_config] if args.key?(:oracle_ssl_config) @password = args[:password] if args.key?(:password) @port = args[:port] if args.key?(:port) @secret_manager_stored_password = args[:secret_manager_stored_password] if args.key?(:secret_manager_stored_password) @username = args[:username] if args.key?(:username) end |