Class: Google::Apis::DatastreamV1::PostgresqlColumn

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

PostgreSQL Column.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PostgresqlColumn

Returns a new instance of PostgresqlColumn.



3287
3288
3289
# File 'lib/google/apis/datastream_v1/classes.rb', line 3287

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#columnString

The column name. Corresponds to the JSON property column

Returns:

  • (String)


3248
3249
3250
# File 'lib/google/apis/datastream_v1/classes.rb', line 3248

def column
  @column
end

#data_typeString

The PostgreSQL data type. Corresponds to the JSON property dataType

Returns:

  • (String)


3253
3254
3255
# File 'lib/google/apis/datastream_v1/classes.rb', line 3253

def data_type
  @data_type
end

#lengthFixnum

Column length. Corresponds to the JSON property length

Returns:

  • (Fixnum)


3258
3259
3260
# File 'lib/google/apis/datastream_v1/classes.rb', line 3258

def length
  @length
end

#nullableBoolean Also known as: nullable?

Whether or not the column can accept a null value. Corresponds to the JSON property nullable

Returns:

  • (Boolean)


3263
3264
3265
# File 'lib/google/apis/datastream_v1/classes.rb', line 3263

def nullable
  @nullable
end

#ordinal_positionFixnum

The ordinal position of the column in the table. Corresponds to the JSON property ordinalPosition

Returns:

  • (Fixnum)


3269
3270
3271
# File 'lib/google/apis/datastream_v1/classes.rb', line 3269

def ordinal_position
  @ordinal_position
end

#precisionFixnum

Column precision. Corresponds to the JSON property precision

Returns:

  • (Fixnum)


3274
3275
3276
# File 'lib/google/apis/datastream_v1/classes.rb', line 3274

def precision
  @precision
end

#primary_keyBoolean Also known as: primary_key?

Whether or not the column represents a primary key. Corresponds to the JSON property primaryKey

Returns:

  • (Boolean)


3279
3280
3281
# File 'lib/google/apis/datastream_v1/classes.rb', line 3279

def primary_key
  @primary_key
end

#scaleFixnum

Column scale. Corresponds to the JSON property scale

Returns:

  • (Fixnum)


3285
3286
3287
# File 'lib/google/apis/datastream_v1/classes.rb', line 3285

def scale
  @scale
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3292
3293
3294
3295
3296
3297
3298
3299
3300
3301
# File 'lib/google/apis/datastream_v1/classes.rb', line 3292

def update!(**args)
  @column = args[:column] if args.key?(:column)
  @data_type = args[:data_type] if args.key?(:data_type)
  @length = args[:length] if args.key?(:length)
  @nullable = args[:nullable] if args.key?(:nullable)
  @ordinal_position = args[:ordinal_position] if args.key?(:ordinal_position)
  @precision = args[:precision] if args.key?(:precision)
  @primary_key = args[:primary_key] if args.key?(:primary_key)
  @scale = args[:scale] if args.key?(:scale)
end