Class: Google::Apis::DatastreamV1::PostgresqlSourceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

Configuration for syncing data from a PostgreSQL source.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PostgresqlSourceConfig

Returns a new instance of PostgresqlSourceConfig.



3462
3463
3464
# File 'lib/google/apis/datastream_v1/classes.rb', line 3462

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#exclude_objectsGoogle::Apis::DatastreamV1::PostgresqlRdbms

PostgreSQL database structure. Corresponds to the JSON property excludeObjects



3437
3438
3439
# File 'lib/google/apis/datastream_v1/classes.rb', line 3437

def exclude_objects
  @exclude_objects
end

#include_objectsGoogle::Apis::DatastreamV1::PostgresqlRdbms

PostgreSQL database structure. Corresponds to the JSON property includeObjects



3442
3443
3444
# File 'lib/google/apis/datastream_v1/classes.rb', line 3442

def include_objects
  @include_objects
end

#max_concurrent_backfill_tasksFixnum

Maximum number of concurrent backfill tasks. The number should be non negative. If not set (or set to 0), the system's default value will be used. Corresponds to the JSON property maxConcurrentBackfillTasks

Returns:

  • (Fixnum)


3448
3449
3450
# File 'lib/google/apis/datastream_v1/classes.rb', line 3448

def max_concurrent_backfill_tasks
  @max_concurrent_backfill_tasks
end

#publicationString

Required. The name of the publication that includes the set of all tables that are defined in the stream's include_objects. Corresponds to the JSON property publication

Returns:

  • (String)


3454
3455
3456
# File 'lib/google/apis/datastream_v1/classes.rb', line 3454

def publication
  @publication
end

#replication_slotString

Required. Immutable. The name of the logical replication slot that's configured with the pgoutput plugin. Corresponds to the JSON property replicationSlot

Returns:

  • (String)


3460
3461
3462
# File 'lib/google/apis/datastream_v1/classes.rb', line 3460

def replication_slot
  @replication_slot
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3467
3468
3469
3470
3471
3472
3473
# File 'lib/google/apis/datastream_v1/classes.rb', line 3467

def update!(**args)
  @exclude_objects = args[:exclude_objects] if args.key?(:exclude_objects)
  @include_objects = args[:include_objects] if args.key?(:include_objects)
  @max_concurrent_backfill_tasks = args[:max_concurrent_backfill_tasks] if args.key?(:max_concurrent_backfill_tasks)
  @publication = args[:publication] if args.key?(:publication)
  @replication_slot = args[:replication_slot] if args.key?(:replication_slot)
end