Class: Google::Apis::DatastreamV1::PostgresqlSslConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

PostgreSQL SSL configuration information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PostgresqlSslConfig

Returns a new instance of PostgresqlSslConfig.



3330
3331
3332
# File 'lib/google/apis/datastream_v1/classes.rb', line 3330

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#server_and_client_verificationGoogle::Apis::DatastreamV1::ServerAndClientVerification

Message represents the option where Datastream will enforce the encryption and authenticate the server identity as well as the client identity. ca_certificate, client_certificate and client_key must be set if user selects this option. Corresponds to the JSON property serverAndClientVerification



3321
3322
3323
# File 'lib/google/apis/datastream_v1/classes.rb', line 3321

def server_and_client_verification
  @server_and_client_verification
end

#server_verificationGoogle::Apis::DatastreamV1::ServerVerification

Message represents the option where Datastream will enforce the encryption and authenticate the server identity. ca_certificate must be set if user selects this option. Corresponds to the JSON property serverVerification



3328
3329
3330
# File 'lib/google/apis/datastream_v1/classes.rb', line 3328

def server_verification
  @server_verification
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3335
3336
3337
3338
# File 'lib/google/apis/datastream_v1/classes.rb', line 3335

def update!(**args)
  @server_and_client_verification = args[:server_and_client_verification] if args.key?(:server_and_client_verification)
  @server_verification = args[:server_verification] if args.key?(:server_verification)
end