Class: Google::Apis::DatastreamV1::ResourceInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

Describes the resource that is being accessed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceInfo

Returns a new instance of ResourceInfo.



3736
3737
3738
# File 'lib/google/apis/datastream_v1/classes.rb', line 3736

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Describes what error is encountered when accessing this resource. For example, updating a cloud project may require the writer permission on the developer console project. Corresponds to the JSON property description

Returns:

  • (String)


3715
3716
3717
# File 'lib/google/apis/datastream_v1/classes.rb', line 3715

def description
  @description
end

#ownerString

The owner of the resource (optional). For example, "user:" or "project:". Corresponds to the JSON property owner

Returns:

  • (String)


3720
3721
3722
# File 'lib/google/apis/datastream_v1/classes.rb', line 3720

def owner
  @owner
end

#resource_nameString

The name of the resource being accessed. For example, a shared calendar name: " example.com_4fghdhgsrgh@group.calendar.google.com", if the current error is google.rpc.Code.PERMISSION_DENIED. Corresponds to the JSON property resourceName

Returns:

  • (String)


3727
3728
3729
# File 'lib/google/apis/datastream_v1/classes.rb', line 3727

def resource_name
  @resource_name
end

#resource_typeString

A name for the type of resource being accessed, e.g. "sql table", "cloud storage bucket", "file", "Google calendar"; or the type URL of the resource: e. g. "type.googleapis.com/google.pubsub.v1.Topic". Corresponds to the JSON property resourceType

Returns:

  • (String)


3734
3735
3736
# File 'lib/google/apis/datastream_v1/classes.rb', line 3734

def resource_type
  @resource_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3741
3742
3743
3744
3745
3746
# File 'lib/google/apis/datastream_v1/classes.rb', line 3741

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @owner = args[:owner] if args.key?(:owner)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
end