Class: Google::Apis::DatastreamV1::Route
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1::Route
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb
Overview
The route resource is the child of the private connection resource, used for defining a route for a private connection.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#destination_address ⇒ String
Required.
-
#destination_port ⇒ Fixnum
Destination port for connection Corresponds to the JSON property
destinationPort. -
#display_name ⇒ String
Required.
-
#labels ⇒ Hash<String,String>
Labels.
-
#name ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Route
constructor
A new instance of Route.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Route
Returns a new instance of Route.
3816 3817 3818 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3816 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The create time of the resource.
Corresponds to the JSON property createTime
3784 3785 3786 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3784 def create_time @create_time end |
#destination_address ⇒ String
Required. Destination address for connection
Corresponds to the JSON property destinationAddress
3789 3790 3791 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3789 def destination_address @destination_address end |
#destination_port ⇒ Fixnum
Destination port for connection
Corresponds to the JSON property destinationPort
3794 3795 3796 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3794 def destination_port @destination_port end |
#display_name ⇒ String
Required. Display name.
Corresponds to the JSON property displayName
3799 3800 3801 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3799 def display_name @display_name end |
#labels ⇒ Hash<String,String>
Labels.
Corresponds to the JSON property labels
3804 3805 3806 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3804 def labels @labels end |
#name ⇒ String
Output only. Identifier. The resource's name.
Corresponds to the JSON property name
3809 3810 3811 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3809 def name @name end |
#update_time ⇒ String
Output only. The update time of the resource.
Corresponds to the JSON property updateTime
3814 3815 3816 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3814 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3821 3822 3823 3824 3825 3826 3827 3828 3829 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3821 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @destination_address = args[:destination_address] if args.key?(:destination_address) @destination_port = args[:destination_port] if args.key?(:destination_port) @display_name = args[:display_name] if args.key?(:display_name) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |