Class: Google::Apis::DatastreamV1::Secret

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

A confidential piece of information where the actual value is either directly specified in the message as a raw string or stored in GCP secret manager.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Secret

Returns a new instance of Secret.



4291
4292
4293
# File 'lib/google/apis/datastream_v1/classes.rb', line 4291

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#raw_valueString

Optional. Input only. The actual raw value of the secret as plain text. Corresponds to the JSON property rawValue

Returns:

  • (String)


4281
4282
4283
# File 'lib/google/apis/datastream_v1/classes.rb', line 4281

def raw_value
  @raw_value
end

#secret_versionString

Optional. A Secret Manager resource name storing the actual value of the secret. Supported formats: * projects/project/locations/location/secrets/ secret/versions/version * projects/project/secrets/secret/versions/ version Corresponds to the JSON property secretVersion

Returns:

  • (String)


4289
4290
4291
# File 'lib/google/apis/datastream_v1/classes.rb', line 4289

def secret_version
  @secret_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4296
4297
4298
4299
# File 'lib/google/apis/datastream_v1/classes.rb', line 4296

def update!(**args)
  @raw_value = args[:raw_value] if args.key?(:raw_value)
  @secret_version = args[:secret_version] if args.key?(:secret_version)
end