Class: Google::Apis::DatastreamV1::SourceConfig
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1::SourceConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb
Overview
The configuration of the stream source.
Instance Attribute Summary collapse
-
#dataverse_source_config ⇒ Google::Apis::DatastreamV1::DataverseSourceConfig
Configuration for syncing data from a Dataverse source.
-
#mongodb_source_config ⇒ Google::Apis::DatastreamV1::MongodbSourceConfig
Configuration for syncing data from a MongoDB source.
-
#mysql_source_config ⇒ Google::Apis::DatastreamV1::MysqlSourceConfig
Configuration for syncing data from a MySQL source.
-
#oracle_source_config ⇒ Google::Apis::DatastreamV1::OracleSourceConfig
Configuration for syncing data from an Oracle source.
-
#postgresql_source_config ⇒ Google::Apis::DatastreamV1::PostgresqlSourceConfig
Configuration for syncing data from a PostgreSQL source.
-
#salesforce_marketing_cloud_source_config ⇒ Google::Apis::DatastreamV1::SalesforceMarketingCloudSourceConfig
Configuration for syncing data from a Salesforce Marketing Cloud source.
-
#salesforce_source_config ⇒ Google::Apis::DatastreamV1::SalesforceSourceConfig
Configuration for syncing data from a Salesforce source.
-
#service_now_source_config ⇒ Google::Apis::DatastreamV1::ServiceNowSourceConfig
Configuration for syncing data from a ServiceNow source.
-
#source_connection_profile ⇒ String
Required.
-
#spanner_source_config ⇒ Google::Apis::DatastreamV1::SpannerSourceConfig
Configuration for syncing data from a Spanner source.
-
#sql_server_source_config ⇒ Google::Apis::DatastreamV1::SqlServerSourceConfig
Configuration for syncing data from a SQLServer source.
-
#workday_source_config ⇒ Google::Apis::DatastreamV1::WorkdaySourceConfig
Configuration for syncing data from a Workday source.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SourceConfig
constructor
A new instance of SourceConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SourceConfig
Returns a new instance of SourceConfig.
4549 4550 4551 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4549 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dataverse_source_config ⇒ Google::Apis::DatastreamV1::DataverseSourceConfig
Configuration for syncing data from a Dataverse source.
Corresponds to the JSON property dataverseSourceConfig
4491 4492 4493 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4491 def dataverse_source_config @dataverse_source_config end |
#mongodb_source_config ⇒ Google::Apis::DatastreamV1::MongodbSourceConfig
Configuration for syncing data from a MongoDB source.
Corresponds to the JSON property mongodbSourceConfig
4496 4497 4498 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4496 def mongodb_source_config @mongodb_source_config end |
#mysql_source_config ⇒ Google::Apis::DatastreamV1::MysqlSourceConfig
Configuration for syncing data from a MySQL source.
Corresponds to the JSON property mysqlSourceConfig
4501 4502 4503 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4501 def mysql_source_config @mysql_source_config end |
#oracle_source_config ⇒ Google::Apis::DatastreamV1::OracleSourceConfig
Configuration for syncing data from an Oracle source.
Corresponds to the JSON property oracleSourceConfig
4506 4507 4508 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4506 def oracle_source_config @oracle_source_config end |
#postgresql_source_config ⇒ Google::Apis::DatastreamV1::PostgresqlSourceConfig
Configuration for syncing data from a PostgreSQL source.
Corresponds to the JSON property postgresqlSourceConfig
4511 4512 4513 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4511 def postgresql_source_config @postgresql_source_config end |
#salesforce_marketing_cloud_source_config ⇒ Google::Apis::DatastreamV1::SalesforceMarketingCloudSourceConfig
Configuration for syncing data from a Salesforce Marketing Cloud source.
Corresponds to the JSON property salesforceMarketingCloudSourceConfig
4516 4517 4518 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4516 def salesforce_marketing_cloud_source_config @salesforce_marketing_cloud_source_config end |
#salesforce_source_config ⇒ Google::Apis::DatastreamV1::SalesforceSourceConfig
Configuration for syncing data from a Salesforce source.
Corresponds to the JSON property salesforceSourceConfig
4521 4522 4523 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4521 def salesforce_source_config @salesforce_source_config end |
#service_now_source_config ⇒ Google::Apis::DatastreamV1::ServiceNowSourceConfig
Configuration for syncing data from a ServiceNow source.
Corresponds to the JSON property serviceNowSourceConfig
4526 4527 4528 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4526 def service_now_source_config @service_now_source_config end |
#source_connection_profile ⇒ String
Required. Source connection profile resource. Format: projects/project/
locations/location/connectionProfiles/name`
Corresponds to the JSON propertysourceConnectionProfile`
4532 4533 4534 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4532 def source_connection_profile @source_connection_profile end |
#spanner_source_config ⇒ Google::Apis::DatastreamV1::SpannerSourceConfig
Configuration for syncing data from a Spanner source.
Corresponds to the JSON property spannerSourceConfig
4537 4538 4539 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4537 def spanner_source_config @spanner_source_config end |
#sql_server_source_config ⇒ Google::Apis::DatastreamV1::SqlServerSourceConfig
Configuration for syncing data from a SQLServer source.
Corresponds to the JSON property sqlServerSourceConfig
4542 4543 4544 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4542 def sql_server_source_config @sql_server_source_config end |
#workday_source_config ⇒ Google::Apis::DatastreamV1::WorkdaySourceConfig
Configuration for syncing data from a Workday source.
Corresponds to the JSON property workdaySourceConfig
4547 4548 4549 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4547 def workday_source_config @workday_source_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 4566 4567 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4554 def update!(**args) @dataverse_source_config = args[:dataverse_source_config] if args.key?(:dataverse_source_config) @mongodb_source_config = args[:mongodb_source_config] if args.key?(:mongodb_source_config) @mysql_source_config = args[:mysql_source_config] if args.key?(:mysql_source_config) @oracle_source_config = args[:oracle_source_config] if args.key?(:oracle_source_config) @postgresql_source_config = args[:postgresql_source_config] if args.key?(:postgresql_source_config) @salesforce_marketing_cloud_source_config = args[:salesforce_marketing_cloud_source_config] if args.key?(:salesforce_marketing_cloud_source_config) @salesforce_source_config = args[:salesforce_source_config] if args.key?(:salesforce_source_config) @service_now_source_config = args[:service_now_source_config] if args.key?(:service_now_source_config) @source_connection_profile = args[:source_connection_profile] if args.key?(:source_connection_profile) @spanner_source_config = args[:spanner_source_config] if args.key?(:spanner_source_config) @sql_server_source_config = args[:sql_server_source_config] if args.key?(:sql_server_source_config) @workday_source_config = args[:workday_source_config] if args.key?(:workday_source_config) end |