Class: Google::Apis::DatastreamV1::SourceHierarchyDatasets

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

Destination datasets are created so that hierarchy of the destination data objects matches the source hierarchy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SourceHierarchyDatasets

Returns a new instance of SourceHierarchyDatasets.



4586
4587
4588
# File 'lib/google/apis/datastream_v1/classes.rb', line 4586

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataset_templateGoogle::Apis::DatastreamV1::DatasetTemplate

Dataset template used for dynamic dataset creation. Corresponds to the JSON property datasetTemplate



4578
4579
4580
# File 'lib/google/apis/datastream_v1/classes.rb', line 4578

def dataset_template
  @dataset_template
end

#project_idString

Optional. The project id of the BigQuery dataset. If not specified, the project will be inferred from the stream resource. Corresponds to the JSON property projectId

Returns:

  • (String)


4584
4585
4586
# File 'lib/google/apis/datastream_v1/classes.rb', line 4584

def project_id
  @project_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4591
4592
4593
4594
# File 'lib/google/apis/datastream_v1/classes.rb', line 4591

def update!(**args)
  @dataset_template = args[:dataset_template] if args.key?(:dataset_template)
  @project_id = args[:project_id] if args.key?(:project_id)
end