Class: Google::Apis::DatastreamV1::Stream

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

A resource representing streaming data from a source to a destination.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Stream

Returns a new instance of Stream.



5605
5606
5607
# File 'lib/google/apis/datastream_v1/classes.rb', line 5605

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backfill_allGoogle::Apis::DatastreamV1::BackfillAllStrategy

Backfill strategy to automatically backfill the Stream's objects. Specific objects can be excluded. Corresponds to the JSON property backfillAll



5523
5524
5525
# File 'lib/google/apis/datastream_v1/classes.rb', line 5523

def backfill_all
  @backfill_all
end

#backfill_noneGoogle::Apis::DatastreamV1::BackfillNoneStrategy

Backfill strategy to disable automatic backfill for the Stream's objects. Corresponds to the JSON property backfillNone



5528
5529
5530
# File 'lib/google/apis/datastream_v1/classes.rb', line 5528

def backfill_none
  @backfill_none
end

#create_timeString

Output only. The creation time of the stream. Corresponds to the JSON property createTime

Returns:

  • (String)


5533
5534
5535
# File 'lib/google/apis/datastream_v1/classes.rb', line 5533

def create_time
  @create_time
end

#customer_managed_encryption_keyString

Immutable. A reference to a KMS encryption key. If provided, it will be used to encrypt the data. If left blank, data will be encrypted using an internal Stream-specific encryption key provisioned through KMS. Corresponds to the JSON property customerManagedEncryptionKey

Returns:

  • (String)


5540
5541
5542
# File 'lib/google/apis/datastream_v1/classes.rb', line 5540

def customer_managed_encryption_key
  @customer_managed_encryption_key
end

#destination_configGoogle::Apis::DatastreamV1::DestinationConfig

The configuration of the stream destination. Corresponds to the JSON property destinationConfig



5545
5546
5547
# File 'lib/google/apis/datastream_v1/classes.rb', line 5545

def destination_config
  @destination_config
end

#display_nameString

Required. Display name. Corresponds to the JSON property displayName

Returns:

  • (String)


5550
5551
5552
# File 'lib/google/apis/datastream_v1/classes.rb', line 5550

def display_name
  @display_name
end

#errorsArray<Google::Apis::DatastreamV1::Error>

Output only. Errors on the Stream. Corresponds to the JSON property errors



5555
5556
5557
# File 'lib/google/apis/datastream_v1/classes.rb', line 5555

def errors
  @errors
end

#labelsHash<String,String>

Labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


5560
5561
5562
# File 'lib/google/apis/datastream_v1/classes.rb', line 5560

def labels
  @labels
end

#last_recovery_timeString

Output only. If the stream was recovered, the time of the last recovery. Note: This field is currently experimental. Corresponds to the JSON property lastRecoveryTime

Returns:

  • (String)


5566
5567
5568
# File 'lib/google/apis/datastream_v1/classes.rb', line 5566

def last_recovery_time
  @last_recovery_time
end

#nameString

Output only. Identifier. The stream's name. Corresponds to the JSON property name

Returns:

  • (String)


5571
5572
5573
# File 'lib/google/apis/datastream_v1/classes.rb', line 5571

def name
  @name
end

#rule_setsArray<Google::Apis::DatastreamV1::RuleSet>

Optional. Rule sets to apply to the stream. Corresponds to the JSON property ruleSets



5576
5577
5578
# File 'lib/google/apis/datastream_v1/classes.rb', line 5576

def rule_sets
  @rule_sets
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


5581
5582
5583
# File 'lib/google/apis/datastream_v1/classes.rb', line 5581

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


5587
5588
5589
# File 'lib/google/apis/datastream_v1/classes.rb', line 5587

def satisfies_pzs
  @satisfies_pzs
end

#source_configGoogle::Apis::DatastreamV1::SourceConfig

The configuration of the stream source. Corresponds to the JSON property sourceConfig



5593
5594
5595
# File 'lib/google/apis/datastream_v1/classes.rb', line 5593

def source_config
  @source_config
end

#stateString

The state of the stream. Corresponds to the JSON property state

Returns:

  • (String)


5598
5599
5600
# File 'lib/google/apis/datastream_v1/classes.rb', line 5598

def state
  @state
end

#update_timeString

Output only. The last update time of the stream. Corresponds to the JSON property updateTime

Returns:

  • (String)


5603
5604
5605
# File 'lib/google/apis/datastream_v1/classes.rb', line 5603

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
# File 'lib/google/apis/datastream_v1/classes.rb', line 5610

def update!(**args)
  @backfill_all = args[:backfill_all] if args.key?(:backfill_all)
  @backfill_none = args[:backfill_none] if args.key?(:backfill_none)
  @create_time = args[:create_time] if args.key?(:create_time)
  @customer_managed_encryption_key = args[:customer_managed_encryption_key] if args.key?(:customer_managed_encryption_key)
  @destination_config = args[:destination_config] if args.key?(:destination_config)
  @display_name = args[:display_name] if args.key?(:display_name)
  @errors = args[:errors] if args.key?(:errors)
  @labels = args[:labels] if args.key?(:labels)
  @last_recovery_time = args[:last_recovery_time] if args.key?(:last_recovery_time)
  @name = args[:name] if args.key?(:name)
  @rule_sets = args[:rule_sets] if args.key?(:rule_sets)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @source_config = args[:source_config] if args.key?(:source_config)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end