Class: Google::Apis::DatastreamV1::StreamObject

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

A specific stream object (e.g a specific DB table).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StreamObject

Returns a new instance of StreamObject.



5689
5690
5691
# File 'lib/google/apis/datastream_v1/classes.rb', line 5689

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backfill_jobGoogle::Apis::DatastreamV1::BackfillJob

Represents a backfill job on a specific stream object. Corresponds to the JSON property backfillJob



5650
5651
5652
# File 'lib/google/apis/datastream_v1/classes.rb', line 5650

def backfill_job
  @backfill_job
end

#create_timeString

Output only. The creation time of the object. Corresponds to the JSON property createTime

Returns:

  • (String)


5655
5656
5657
# File 'lib/google/apis/datastream_v1/classes.rb', line 5655

def create_time
  @create_time
end

#customization_rulesArray<Google::Apis::DatastreamV1::CustomizationRule>

Output only. The customization rules for the object. These rules are derived from the parent Stream's rule_sets and represent the intended configuration for the object. Corresponds to the JSON property customizationRules



5662
5663
5664
# File 'lib/google/apis/datastream_v1/classes.rb', line 5662

def customization_rules
  @customization_rules
end

#display_nameString

Required. Display name. Corresponds to the JSON property displayName

Returns:

  • (String)


5667
5668
5669
# File 'lib/google/apis/datastream_v1/classes.rb', line 5667

def display_name
  @display_name
end

#errorsArray<Google::Apis::DatastreamV1::Error>

Output only. Active errors on the object. Corresponds to the JSON property errors



5672
5673
5674
# File 'lib/google/apis/datastream_v1/classes.rb', line 5672

def errors
  @errors
end

#nameString

Output only. Identifier. The object resource's name. Corresponds to the JSON property name

Returns:

  • (String)


5677
5678
5679
# File 'lib/google/apis/datastream_v1/classes.rb', line 5677

def name
  @name
end

#source_objectGoogle::Apis::DatastreamV1::SourceObjectIdentifier

Represents an identifier of an object in the data source. Corresponds to the JSON property sourceObject



5682
5683
5684
# File 'lib/google/apis/datastream_v1/classes.rb', line 5682

def source_object
  @source_object
end

#update_timeString

Output only. The last update time of the object. Corresponds to the JSON property updateTime

Returns:

  • (String)


5687
5688
5689
# File 'lib/google/apis/datastream_v1/classes.rb', line 5687

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5694
5695
5696
5697
5698
5699
5700
5701
5702
5703
# File 'lib/google/apis/datastream_v1/classes.rb', line 5694

def update!(**args)
  @backfill_job = args[:backfill_job] if args.key?(:backfill_job)
  @create_time = args[:create_time] if args.key?(:create_time)
  @customization_rules = args[:customization_rules] if args.key?(:customization_rules)
  @display_name = args[:display_name] if args.key?(:display_name)
  @errors = args[:errors] if args.key?(:errors)
  @name = args[:name] if args.key?(:name)
  @source_object = args[:source_object] if args.key?(:source_object)
  @update_time = args[:update_time] if args.key?(:update_time)
end