Class: Google::Apis::DatastreamV1::UserCredentials
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1::UserCredentials
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb
Overview
Deprecated: Salesforce is retiring Username-Password authentication. Use
Oauth2ClientCredentials instead.
Instance Attribute Summary collapse
-
#password ⇒ String
Optional.
-
#secret_manager_stored_password ⇒ String
Optional.
-
#secret_manager_stored_security_token ⇒ String
Optional.
-
#security_token ⇒ String
Optional.
-
#username ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserCredentials
constructor
A new instance of UserCredentials.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserCredentials
Returns a new instance of UserCredentials.
5767 5768 5769 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5767 def initialize(**args) update!(**args) end |
Instance Attribute Details
#password ⇒ String
Optional. Password for the Salesforce connection. Mutually exclusive with the
secret_manager_stored_password field.
Corresponds to the JSON property password
5741 5742 5743 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5741 def password @password end |
#secret_manager_stored_password ⇒ String
Optional. A reference to a Secret Manager resource name storing the Salesforce
connection's password. Mutually exclusive with the password field.
Corresponds to the JSON property secretManagerStoredPassword
5747 5748 5749 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5747 def secret_manager_stored_password @secret_manager_stored_password end |
#secret_manager_stored_security_token ⇒ String
Optional. A reference to a Secret Manager resource name storing the Salesforce
connection's security token. Mutually exclusive with the security_token
field.
Corresponds to the JSON property secretManagerStoredSecurityToken
5754 5755 5756 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5754 def secret_manager_stored_security_token @secret_manager_stored_security_token end |
#security_token ⇒ String
Optional. Security token for the Salesforce connection. Mutually exclusive
with the secret_manager_stored_security_token field.
Corresponds to the JSON property securityToken
5760 5761 5762 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5760 def security_token @security_token end |
#username ⇒ String
Required. Username for the Salesforce connection.
Corresponds to the JSON property username
5765 5766 5767 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5765 def username @username end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5772 5773 5774 5775 5776 5777 5778 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5772 def update!(**args) @password = args[:password] if args.key?(:password) @secret_manager_stored_password = args[:secret_manager_stored_password] if args.key?(:secret_manager_stored_password) @secret_manager_stored_security_token = args[:secret_manager_stored_security_token] if args.key?(:secret_manager_stored_security_token) @security_token = args[:security_token] if args.key?(:security_token) @username = args[:username] if args.key?(:username) end |