Class: Google::Apis::DatastreamV1::UserPasswordCredentials

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

User-password credentials.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserPasswordCredentials

Returns a new instance of UserPasswordCredentials.



5796
5797
5798
# File 'lib/google/apis/datastream_v1/classes.rb', line 5796

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#passwordGoogle::Apis::DatastreamV1::Secret

A confidential piece of information where the actual value is either directly specified in the message as a raw string or stored in GCP secret manager. Corresponds to the JSON property password



5789
5790
5791
# File 'lib/google/apis/datastream_v1/classes.rb', line 5789

def password
  @password
end

#usernameString

Required. Username for the connection. Corresponds to the JSON property username

Returns:

  • (String)


5794
5795
5796
# File 'lib/google/apis/datastream_v1/classes.rb', line 5794

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5801
5802
5803
5804
# File 'lib/google/apis/datastream_v1/classes.rb', line 5801

def update!(**args)
  @password = args[:password] if args.key?(:password)
  @username = args[:username] if args.key?(:username)
end