Class: Google::Apis::DatastreamV1::BigQueryDestinationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

BigQuery destination configuration

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BigQueryDestinationConfig

Returns a new instance of BigQueryDestinationConfig.



264
265
266
# File 'lib/google/apis/datastream_v1/classes.rb', line 264

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#append_onlyGoogle::Apis::DatastreamV1::AppendOnly

AppendOnly mode defines that all changes to a table will be written to the destination table. Corresponds to the JSON property appendOnly



232
233
234
# File 'lib/google/apis/datastream_v1/classes.rb', line 232

def append_only
  @append_only
end

#blmt_configGoogle::Apis::DatastreamV1::BlmtConfig

The configuration for BLMT. Corresponds to the JSON property blmtConfig



237
238
239
# File 'lib/google/apis/datastream_v1/classes.rb', line 237

def blmt_config
  @blmt_config
end

#data_freshnessString

The guaranteed data freshness (in seconds) when querying tables created by the stream. Editing this field will only affect new tables created in the future, but existing tables will not be impacted. Lower values mean that queries will return fresher data, but may result in higher cost. Corresponds to the JSON property dataFreshness

Returns:

  • (String)


245
246
247
# File 'lib/google/apis/datastream_v1/classes.rb', line 245

def data_freshness
  @data_freshness
end

#mergeGoogle::Apis::DatastreamV1::Merge

Merge mode defines that all changes to a table will be merged at the destination table. Corresponds to the JSON property merge



251
252
253
# File 'lib/google/apis/datastream_v1/classes.rb', line 251

def merge
  @merge
end

#single_target_datasetGoogle::Apis::DatastreamV1::SingleTargetDataset

A single target dataset to which all data will be streamed. Corresponds to the JSON property singleTargetDataset



256
257
258
# File 'lib/google/apis/datastream_v1/classes.rb', line 256

def single_target_dataset
  @single_target_dataset
end

#source_hierarchy_datasetsGoogle::Apis::DatastreamV1::SourceHierarchyDatasets

Destination datasets are created so that hierarchy of the destination data objects matches the source hierarchy. Corresponds to the JSON property sourceHierarchyDatasets



262
263
264
# File 'lib/google/apis/datastream_v1/classes.rb', line 262

def source_hierarchy_datasets
  @source_hierarchy_datasets
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



269
270
271
272
273
274
275
276
# File 'lib/google/apis/datastream_v1/classes.rb', line 269

def update!(**args)
  @append_only = args[:append_only] if args.key?(:append_only)
  @blmt_config = args[:blmt_config] if args.key?(:blmt_config)
  @data_freshness = args[:data_freshness] if args.key?(:data_freshness)
  @merge = args[:merge] if args.key?(:merge)
  @single_target_dataset = args[:single_target_dataset] if args.key?(:single_target_dataset)
  @source_hierarchy_datasets = args[:source_hierarchy_datasets] if args.key?(:source_hierarchy_datasets)
end