Class: Google::Apis::DatastreamV1::ConnectionProfile
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1::ConnectionProfile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb
Overview
A set of reusable connection configurations to be used as a source or destination for a stream.
Instance Attribute Summary collapse
-
#bigquery_profile ⇒ Google::Apis::DatastreamV1::BigQueryProfile
Profile for connecting to a BigQuery destination.
-
#create_time ⇒ String
Output only.
-
#dataverse_profile ⇒ Google::Apis::DatastreamV1::DataverseProfile
Profile for connecting to a Dataverse source.
-
#display_name ⇒ String
Required.
-
#forward_ssh_connectivity ⇒ Google::Apis::DatastreamV1::ForwardSshTunnelConnectivity
Forward SSH Tunnel connectivity.
-
#gcs_profile ⇒ Google::Apis::DatastreamV1::GcsProfile
Profile for connecting to a Cloud Storage destination.
-
#labels ⇒ Hash<String,String>
Labels.
-
#mongodb_profile ⇒ Google::Apis::DatastreamV1::MongodbProfile
Profile for connecting to a MongoDB source.
-
#mysql_profile ⇒ Google::Apis::DatastreamV1::MysqlProfile
Profile for connecting to a MySQL source.
-
#name ⇒ String
Output only.
-
#oracle_profile ⇒ Google::Apis::DatastreamV1::OracleProfile
Profile for connecting to an Oracle source.
-
#postgresql_profile ⇒ Google::Apis::DatastreamV1::PostgresqlProfile
Profile for connecting to a PostgreSQL source.
-
#private_connectivity ⇒ Google::Apis::DatastreamV1::PrivateConnectivity
Private Connectivity Corresponds to the JSON property
privateConnectivity. -
#salesforce_marketing_cloud_profile ⇒ Google::Apis::DatastreamV1::SalesforceMarketingCloudProfile
Profile for connecting to a Salesforce Marketing Cloud source.
-
#salesforce_profile ⇒ Google::Apis::DatastreamV1::SalesforceProfile
Profile for connecting to a Salesforce source.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#service_now_profile ⇒ Google::Apis::DatastreamV1::ServiceNowProfile
Profile for connecting to a ServiceNow source.
-
#spanner_profile ⇒ Google::Apis::DatastreamV1::SpannerProfile
Profile for connecting to a Spanner source.
-
#sql_server_profile ⇒ Google::Apis::DatastreamV1::SqlServerProfile
Profile for connecting to a SQLServer source.
-
#static_service_ip_connectivity ⇒ Google::Apis::DatastreamV1::StaticServiceIpConnectivity
Static IP address connectivity.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConnectionProfile
constructor
A new instance of ConnectionProfile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConnectionProfile
Returns a new instance of ConnectionProfile.
584 585 586 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 584 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bigquery_profile ⇒ Google::Apis::DatastreamV1::BigQueryProfile
Profile for connecting to a BigQuery destination.
Corresponds to the JSON property bigqueryProfile
473 474 475 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 473 def bigquery_profile @bigquery_profile end |
#create_time ⇒ String
Output only. The create time of the resource.
Corresponds to the JSON property createTime
478 479 480 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 478 def create_time @create_time end |
#dataverse_profile ⇒ Google::Apis::DatastreamV1::DataverseProfile
Profile for connecting to a Dataverse source.
Corresponds to the JSON property dataverseProfile
483 484 485 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 483 def dataverse_profile @dataverse_profile end |
#display_name ⇒ String
Required. Display name.
Corresponds to the JSON property displayName
488 489 490 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 488 def display_name @display_name end |
#forward_ssh_connectivity ⇒ Google::Apis::DatastreamV1::ForwardSshTunnelConnectivity
Forward SSH Tunnel connectivity.
Corresponds to the JSON property forwardSshConnectivity
493 494 495 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 493 def forward_ssh_connectivity @forward_ssh_connectivity end |
#gcs_profile ⇒ Google::Apis::DatastreamV1::GcsProfile
Profile for connecting to a Cloud Storage destination.
Corresponds to the JSON property gcsProfile
498 499 500 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 498 def gcs_profile @gcs_profile end |
#labels ⇒ Hash<String,String>
Labels.
Corresponds to the JSON property labels
503 504 505 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 503 def labels @labels end |
#mongodb_profile ⇒ Google::Apis::DatastreamV1::MongodbProfile
Profile for connecting to a MongoDB source.
Corresponds to the JSON property mongodbProfile
508 509 510 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 508 def mongodb_profile @mongodb_profile end |
#mysql_profile ⇒ Google::Apis::DatastreamV1::MysqlProfile
Profile for connecting to a MySQL source.
Corresponds to the JSON property mysqlProfile
513 514 515 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 513 def mysql_profile @mysql_profile end |
#name ⇒ String
Output only. Identifier. The resource's name.
Corresponds to the JSON property name
518 519 520 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 518 def name @name end |
#oracle_profile ⇒ Google::Apis::DatastreamV1::OracleProfile
Profile for connecting to an Oracle source.
Corresponds to the JSON property oracleProfile
523 524 525 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 523 def oracle_profile @oracle_profile end |
#postgresql_profile ⇒ Google::Apis::DatastreamV1::PostgresqlProfile
Profile for connecting to a PostgreSQL source.
Corresponds to the JSON property postgresqlProfile
528 529 530 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 528 def postgresql_profile @postgresql_profile end |
#private_connectivity ⇒ Google::Apis::DatastreamV1::PrivateConnectivity
Private Connectivity
Corresponds to the JSON property privateConnectivity
533 534 535 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 533 def private_connectivity @private_connectivity end |
#salesforce_marketing_cloud_profile ⇒ Google::Apis::DatastreamV1::SalesforceMarketingCloudProfile
Profile for connecting to a Salesforce Marketing Cloud source.
Corresponds to the JSON property salesforceMarketingCloudProfile
538 539 540 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 538 def salesforce_marketing_cloud_profile @salesforce_marketing_cloud_profile end |
#salesforce_profile ⇒ Google::Apis::DatastreamV1::SalesforceProfile
Profile for connecting to a Salesforce source.
Corresponds to the JSON property salesforceProfile
543 544 545 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 543 def salesforce_profile @salesforce_profile end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
548 549 550 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 548 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
554 555 556 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 554 def satisfies_pzs @satisfies_pzs end |
#service_now_profile ⇒ Google::Apis::DatastreamV1::ServiceNowProfile
Profile for connecting to a ServiceNow source.
Corresponds to the JSON property serviceNowProfile
560 561 562 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 560 def service_now_profile @service_now_profile end |
#spanner_profile ⇒ Google::Apis::DatastreamV1::SpannerProfile
Profile for connecting to a Spanner source.
Corresponds to the JSON property spannerProfile
565 566 567 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 565 def spanner_profile @spanner_profile end |
#sql_server_profile ⇒ Google::Apis::DatastreamV1::SqlServerProfile
Profile for connecting to a SQLServer source.
Corresponds to the JSON property sqlServerProfile
570 571 572 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 570 def sql_server_profile @sql_server_profile end |
#static_service_ip_connectivity ⇒ Google::Apis::DatastreamV1::StaticServiceIpConnectivity
Static IP address connectivity. Used when the source database is configured to
allow incoming connections from the Datastream public IP addresses for the
region specified in the connection profile.
Corresponds to the JSON property staticServiceIpConnectivity
577 578 579 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 577 def static_service_ip_connectivity @static_service_ip_connectivity end |
#update_time ⇒ String
Output only. The update time of the resource.
Corresponds to the JSON property updateTime
582 583 584 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 582 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 589 def update!(**args) @bigquery_profile = args[:bigquery_profile] if args.key?(:bigquery_profile) @create_time = args[:create_time] if args.key?(:create_time) @dataverse_profile = args[:dataverse_profile] if args.key?(:dataverse_profile) @display_name = args[:display_name] if args.key?(:display_name) @forward_ssh_connectivity = args[:forward_ssh_connectivity] if args.key?(:forward_ssh_connectivity) @gcs_profile = args[:gcs_profile] if args.key?(:gcs_profile) @labels = args[:labels] if args.key?(:labels) @mongodb_profile = args[:mongodb_profile] if args.key?(:mongodb_profile) @mysql_profile = args[:mysql_profile] if args.key?(:mysql_profile) @name = args[:name] if args.key?(:name) @oracle_profile = args[:oracle_profile] if args.key?(:oracle_profile) @postgresql_profile = args[:postgresql_profile] if args.key?(:postgresql_profile) @private_connectivity = args[:private_connectivity] if args.key?(:private_connectivity) @salesforce_marketing_cloud_profile = args[:salesforce_marketing_cloud_profile] if args.key?(:salesforce_marketing_cloud_profile) @salesforce_profile = args[:salesforce_profile] if args.key?(:salesforce_profile) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @service_now_profile = args[:service_now_profile] if args.key?(:service_now_profile) @spanner_profile = args[:spanner_profile] if args.key?(:spanner_profile) @sql_server_profile = args[:sql_server_profile] if args.key?(:sql_server_profile) @static_service_ip_connectivity = args[:static_service_ip_connectivity] if args.key?(:static_service_ip_connectivity) @update_time = args[:update_time] if args.key?(:update_time) end |