Class: Google::Apis::DatastreamV1::ConnectionProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

A set of reusable connection configurations to be used as a source or destination for a stream.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConnectionProfile

Returns a new instance of ConnectionProfile.



563
564
565
# File 'lib/google/apis/datastream_v1/classes.rb', line 563

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigquery_profileGoogle::Apis::DatastreamV1::BigQueryProfile

Profile for connecting to a BigQuery destination. Corresponds to the JSON property bigqueryProfile



467
468
469
# File 'lib/google/apis/datastream_v1/classes.rb', line 467

def bigquery_profile
  @bigquery_profile
end

#create_timeString

Output only. The create time of the resource. Corresponds to the JSON property createTime

Returns:

  • (String)


472
473
474
# File 'lib/google/apis/datastream_v1/classes.rb', line 472

def create_time
  @create_time
end

#display_nameString

Required. Display name. Corresponds to the JSON property displayName

Returns:

  • (String)


477
478
479
# File 'lib/google/apis/datastream_v1/classes.rb', line 477

def display_name
  @display_name
end

#forward_ssh_connectivityGoogle::Apis::DatastreamV1::ForwardSshTunnelConnectivity

Forward SSH Tunnel connectivity. Corresponds to the JSON property forwardSshConnectivity



482
483
484
# File 'lib/google/apis/datastream_v1/classes.rb', line 482

def forward_ssh_connectivity
  @forward_ssh_connectivity
end

#gcs_profileGoogle::Apis::DatastreamV1::GcsProfile

Profile for connecting to a Cloud Storage destination. Corresponds to the JSON property gcsProfile



487
488
489
# File 'lib/google/apis/datastream_v1/classes.rb', line 487

def gcs_profile
  @gcs_profile
end

#labelsHash<String,String>

Labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


492
493
494
# File 'lib/google/apis/datastream_v1/classes.rb', line 492

def labels
  @labels
end

#mongodb_profileGoogle::Apis::DatastreamV1::MongodbProfile

Profile for connecting to a MongoDB source. Corresponds to the JSON property mongodbProfile



497
498
499
# File 'lib/google/apis/datastream_v1/classes.rb', line 497

def mongodb_profile
  @mongodb_profile
end

#mysql_profileGoogle::Apis::DatastreamV1::MysqlProfile

Profile for connecting to a MySQL source. Corresponds to the JSON property mysqlProfile



502
503
504
# File 'lib/google/apis/datastream_v1/classes.rb', line 502

def mysql_profile
  @mysql_profile
end

#nameString

Output only. Identifier. The resource's name. Corresponds to the JSON property name

Returns:

  • (String)


507
508
509
# File 'lib/google/apis/datastream_v1/classes.rb', line 507

def name
  @name
end

#oracle_profileGoogle::Apis::DatastreamV1::OracleProfile

Profile for connecting to an Oracle source. Corresponds to the JSON property oracleProfile



512
513
514
# File 'lib/google/apis/datastream_v1/classes.rb', line 512

def oracle_profile
  @oracle_profile
end

#postgresql_profileGoogle::Apis::DatastreamV1::PostgresqlProfile

Profile for connecting to a PostgreSQL source. Corresponds to the JSON property postgresqlProfile



517
518
519
# File 'lib/google/apis/datastream_v1/classes.rb', line 517

def postgresql_profile
  @postgresql_profile
end

#private_connectivityGoogle::Apis::DatastreamV1::PrivateConnectivity

Private Connectivity Corresponds to the JSON property privateConnectivity



522
523
524
# File 'lib/google/apis/datastream_v1/classes.rb', line 522

def private_connectivity
  @private_connectivity
end

#salesforce_profileGoogle::Apis::DatastreamV1::SalesforceProfile

Profile for connecting to a Salesforce source. Corresponds to the JSON property salesforceProfile



527
528
529
# File 'lib/google/apis/datastream_v1/classes.rb', line 527

def salesforce_profile
  @salesforce_profile
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


532
533
534
# File 'lib/google/apis/datastream_v1/classes.rb', line 532

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


538
539
540
# File 'lib/google/apis/datastream_v1/classes.rb', line 538

def satisfies_pzs
  @satisfies_pzs
end

#spanner_profileGoogle::Apis::DatastreamV1::SpannerProfile

Profile for connecting to a Spanner source. Corresponds to the JSON property spannerProfile



544
545
546
# File 'lib/google/apis/datastream_v1/classes.rb', line 544

def spanner_profile
  @spanner_profile
end

#sql_server_profileGoogle::Apis::DatastreamV1::SqlServerProfile

Profile for connecting to a SQLServer source. Corresponds to the JSON property sqlServerProfile



549
550
551
# File 'lib/google/apis/datastream_v1/classes.rb', line 549

def sql_server_profile
  @sql_server_profile
end

#static_service_ip_connectivityGoogle::Apis::DatastreamV1::StaticServiceIpConnectivity

Static IP address connectivity. Used when the source database is configured to allow incoming connections from the Datastream public IP addresses for the region specified in the connection profile. Corresponds to the JSON property staticServiceIpConnectivity



556
557
558
# File 'lib/google/apis/datastream_v1/classes.rb', line 556

def static_service_ip_connectivity
  @static_service_ip_connectivity
end

#update_timeString

Output only. The update time of the resource. Corresponds to the JSON property updateTime

Returns:

  • (String)


561
562
563
# File 'lib/google/apis/datastream_v1/classes.rb', line 561

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
# File 'lib/google/apis/datastream_v1/classes.rb', line 568

def update!(**args)
  @bigquery_profile = args[:bigquery_profile] if args.key?(:bigquery_profile)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @forward_ssh_connectivity = args[:forward_ssh_connectivity] if args.key?(:forward_ssh_connectivity)
  @gcs_profile = args[:gcs_profile] if args.key?(:gcs_profile)
  @labels = args[:labels] if args.key?(:labels)
  @mongodb_profile = args[:mongodb_profile] if args.key?(:mongodb_profile)
  @mysql_profile = args[:mysql_profile] if args.key?(:mysql_profile)
  @name = args[:name] if args.key?(:name)
  @oracle_profile = args[:oracle_profile] if args.key?(:oracle_profile)
  @postgresql_profile = args[:postgresql_profile] if args.key?(:postgresql_profile)
  @private_connectivity = args[:private_connectivity] if args.key?(:private_connectivity)
  @salesforce_profile = args[:salesforce_profile] if args.key?(:salesforce_profile)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @spanner_profile = args[:spanner_profile] if args.key?(:spanner_profile)
  @sql_server_profile = args[:sql_server_profile] if args.key?(:sql_server_profile)
  @static_service_ip_connectivity = args[:static_service_ip_connectivity] if args.key?(:static_service_ip_connectivity)
  @update_time = args[:update_time] if args.key?(:update_time)
end