Class: Google::Apis::DatastreamV1::ConnectionProfile
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1::ConnectionProfile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb
Overview
A set of reusable connection configurations to be used as a source or destination for a stream.
Instance Attribute Summary collapse
-
#bigquery_profile ⇒ Google::Apis::DatastreamV1::BigQueryProfile
Profile for connecting to a BigQuery destination.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#forward_ssh_connectivity ⇒ Google::Apis::DatastreamV1::ForwardSshTunnelConnectivity
Forward SSH Tunnel connectivity.
-
#gcs_profile ⇒ Google::Apis::DatastreamV1::GcsProfile
Profile for connecting to a Cloud Storage destination.
-
#labels ⇒ Hash<String,String>
Labels.
-
#mongodb_profile ⇒ Google::Apis::DatastreamV1::MongodbProfile
Profile for connecting to a MongoDB source.
-
#mysql_profile ⇒ Google::Apis::DatastreamV1::MysqlProfile
Profile for connecting to a MySQL source.
-
#name ⇒ String
Output only.
-
#oracle_profile ⇒ Google::Apis::DatastreamV1::OracleProfile
Profile for connecting to an Oracle source.
-
#postgresql_profile ⇒ Google::Apis::DatastreamV1::PostgresqlProfile
Profile for connecting to a PostgreSQL source.
-
#private_connectivity ⇒ Google::Apis::DatastreamV1::PrivateConnectivity
Private Connectivity Corresponds to the JSON property
privateConnectivity. -
#salesforce_profile ⇒ Google::Apis::DatastreamV1::SalesforceProfile
Profile for connecting to a Salesforce source.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#spanner_profile ⇒ Google::Apis::DatastreamV1::SpannerProfile
Profile for connecting to a Spanner source.
-
#sql_server_profile ⇒ Google::Apis::DatastreamV1::SqlServerProfile
Profile for connecting to a SQLServer source.
-
#static_service_ip_connectivity ⇒ Google::Apis::DatastreamV1::StaticServiceIpConnectivity
Static IP address connectivity.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConnectionProfile
constructor
A new instance of ConnectionProfile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConnectionProfile
Returns a new instance of ConnectionProfile.
557 558 559 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 557 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bigquery_profile ⇒ Google::Apis::DatastreamV1::BigQueryProfile
Profile for connecting to a BigQuery destination.
Corresponds to the JSON property bigqueryProfile
461 462 463 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 461 def bigquery_profile @bigquery_profile end |
#create_time ⇒ String
Output only. The create time of the resource.
Corresponds to the JSON property createTime
466 467 468 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 466 def create_time @create_time end |
#display_name ⇒ String
Required. Display name.
Corresponds to the JSON property displayName
471 472 473 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 471 def display_name @display_name end |
#forward_ssh_connectivity ⇒ Google::Apis::DatastreamV1::ForwardSshTunnelConnectivity
Forward SSH Tunnel connectivity.
Corresponds to the JSON property forwardSshConnectivity
476 477 478 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 476 def forward_ssh_connectivity @forward_ssh_connectivity end |
#gcs_profile ⇒ Google::Apis::DatastreamV1::GcsProfile
Profile for connecting to a Cloud Storage destination.
Corresponds to the JSON property gcsProfile
481 482 483 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 481 def gcs_profile @gcs_profile end |
#labels ⇒ Hash<String,String>
Labels.
Corresponds to the JSON property labels
486 487 488 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 486 def labels @labels end |
#mongodb_profile ⇒ Google::Apis::DatastreamV1::MongodbProfile
Profile for connecting to a MongoDB source.
Corresponds to the JSON property mongodbProfile
491 492 493 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 491 def mongodb_profile @mongodb_profile end |
#mysql_profile ⇒ Google::Apis::DatastreamV1::MysqlProfile
Profile for connecting to a MySQL source.
Corresponds to the JSON property mysqlProfile
496 497 498 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 496 def mysql_profile @mysql_profile end |
#name ⇒ String
Output only. Identifier. The resource's name.
Corresponds to the JSON property name
501 502 503 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 501 def name @name end |
#oracle_profile ⇒ Google::Apis::DatastreamV1::OracleProfile
Profile for connecting to an Oracle source.
Corresponds to the JSON property oracleProfile
506 507 508 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 506 def oracle_profile @oracle_profile end |
#postgresql_profile ⇒ Google::Apis::DatastreamV1::PostgresqlProfile
Profile for connecting to a PostgreSQL source.
Corresponds to the JSON property postgresqlProfile
511 512 513 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 511 def postgresql_profile @postgresql_profile end |
#private_connectivity ⇒ Google::Apis::DatastreamV1::PrivateConnectivity
Private Connectivity
Corresponds to the JSON property privateConnectivity
516 517 518 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 516 def private_connectivity @private_connectivity end |
#salesforce_profile ⇒ Google::Apis::DatastreamV1::SalesforceProfile
Profile for connecting to a Salesforce source.
Corresponds to the JSON property salesforceProfile
521 522 523 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 521 def salesforce_profile @salesforce_profile end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
526 527 528 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 526 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
532 533 534 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 532 def satisfies_pzs @satisfies_pzs end |
#spanner_profile ⇒ Google::Apis::DatastreamV1::SpannerProfile
Profile for connecting to a Spanner source.
Corresponds to the JSON property spannerProfile
538 539 540 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 538 def spanner_profile @spanner_profile end |
#sql_server_profile ⇒ Google::Apis::DatastreamV1::SqlServerProfile
Profile for connecting to a SQLServer source.
Corresponds to the JSON property sqlServerProfile
543 544 545 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 543 def sql_server_profile @sql_server_profile end |
#static_service_ip_connectivity ⇒ Google::Apis::DatastreamV1::StaticServiceIpConnectivity
Static IP address connectivity. Used when the source database is configured to
allow incoming connections from the Datastream public IP addresses for the
region specified in the connection profile.
Corresponds to the JSON property staticServiceIpConnectivity
550 551 552 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 550 def static_service_ip_connectivity @static_service_ip_connectivity end |
#update_time ⇒ String
Output only. The update time of the resource.
Corresponds to the JSON property updateTime
555 556 557 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 555 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 562 def update!(**args) @bigquery_profile = args[:bigquery_profile] if args.key?(:bigquery_profile) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @forward_ssh_connectivity = args[:forward_ssh_connectivity] if args.key?(:forward_ssh_connectivity) @gcs_profile = args[:gcs_profile] if args.key?(:gcs_profile) @labels = args[:labels] if args.key?(:labels) @mongodb_profile = args[:mongodb_profile] if args.key?(:mongodb_profile) @mysql_profile = args[:mysql_profile] if args.key?(:mysql_profile) @name = args[:name] if args.key?(:name) @oracle_profile = args[:oracle_profile] if args.key?(:oracle_profile) @postgresql_profile = args[:postgresql_profile] if args.key?(:postgresql_profile) @private_connectivity = args[:private_connectivity] if args.key?(:private_connectivity) @salesforce_profile = args[:salesforce_profile] if args.key?(:salesforce_profile) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @spanner_profile = args[:spanner_profile] if args.key?(:spanner_profile) @sql_server_profile = args[:sql_server_profile] if args.key?(:sql_server_profile) @static_service_ip_connectivity = args[:static_service_ip_connectivity] if args.key?(:static_service_ip_connectivity) @update_time = args[:update_time] if args.key?(:update_time) end |