Class: Google::Apis::DatastreamV1::ConnectionProfile
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1::ConnectionProfile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb
Overview
A set of reusable connection configurations to be used as a source or destination for a stream.
Instance Attribute Summary collapse
-
#bigquery_profile ⇒ Google::Apis::DatastreamV1::BigQueryProfile
BigQuery warehouse profile.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#forward_ssh_connectivity ⇒ Google::Apis::DatastreamV1::ForwardSshTunnelConnectivity
Forward SSH Tunnel connectivity.
-
#gcs_profile ⇒ Google::Apis::DatastreamV1::GcsProfile
Cloud Storage bucket profile.
-
#labels ⇒ Hash<String,String>
Labels.
-
#mongodb_profile ⇒ Google::Apis::DatastreamV1::MongodbProfile
MongoDB profile.
-
#mysql_profile ⇒ Google::Apis::DatastreamV1::MysqlProfile
MySQL database profile.
-
#name ⇒ String
Output only.
-
#oracle_profile ⇒ Google::Apis::DatastreamV1::OracleProfile
Oracle database profile.
-
#postgresql_profile ⇒ Google::Apis::DatastreamV1::PostgresqlProfile
PostgreSQL database profile.
-
#private_connectivity ⇒ Google::Apis::DatastreamV1::PrivateConnectivity
Private Connectivity Corresponds to the JSON property
privateConnectivity. -
#salesforce_profile ⇒ Google::Apis::DatastreamV1::SalesforceProfile
Salesforce profile Corresponds to the JSON property
salesforceProfile. -
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#sql_server_profile ⇒ Google::Apis::DatastreamV1::SqlServerProfile
SQLServer database profile.
-
#static_service_ip_connectivity ⇒ Google::Apis::DatastreamV1::StaticServiceIpConnectivity
Static IP address connectivity.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConnectionProfile
constructor
A new instance of ConnectionProfile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConnectionProfile
Returns a new instance of ConnectionProfile.
526 527 528 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 526 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bigquery_profile ⇒ Google::Apis::DatastreamV1::BigQueryProfile
BigQuery warehouse profile.
Corresponds to the JSON property bigqueryProfile
435 436 437 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 435 def bigquery_profile @bigquery_profile end |
#create_time ⇒ String
Output only. The create time of the resource.
Corresponds to the JSON property createTime
440 441 442 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 440 def create_time @create_time end |
#display_name ⇒ String
Required. Display name.
Corresponds to the JSON property displayName
445 446 447 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 445 def display_name @display_name end |
#forward_ssh_connectivity ⇒ Google::Apis::DatastreamV1::ForwardSshTunnelConnectivity
Forward SSH Tunnel connectivity.
Corresponds to the JSON property forwardSshConnectivity
450 451 452 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 450 def forward_ssh_connectivity @forward_ssh_connectivity end |
#gcs_profile ⇒ Google::Apis::DatastreamV1::GcsProfile
Cloud Storage bucket profile.
Corresponds to the JSON property gcsProfile
455 456 457 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 455 def gcs_profile @gcs_profile end |
#labels ⇒ Hash<String,String>
Labels.
Corresponds to the JSON property labels
460 461 462 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 460 def labels @labels end |
#mongodb_profile ⇒ Google::Apis::DatastreamV1::MongodbProfile
MongoDB profile.
Corresponds to the JSON property mongodbProfile
465 466 467 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 465 def mongodb_profile @mongodb_profile end |
#mysql_profile ⇒ Google::Apis::DatastreamV1::MysqlProfile
MySQL database profile.
Corresponds to the JSON property mysqlProfile
470 471 472 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 470 def mysql_profile @mysql_profile end |
#name ⇒ String
Output only. Identifier. The resource's name.
Corresponds to the JSON property name
475 476 477 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 475 def name @name end |
#oracle_profile ⇒ Google::Apis::DatastreamV1::OracleProfile
Oracle database profile.
Corresponds to the JSON property oracleProfile
480 481 482 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 480 def oracle_profile @oracle_profile end |
#postgresql_profile ⇒ Google::Apis::DatastreamV1::PostgresqlProfile
PostgreSQL database profile.
Corresponds to the JSON property postgresqlProfile
485 486 487 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 485 def postgresql_profile @postgresql_profile end |
#private_connectivity ⇒ Google::Apis::DatastreamV1::PrivateConnectivity
Private Connectivity
Corresponds to the JSON property privateConnectivity
490 491 492 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 490 def private_connectivity @private_connectivity end |
#salesforce_profile ⇒ Google::Apis::DatastreamV1::SalesforceProfile
Salesforce profile
Corresponds to the JSON property salesforceProfile
495 496 497 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 495 def salesforce_profile @salesforce_profile end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
500 501 502 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 500 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
506 507 508 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 506 def satisfies_pzs @satisfies_pzs end |
#sql_server_profile ⇒ Google::Apis::DatastreamV1::SqlServerProfile
SQLServer database profile.
Corresponds to the JSON property sqlServerProfile
512 513 514 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 512 def sql_server_profile @sql_server_profile end |
#static_service_ip_connectivity ⇒ Google::Apis::DatastreamV1::StaticServiceIpConnectivity
Static IP address connectivity. Used when the source database is configured to
allow incoming connections from the Datastream public IP addresses for the
region specified in the connection profile.
Corresponds to the JSON property staticServiceIpConnectivity
519 520 521 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 519 def static_service_ip_connectivity @static_service_ip_connectivity end |
#update_time ⇒ String
Output only. The update time of the resource.
Corresponds to the JSON property updateTime
524 525 526 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 524 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 531 def update!(**args) @bigquery_profile = args[:bigquery_profile] if args.key?(:bigquery_profile) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @forward_ssh_connectivity = args[:forward_ssh_connectivity] if args.key?(:forward_ssh_connectivity) @gcs_profile = args[:gcs_profile] if args.key?(:gcs_profile) @labels = args[:labels] if args.key?(:labels) @mongodb_profile = args[:mongodb_profile] if args.key?(:mongodb_profile) @mysql_profile = args[:mysql_profile] if args.key?(:mysql_profile) @name = args[:name] if args.key?(:name) @oracle_profile = args[:oracle_profile] if args.key?(:oracle_profile) @postgresql_profile = args[:postgresql_profile] if args.key?(:postgresql_profile) @private_connectivity = args[:private_connectivity] if args.key?(:private_connectivity) @salesforce_profile = args[:salesforce_profile] if args.key?(:salesforce_profile) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @sql_server_profile = args[:sql_server_profile] if args.key?(:sql_server_profile) @static_service_ip_connectivity = args[:static_service_ip_connectivity] if args.key?(:static_service_ip_connectivity) @update_time = args[:update_time] if args.key?(:update_time) end |