Class: Google::Apis::DatastreamV1::DatasetTemplate
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1::DatasetTemplate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb
Overview
Dataset template used for dynamic dataset creation.
Instance Attribute Summary collapse
-
#dataset_id_prefix ⇒ String
If supplied, every created dataset will have its name prefixed by the provided value.
-
#kms_key_name ⇒ String
Describes the Cloud KMS encryption key that will be used to protect destination BigQuery table.
-
#location ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DatasetTemplate
constructor
A new instance of DatasetTemplate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DatasetTemplate
Returns a new instance of DatasetTemplate.
672 673 674 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 672 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dataset_id_prefix ⇒ String
If supplied, every created dataset will have its name prefixed by the provided
value. The prefix and name will be separated by an underscore. i.e. _.
Corresponds to the JSON property datasetIdPrefix
654 655 656 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 654 def dataset_id_prefix @dataset_id_prefix end |
#kms_key_name ⇒ String
Describes the Cloud KMS encryption key that will be used to protect
destination BigQuery table. The BigQuery Service Account associated with your
project requires access to this encryption key. i.e. projects/project/
locations/location/keyRings/key_ring/cryptoKeys/cryptoKey. See https://
cloud.google.com/bigquery/docs/customer-managed-encryption for more
information.
Corresponds to the JSON property kmsKeyName
664 665 666 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 664 def kms_key_name @kms_key_name end |
#location ⇒ String
Required. The geographic location where the dataset should reside. See https://
cloud.google.com/bigquery/docs/locations for supported locations.
Corresponds to the JSON property location
670 671 672 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 670 def location @location end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
677 678 679 680 681 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 677 def update!(**args) @dataset_id_prefix = args[:dataset_id_prefix] if args.key?(:dataset_id_prefix) @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name) @location = args[:location] if args.key?(:location) end |