Class: Google::Apis::DatastreamV1::DatastreamService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::DatastreamV1::DatastreamService
- Defined in:
- lib/google/apis/datastream_v1/service.rb
Overview
Datastream API
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://datastream.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_connection_profile(parent, connection_profile_object = nil, connection_profile_id: nil, force: nil, request_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::Operation
Use this method to create a connection profile in a project and location.
-
#create_project_location_private_connection(parent, private_connection_object = nil, force: nil, private_connection_id: nil, request_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::Operation
Use this method to create a private connectivity configuration.
-
#create_project_location_private_connection_route(parent, route_object = nil, request_id: nil, route_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::Operation
Use this method to create a route for a private connectivity configuration in a project and location.
-
#create_project_location_stream(parent, stream_object = nil, force: nil, request_id: nil, stream_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::Operation
Use this method to create a stream.
-
#delete_project_location_connection_profile(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::Operation
Use this method to delete a connection profile.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::Empty
Deletes a long-running operation.
-
#delete_project_location_private_connection(name, force: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::Operation
Use this method to delete a private connectivity configuration.
-
#delete_project_location_private_connection_route(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::Operation
Use this method to delete a route.
-
#delete_project_location_stream(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::Operation
Use this method to delete a stream.
-
#discover_connection_profile(parent, discover_connection_profile_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::DiscoverConnectionProfileResponse
Use this method to discover a connection profile.
-
#fetch_project_location_static_ips(name, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::FetchStaticIpsResponse
The FetchStaticIps API call exposes the static IP addresses used by Datastream.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::Location
Gets information about a location.
-
#get_project_location_connection_profile(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::ConnectionProfile
Use this method to get details about a connection profile.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::Operation
Gets the latest state of a long-running operation.
-
#get_project_location_private_connection(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::PrivateConnection
Use this method to get details about a private connectivity configuration.
-
#get_project_location_private_connection_route(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::Route
Use this method to get details about a route.
-
#get_project_location_stream(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::Stream
Use this method to get details about a stream.
-
#get_project_location_stream_object(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::StreamObject
Use this method to get details about a stream object.
-
#initialize ⇒ DatastreamService
constructor
A new instance of DatastreamService.
-
#list_project_location_connection_profiles(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::ListConnectionProfilesResponse
Use this method to list connection profiles created in a project and location.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_location_private_connection_routes(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::ListRoutesResponse
Use this method to list routes created for a private connectivity configuration in a project and location.
-
#list_project_location_private_connections(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::ListPrivateConnectionsResponse
Use this method to list private connectivity configurations in a project and location.
-
#list_project_location_stream_objects(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::ListStreamObjectsResponse
Use this method to list the objects of a specific stream.
-
#list_project_location_streams(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::ListStreamsResponse
Use this method to list streams in a project and location.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#lookup_stream_object(parent, lookup_stream_object_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::StreamObject
Use this method to look up a stream object by its source object identifier.
-
#patch_project_location_connection_profile(name, connection_profile_object = nil, force: nil, request_id: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::Operation
Use this method to update the parameters of a connection profile.
-
#patch_project_location_stream(name, stream_object = nil, force: nil, request_id: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::Operation
Use this method to update the configuration of a stream.
-
#run_stream(name, run_stream_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::Operation
Use this method to start, resume or recover a stream with a non default CDC strategy.
-
#start_object_backfill_job(object, start_backfill_job_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::StartBackfillJobResponse
Use this method to start a backfill job for the specified stream object.
-
#stop_object_backfill_job(object, stop_backfill_job_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::StopBackfillJobResponse
Use this method to stop a backfill job for the specified stream object.
Constructor Details
#initialize ⇒ DatastreamService
Returns a new instance of DatastreamService.
47 48 49 50 51 52 |
# File 'lib/google/apis/datastream_v1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-datastream_v1', client_version: Google::Apis::DatastreamV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/datastream_v1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/datastream_v1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
467 468 469 470 471 472 473 474 475 476 477 |
# File 'lib/google/apis/datastream_v1/service.rb', line 467 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:cancel', ) command.request_representation = Google::Apis::DatastreamV1::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::DatastreamV1::Empty::Representation command.response_class = Google::Apis::DatastreamV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_connection_profile(parent, connection_profile_object = nil, connection_profile_id: nil, force: nil, request_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::Operation
Use this method to create a connection profile in a project and location.
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/google/apis/datastream_v1/service.rb', line 208 def create_project_location_connection_profile(parent, connection_profile_object = nil, connection_profile_id: nil, force: nil, request_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/connectionProfiles', ) command.request_representation = Google::Apis::DatastreamV1::ConnectionProfile::Representation command.request_object = connection_profile_object command.response_representation = Google::Apis::DatastreamV1::Operation::Representation command.response_class = Google::Apis::DatastreamV1::Operation command.params['parent'] = parent unless parent.nil? command.query['connectionProfileId'] = connection_profile_id unless connection_profile_id.nil? command.query['force'] = force unless force.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_private_connection(parent, private_connection_object = nil, force: nil, private_connection_id: nil, request_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::Operation
Use this method to create a private connectivity configuration.
632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 |
# File 'lib/google/apis/datastream_v1/service.rb', line 632 def create_project_location_private_connection(parent, private_connection_object = nil, force: nil, private_connection_id: nil, request_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/privateConnections', ) command.request_representation = Google::Apis::DatastreamV1::PrivateConnection::Representation command.request_object = private_connection_object command.response_representation = Google::Apis::DatastreamV1::Operation::Representation command.response_class = Google::Apis::DatastreamV1::Operation command.params['parent'] = parent unless parent.nil? command.query['force'] = force unless force.nil? command.query['privateConnectionId'] = private_connection_id unless private_connection_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_private_connection_route(parent, route_object = nil, request_id: nil, route_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::Operation
Use this method to create a route for a private connectivity configuration in a project and location.
808 809 810 811 812 813 814 815 816 817 818 819 820 |
# File 'lib/google/apis/datastream_v1/service.rb', line 808 def create_project_location_private_connection_route(parent, route_object = nil, request_id: nil, route_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/routes', ) command.request_representation = Google::Apis::DatastreamV1::Route::Representation command.request_object = route_object command.response_representation = Google::Apis::DatastreamV1::Operation::Representation command.response_class = Google::Apis::DatastreamV1::Operation command.params['parent'] = parent unless parent.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['routeId'] = route_id unless route_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_stream(parent, stream_object = nil, force: nil, request_id: nil, stream_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::Operation
Use this method to create a stream.
980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 |
# File 'lib/google/apis/datastream_v1/service.rb', line 980 def create_project_location_stream(parent, stream_object = nil, force: nil, request_id: nil, stream_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/streams', ) command.request_representation = Google::Apis::DatastreamV1::Stream::Representation command.request_object = stream_object command.response_representation = Google::Apis::DatastreamV1::Operation::Representation command.response_class = Google::Apis::DatastreamV1::Operation command.params['parent'] = parent unless parent.nil? command.query['force'] = force unless force.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['streamId'] = stream_id unless stream_id.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_connection_profile(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::Operation
Use this method to delete a connection profile.
255 256 257 258 259 260 261 262 263 264 |
# File 'lib/google/apis/datastream_v1/service.rb', line 255 def delete_project_location_connection_profile(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::DatastreamV1::Operation::Representation command.response_class = Google::Apis::DatastreamV1::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
502 503 504 505 506 507 508 509 510 |
# File 'lib/google/apis/datastream_v1/service.rb', line 502 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::DatastreamV1::Empty::Representation command.response_class = Google::Apis::DatastreamV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_private_connection(name, force: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::Operation
Use this method to delete a private connectivity configuration.
682 683 684 685 686 687 688 689 690 691 692 |
# File 'lib/google/apis/datastream_v1/service.rb', line 682 def delete_project_location_private_connection(name, force: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::DatastreamV1::Operation::Representation command.response_class = Google::Apis::DatastreamV1::Operation command.params['name'] = name unless name.nil? command.query['force'] = force unless force.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_private_connection_route(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::Operation
Use this method to delete a route.
853 854 855 856 857 858 859 860 861 862 |
# File 'lib/google/apis/datastream_v1/service.rb', line 853 def delete_project_location_private_connection_route(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::DatastreamV1::Operation::Representation command.response_class = Google::Apis::DatastreamV1::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_stream(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::Operation
Use this method to delete a stream.
1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 |
# File 'lib/google/apis/datastream_v1/service.rb', line 1027 def delete_project_location_stream(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::DatastreamV1::Operation::Representation command.response_class = Google::Apis::DatastreamV1::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#discover_connection_profile(parent, discover_connection_profile_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::DiscoverConnectionProfileResponse
Use this method to discover a connection profile. The discover API call exposes the data objects and metadata belonging to the profile. Typically, a request returns children data objects of a parent data object that's optionally supplied in the request.
291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/google/apis/datastream_v1/service.rb', line 291 def discover_connection_profile(parent, discover_connection_profile_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/connectionProfiles:discover', ) command.request_representation = Google::Apis::DatastreamV1::DiscoverConnectionProfileRequest::Representation command.request_object = discover_connection_profile_request_object command.response_representation = Google::Apis::DatastreamV1::DiscoverConnectionProfileResponse::Representation command.response_class = Google::Apis::DatastreamV1::DiscoverConnectionProfileResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#fetch_project_location_static_ips(name, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::FetchStaticIpsResponse
The FetchStaticIps API call exposes the static IP addresses used by Datastream.
80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/google/apis/datastream_v1/service.rb', line 80 def fetch_project_location_static_ips(name, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}:fetchStaticIps', ) command.response_representation = Google::Apis::DatastreamV1::FetchStaticIpsResponse::Representation command.response_class = Google::Apis::DatastreamV1::FetchStaticIpsResponse command.params['name'] = name unless name.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::Location
Gets information about a location.
112 113 114 115 116 117 118 119 120 |
# File 'lib/google/apis/datastream_v1/service.rb', line 112 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::DatastreamV1::Location::Representation command.response_class = Google::Apis::DatastreamV1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_connection_profile(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::ConnectionProfile
Use this method to get details about a connection profile.
323 324 325 326 327 328 329 330 331 |
# File 'lib/google/apis/datastream_v1/service.rb', line 323 def get_project_location_connection_profile(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::DatastreamV1::ConnectionProfile::Representation command.response_class = Google::Apis::DatastreamV1::ConnectionProfile command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
533 534 535 536 537 538 539 540 541 |
# File 'lib/google/apis/datastream_v1/service.rb', line 533 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::DatastreamV1::Operation::Representation command.response_class = Google::Apis::DatastreamV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_private_connection(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::PrivateConnection
Use this method to get details about a private connectivity configuration.
714 715 716 717 718 719 720 721 722 |
# File 'lib/google/apis/datastream_v1/service.rb', line 714 def get_project_location_private_connection(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::DatastreamV1::PrivateConnection::Representation command.response_class = Google::Apis::DatastreamV1::PrivateConnection command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_private_connection_route(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::Route
Use this method to get details about a route.
884 885 886 887 888 889 890 891 892 |
# File 'lib/google/apis/datastream_v1/service.rb', line 884 def get_project_location_private_connection_route(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::DatastreamV1::Route::Representation command.response_class = Google::Apis::DatastreamV1::Route command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_stream(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::Stream
Use this method to get details about a stream.
1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/google/apis/datastream_v1/service.rb', line 1058 def get_project_location_stream(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::DatastreamV1::Stream::Representation command.response_class = Google::Apis::DatastreamV1::Stream command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_stream_object(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::StreamObject
Use this method to get details about a stream object.
1228 1229 1230 1231 1232 1233 1234 1235 1236 |
# File 'lib/google/apis/datastream_v1/service.rb', line 1228 def get_project_location_stream_object(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::DatastreamV1::StreamObject::Representation command.response_class = Google::Apis::DatastreamV1::StreamObject command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_connection_profiles(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::ListConnectionProfilesResponse
Use this method to list connection profiles created in a project and location.
366 367 368 369 370 371 372 373 374 375 376 377 378 |
# File 'lib/google/apis/datastream_v1/service.rb', line 366 def list_project_location_connection_profiles(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/connectionProfiles', ) command.response_representation = Google::Apis::DatastreamV1::ListConnectionProfilesResponse::Representation command.response_class = Google::Apis::DatastreamV1::ListConnectionProfilesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
578 579 580 581 582 583 584 585 586 587 588 589 590 |
# File 'lib/google/apis/datastream_v1/service.rb', line 578 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/operations', ) command.response_representation = Google::Apis::DatastreamV1::ListOperationsResponse::Representation command.response_class = Google::Apis::DatastreamV1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_private_connection_routes(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::ListRoutesResponse
Use this method to list routes created for a private connectivity configuration in a project and location.
927 928 929 930 931 932 933 934 935 936 937 938 939 |
# File 'lib/google/apis/datastream_v1/service.rb', line 927 def list_project_location_private_connection_routes(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/routes', ) command.response_representation = Google::Apis::DatastreamV1::ListRoutesResponse::Representation command.response_class = Google::Apis::DatastreamV1::ListRoutesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_private_connections(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::ListPrivateConnectionsResponse
Use this method to list private connectivity configurations in a project and location.
759 760 761 762 763 764 765 766 767 768 769 770 771 |
# File 'lib/google/apis/datastream_v1/service.rb', line 759 def list_project_location_private_connections(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/privateConnections', ) command.response_representation = Google::Apis::DatastreamV1::ListPrivateConnectionsResponse::Representation command.response_class = Google::Apis::DatastreamV1::ListPrivateConnectionsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_stream_objects(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::ListStreamObjectsResponse
Use this method to list the objects of a specific stream.
1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 |
# File 'lib/google/apis/datastream_v1/service.rb', line 1266 def list_project_location_stream_objects(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/objects', ) command.response_representation = Google::Apis::DatastreamV1::ListStreamObjectsResponse::Representation command.response_class = Google::Apis::DatastreamV1::ListStreamObjectsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_streams(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::ListStreamsResponse
Use this method to list streams in a project and location.
1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 |
# File 'lib/google/apis/datastream_v1/service.rb', line 1100 def list_project_location_streams(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/streams', ) command.response_representation = Google::Apis::DatastreamV1::ListStreamsResponse::Representation command.response_class = Google::Apis::DatastreamV1::ListStreamsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::ListLocationsResponse
Lists information about the supported locations for this service.
155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/google/apis/datastream_v1/service.rb', line 155 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/locations', ) command.response_representation = Google::Apis::DatastreamV1::ListLocationsResponse::Representation command.response_class = Google::Apis::DatastreamV1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#lookup_stream_object(parent, lookup_stream_object_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::StreamObject
Use this method to look up a stream object by its source object identifier.
1299 1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 |
# File 'lib/google/apis/datastream_v1/service.rb', line 1299 def lookup_stream_object(parent, lookup_stream_object_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/objects:lookup', ) command.request_representation = Google::Apis::DatastreamV1::LookupStreamObjectRequest::Representation command.request_object = lookup_stream_object_request_object command.response_representation = Google::Apis::DatastreamV1::StreamObject::Representation command.response_class = Google::Apis::DatastreamV1::StreamObject command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_connection_profile(name, connection_profile_object = nil, force: nil, request_id: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::Operation
Use this method to update the parameters of a connection profile.
423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 |
# File 'lib/google/apis/datastream_v1/service.rb', line 423 def patch_project_location_connection_profile(name, connection_profile_object = nil, force: nil, request_id: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::DatastreamV1::ConnectionProfile::Representation command.request_object = connection_profile_object command.response_representation = Google::Apis::DatastreamV1::Operation::Representation command.response_class = Google::Apis::DatastreamV1::Operation command.params['name'] = name unless name.nil? command.query['force'] = force unless force.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_stream(name, stream_object = nil, force: nil, request_id: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::Operation
Use this method to update the configuration of a stream.
1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 |
# File 'lib/google/apis/datastream_v1/service.rb', line 1157 def patch_project_location_stream(name, stream_object = nil, force: nil, request_id: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::DatastreamV1::Stream::Representation command.request_object = stream_object command.response_representation = Google::Apis::DatastreamV1::Operation::Representation command.response_class = Google::Apis::DatastreamV1::Operation command.params['name'] = name unless name.nil? command.query['force'] = force unless force.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#run_stream(name, run_stream_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::Operation
Use this method to start, resume or recover a stream with a non default CDC strategy.
1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 |
# File 'lib/google/apis/datastream_v1/service.rb', line 1196 def run_stream(name, run_stream_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:run', ) command.request_representation = Google::Apis::DatastreamV1::RunStreamRequest::Representation command.request_object = run_stream_request_object command.response_representation = Google::Apis::DatastreamV1::Operation::Representation command.response_class = Google::Apis::DatastreamV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#start_object_backfill_job(object, start_backfill_job_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::StartBackfillJobResponse
Use this method to start a backfill job for the specified stream object.
1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 |
# File 'lib/google/apis/datastream_v1/service.rb', line 1332 def start_object_backfill_job(object, start_backfill_job_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+object}:startBackfillJob', ) command.request_representation = Google::Apis::DatastreamV1::StartBackfillJobRequest::Representation command.request_object = start_backfill_job_request_object command.response_representation = Google::Apis::DatastreamV1::StartBackfillJobResponse::Representation command.response_class = Google::Apis::DatastreamV1::StartBackfillJobResponse command.params['object'] = object unless object.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#stop_object_backfill_job(object, stop_backfill_job_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatastreamV1::StopBackfillJobResponse
Use this method to stop a backfill job for the specified stream object.
1365 1366 1367 1368 1369 1370 1371 1372 1373 1374 1375 |
# File 'lib/google/apis/datastream_v1/service.rb', line 1365 def stop_object_backfill_job(object, stop_backfill_job_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+object}:stopBackfillJob', ) command.request_representation = Google::Apis::DatastreamV1::StopBackfillJobRequest::Representation command.request_object = stop_backfill_job_request_object command.response_representation = Google::Apis::DatastreamV1::StopBackfillJobResponse::Representation command.response_class = Google::Apis::DatastreamV1::StopBackfillJobResponse command.params['object'] = object unless object.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |