Class: Google::Apis::DatastreamV1::DiscoverConnectionProfileRequest
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1::DiscoverConnectionProfileRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb
Overview
Request message for 'discover' ConnectionProfile request.
Instance Attribute Summary collapse
-
#connection_profile ⇒ Google::Apis::DatastreamV1::ConnectionProfile
A set of reusable connection configurations to be used as a source or destination for a stream.
-
#connection_profile_name ⇒ String
Optional.
-
#full_hierarchy ⇒ Boolean
(also: #full_hierarchy?)
Optional.
-
#hierarchy_depth ⇒ Fixnum
Optional.
-
#mongodb_cluster ⇒ Google::Apis::DatastreamV1::MongodbCluster
MongoDB Cluster structure.
-
#mysql_rdbms ⇒ Google::Apis::DatastreamV1::MysqlRdbms
MySQL database structure Corresponds to the JSON property
mysqlRdbms. -
#oracle_rdbms ⇒ Google::Apis::DatastreamV1::OracleRdbms
Oracle database structure.
-
#postgresql_rdbms ⇒ Google::Apis::DatastreamV1::PostgresqlRdbms
PostgreSQL database structure.
-
#salesforce_org ⇒ Google::Apis::DatastreamV1::SalesforceOrg
Salesforce organization structure.
-
#spanner_database ⇒ Google::Apis::DatastreamV1::SpannerDatabase
Spanner database structure.
-
#sql_server_rdbms ⇒ Google::Apis::DatastreamV1::SqlServerRdbms
SQLServer database structure.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiscoverConnectionProfileRequest
constructor
A new instance of DiscoverConnectionProfileRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiscoverConnectionProfileRequest
Returns a new instance of DiscoverConnectionProfileRequest.
768 769 770 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 768 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connection_profile ⇒ Google::Apis::DatastreamV1::ConnectionProfile
A set of reusable connection configurations to be used as a source or
destination for a stream.
Corresponds to the JSON property connectionProfile
713 714 715 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 713 def connection_profile @connection_profile end |
#connection_profile_name ⇒ String
Optional. A reference to an existing connection profile.
Corresponds to the JSON property connectionProfileName
718 719 720 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 718 def connection_profile_name @connection_profile_name end |
#full_hierarchy ⇒ Boolean Also known as: full_hierarchy?
Optional. Whether to retrieve the full hierarchy of data objects (TRUE) or
only the current level (FALSE).
Corresponds to the JSON property fullHierarchy
724 725 726 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 724 def full_hierarchy @full_hierarchy end |
#hierarchy_depth ⇒ Fixnum
Optional. The number of hierarchy levels below the current level to be
retrieved.
Corresponds to the JSON property hierarchyDepth
731 732 733 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 731 def hierarchy_depth @hierarchy_depth end |
#mongodb_cluster ⇒ Google::Apis::DatastreamV1::MongodbCluster
MongoDB Cluster structure.
Corresponds to the JSON property mongodbCluster
736 737 738 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 736 def mongodb_cluster @mongodb_cluster end |
#mysql_rdbms ⇒ Google::Apis::DatastreamV1::MysqlRdbms
MySQL database structure
Corresponds to the JSON property mysqlRdbms
741 742 743 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 741 def mysql_rdbms @mysql_rdbms end |
#oracle_rdbms ⇒ Google::Apis::DatastreamV1::OracleRdbms
Oracle database structure.
Corresponds to the JSON property oracleRdbms
746 747 748 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 746 def oracle_rdbms @oracle_rdbms end |
#postgresql_rdbms ⇒ Google::Apis::DatastreamV1::PostgresqlRdbms
PostgreSQL database structure.
Corresponds to the JSON property postgresqlRdbms
751 752 753 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 751 def postgresql_rdbms @postgresql_rdbms end |
#salesforce_org ⇒ Google::Apis::DatastreamV1::SalesforceOrg
Salesforce organization structure.
Corresponds to the JSON property salesforceOrg
756 757 758 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 756 def salesforce_org @salesforce_org end |
#spanner_database ⇒ Google::Apis::DatastreamV1::SpannerDatabase
Spanner database structure.
Corresponds to the JSON property spannerDatabase
761 762 763 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 761 def spanner_database @spanner_database end |
#sql_server_rdbms ⇒ Google::Apis::DatastreamV1::SqlServerRdbms
SQLServer database structure.
Corresponds to the JSON property sqlServerRdbms
766 767 768 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 766 def sql_server_rdbms @sql_server_rdbms end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
773 774 775 776 777 778 779 780 781 782 783 784 785 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 773 def update!(**args) @connection_profile = args[:connection_profile] if args.key?(:connection_profile) @connection_profile_name = args[:connection_profile_name] if args.key?(:connection_profile_name) @full_hierarchy = args[:full_hierarchy] if args.key?(:full_hierarchy) @hierarchy_depth = args[:hierarchy_depth] if args.key?(:hierarchy_depth) @mongodb_cluster = args[:mongodb_cluster] if args.key?(:mongodb_cluster) @mysql_rdbms = args[:mysql_rdbms] if args.key?(:mysql_rdbms) @oracle_rdbms = args[:oracle_rdbms] if args.key?(:oracle_rdbms) @postgresql_rdbms = args[:postgresql_rdbms] if args.key?(:postgresql_rdbms) @salesforce_org = args[:salesforce_org] if args.key?(:salesforce_org) @spanner_database = args[:spanner_database] if args.key?(:spanner_database) @sql_server_rdbms = args[:sql_server_rdbms] if args.key?(:sql_server_rdbms) end |