Class: Google::Apis::DatastreamV1::DiscoverConnectionProfileRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

Request message for 'discover' ConnectionProfile request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiscoverConnectionProfileRequest

Returns a new instance of DiscoverConnectionProfileRequest.



706
707
708
# File 'lib/google/apis/datastream_v1/classes.rb', line 706

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connection_profileGoogle::Apis::DatastreamV1::ConnectionProfile

A set of reusable connection configurations to be used as a source or destination for a stream. Corresponds to the JSON property connectionProfile



656
657
658
# File 'lib/google/apis/datastream_v1/classes.rb', line 656

def connection_profile
  @connection_profile
end

#connection_profile_nameString

Optional. A reference to an existing connection profile. Corresponds to the JSON property connectionProfileName

Returns:

  • (String)


661
662
663
# File 'lib/google/apis/datastream_v1/classes.rb', line 661

def connection_profile_name
  @connection_profile_name
end

#full_hierarchyBoolean Also known as: full_hierarchy?

Optional. Whether to retrieve the full hierarchy of data objects (TRUE) or only the current level (FALSE). Corresponds to the JSON property fullHierarchy

Returns:

  • (Boolean)


667
668
669
# File 'lib/google/apis/datastream_v1/classes.rb', line 667

def full_hierarchy
  @full_hierarchy
end

#hierarchy_depthFixnum

Optional. The number of hierarchy levels below the current level to be retrieved. Corresponds to the JSON property hierarchyDepth

Returns:

  • (Fixnum)


674
675
676
# File 'lib/google/apis/datastream_v1/classes.rb', line 674

def hierarchy_depth
  @hierarchy_depth
end

#mongodb_clusterGoogle::Apis::DatastreamV1::MongodbCluster

MongoDB Cluster structure. Corresponds to the JSON property mongodbCluster



679
680
681
# File 'lib/google/apis/datastream_v1/classes.rb', line 679

def mongodb_cluster
  @mongodb_cluster
end

#mysql_rdbmsGoogle::Apis::DatastreamV1::MysqlRdbms

MySQL database structure Corresponds to the JSON property mysqlRdbms



684
685
686
# File 'lib/google/apis/datastream_v1/classes.rb', line 684

def mysql_rdbms
  @mysql_rdbms
end

#oracle_rdbmsGoogle::Apis::DatastreamV1::OracleRdbms

Oracle database structure. Corresponds to the JSON property oracleRdbms



689
690
691
# File 'lib/google/apis/datastream_v1/classes.rb', line 689

def oracle_rdbms
  @oracle_rdbms
end

#postgresql_rdbmsGoogle::Apis::DatastreamV1::PostgresqlRdbms

PostgreSQL database structure. Corresponds to the JSON property postgresqlRdbms



694
695
696
# File 'lib/google/apis/datastream_v1/classes.rb', line 694

def postgresql_rdbms
  @postgresql_rdbms
end

#salesforce_orgGoogle::Apis::DatastreamV1::SalesforceOrg

Salesforce organization structure. Corresponds to the JSON property salesforceOrg



699
700
701
# File 'lib/google/apis/datastream_v1/classes.rb', line 699

def salesforce_org
  @salesforce_org
end

#sql_server_rdbmsGoogle::Apis::DatastreamV1::SqlServerRdbms

SQLServer database structure. Corresponds to the JSON property sqlServerRdbms



704
705
706
# File 'lib/google/apis/datastream_v1/classes.rb', line 704

def sql_server_rdbms
  @sql_server_rdbms
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



711
712
713
714
715
716
717
718
719
720
721
722
# File 'lib/google/apis/datastream_v1/classes.rb', line 711

def update!(**args)
  @connection_profile = args[:connection_profile] if args.key?(:connection_profile)
  @connection_profile_name = args[:connection_profile_name] if args.key?(:connection_profile_name)
  @full_hierarchy = args[:full_hierarchy] if args.key?(:full_hierarchy)
  @hierarchy_depth = args[:hierarchy_depth] if args.key?(:hierarchy_depth)
  @mongodb_cluster = args[:mongodb_cluster] if args.key?(:mongodb_cluster)
  @mysql_rdbms = args[:mysql_rdbms] if args.key?(:mysql_rdbms)
  @oracle_rdbms = args[:oracle_rdbms] if args.key?(:oracle_rdbms)
  @postgresql_rdbms = args[:postgresql_rdbms] if args.key?(:postgresql_rdbms)
  @salesforce_org = args[:salesforce_org] if args.key?(:salesforce_org)
  @sql_server_rdbms = args[:sql_server_rdbms] if args.key?(:sql_server_rdbms)
end