Class: Google::Apis::DatastreamV1::EncryptionAndServerValidation
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1::EncryptionAndServerValidation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb
Overview
Message to represent the option where Datastream will enforce encryption and authenticate server identity. ca_certificate must be set if user selects this option.
Instance Attribute Summary collapse
-
#ca_certificate ⇒ String
Optional.
-
#server_certificate_hostname ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EncryptionAndServerValidation
constructor
A new instance of EncryptionAndServerValidation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EncryptionAndServerValidation
Returns a new instance of EncryptionAndServerValidation.
895 896 897 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 895 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ca_certificate ⇒ String
Optional. Input only. PEM-encoded certificate of the CA that signed the source
database server's certificate.
Corresponds to the JSON property caCertificate
882 883 884 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 882 def ca_certificate @ca_certificate end |
#server_certificate_hostname ⇒ String
Optional. The hostname mentioned in the Subject or SAN extension of the server
certificate. This field is used for bypassing the hostname validation while
verifying server certificate. This is required for scenarios where the host
name that datastream connects to is different from the certificate's subject.
This specifically happens for private connectivity. It could also happen when
the customer provides a public IP in connection profile but the same is not
present in the server certificate.
Corresponds to the JSON property serverCertificateHostname
893 894 895 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 893 def server_certificate_hostname @server_certificate_hostname end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
900 901 902 903 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 900 def update!(**args) @ca_certificate = args[:ca_certificate] if args.key?(:ca_certificate) @server_certificate_hostname = args[:server_certificate_hostname] if args.key?(:server_certificate_hostname) end |