Class: Google::Apis::DatastreamV1::LocalizedMessage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

Provides a localized error message that is safe to return to the user which can be attached to an RPC error.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LocalizedMessage

Returns a new instance of LocalizedMessage.



1627
1628
1629
# File 'lib/google/apis/datastream_v1/classes.rb', line 1627

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#localeString

The locale used following the specification defined at https://www.rfc-editor. org/rfc/bcp/bcp47.txt. Examples are: "en-US", "fr-CH", "es-MX" Corresponds to the JSON property locale

Returns:

  • (String)


1620
1621
1622
# File 'lib/google/apis/datastream_v1/classes.rb', line 1620

def locale
  @locale
end

#messageString

The localized error message in the above locale. Corresponds to the JSON property message

Returns:

  • (String)


1625
1626
1627
# File 'lib/google/apis/datastream_v1/classes.rb', line 1625

def message
  @message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1632
1633
1634
1635
# File 'lib/google/apis/datastream_v1/classes.rb', line 1632

def update!(**args)
  @locale = args[:locale] if args.key?(:locale)
  @message = args[:message] if args.key?(:message)
end