Class: Google::Apis::DatastreamV1::MongodbProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

Profile for connecting to a MongoDB source.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MongodbProfile

Returns a new instance of MongodbProfile.



1956
1957
1958
# File 'lib/google/apis/datastream_v1/classes.rb', line 1956

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_optionsHash<String,String>

Optional. Specifies additional options for the MongoDB connection. The options should be sent as key-value pairs, for example: additional_options =" serverSelectionTimeoutMS": "10000", "directConnection": "true"`. Keys are case-sensitive and should match the official MongoDB connection string options: https://www.mongodb.com/docs/manual/reference/connection-string-options/ The server will not modify the values provided by the user. Corresponds to the JSON propertyadditionalOptions`

Returns:

  • (Hash<String,String>)


1907
1908
1909
# File 'lib/google/apis/datastream_v1/classes.rb', line 1907

def additional_options
  @additional_options
end

#host_addressesArray<Google::Apis::DatastreamV1::HostAddress>

Required. List of host addresses for a MongoDB cluster. For SRV connection format, this list must contain exactly one DNS host without a port. For Standard connection format, this list must contain all the required hosts in the cluster with their respective ports. Corresponds to the JSON property hostAddresses



1915
1916
1917
# File 'lib/google/apis/datastream_v1/classes.rb', line 1915

def host_addresses
  @host_addresses
end

#passwordString

Optional. Password for the MongoDB connection. Mutually exclusive with the secret_manager_stored_password field. Corresponds to the JSON property password

Returns:

  • (String)


1921
1922
1923
# File 'lib/google/apis/datastream_v1/classes.rb', line 1921

def password
  @password
end

#replica_setString

Optional. Name of the replica set. Only needed for self hosted replica set type MongoDB cluster. For SRV connection format, this field must be empty. For Standard connection format, this field must be specified. Corresponds to the JSON property replicaSet

Returns:

  • (String)


1928
1929
1930
# File 'lib/google/apis/datastream_v1/classes.rb', line 1928

def replica_set
  @replica_set
end

#secret_manager_stored_passwordString

Optional. A reference to a Secret Manager resource name storing the SQLServer connection password. Mutually exclusive with the password field. Corresponds to the JSON property secretManagerStoredPassword

Returns:

  • (String)


1934
1935
1936
# File 'lib/google/apis/datastream_v1/classes.rb', line 1934

def secret_manager_stored_password
  @secret_manager_stored_password
end

#srv_connection_formatGoogle::Apis::DatastreamV1::SrvConnectionFormat

Srv connection format. Corresponds to the JSON property srvConnectionFormat



1939
1940
1941
# File 'lib/google/apis/datastream_v1/classes.rb', line 1939

def srv_connection_format
  @srv_connection_format
end

#ssl_configGoogle::Apis::DatastreamV1::MongodbSslConfig

MongoDB SSL configuration information. Corresponds to the JSON property sslConfig



1944
1945
1946
# File 'lib/google/apis/datastream_v1/classes.rb', line 1944

def ssl_config
  @ssl_config
end

#standard_connection_formatGoogle::Apis::DatastreamV1::StandardConnectionFormat

Standard connection format. Corresponds to the JSON property standardConnectionFormat



1949
1950
1951
# File 'lib/google/apis/datastream_v1/classes.rb', line 1949

def standard_connection_format
  @standard_connection_format
end

#usernameString

Required. Username for the MongoDB connection. Corresponds to the JSON property username

Returns:

  • (String)


1954
1955
1956
# File 'lib/google/apis/datastream_v1/classes.rb', line 1954

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
# File 'lib/google/apis/datastream_v1/classes.rb', line 1961

def update!(**args)
  @additional_options = args[:additional_options] if args.key?(:additional_options)
  @host_addresses = args[:host_addresses] if args.key?(:host_addresses)
  @password = args[:password] if args.key?(:password)
  @replica_set = args[:replica_set] if args.key?(:replica_set)
  @secret_manager_stored_password = args[:secret_manager_stored_password] if args.key?(:secret_manager_stored_password)
  @srv_connection_format = args[:srv_connection_format] if args.key?(:srv_connection_format)
  @ssl_config = args[:ssl_config] if args.key?(:ssl_config)
  @standard_connection_format = args[:standard_connection_format] if args.key?(:standard_connection_format)
  @username = args[:username] if args.key?(:username)
end