Class: Google::Apis::DatastreamV1::MongodbProfile
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1::MongodbProfile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb
Overview
Profile for connecting to a MongoDB source.
Instance Attribute Summary collapse
-
#additional_options ⇒ Hash<String,String>
Optional.
-
#host_addresses ⇒ Array<Google::Apis::DatastreamV1::HostAddress>
Required.
-
#password ⇒ String
Optional.
-
#replica_set ⇒ String
Optional.
-
#secret_manager_stored_password ⇒ String
Optional.
-
#srv_connection_format ⇒ Google::Apis::DatastreamV1::SrvConnectionFormat
Srv connection format.
-
#ssl_config ⇒ Google::Apis::DatastreamV1::MongodbSslConfig
MongoDB SSL configuration information.
-
#standard_connection_format ⇒ Google::Apis::DatastreamV1::StandardConnectionFormat
Standard connection format.
-
#username ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MongodbProfile
constructor
A new instance of MongodbProfile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MongodbProfile
Returns a new instance of MongodbProfile.
1950 1951 1952 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 1950 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_options ⇒ Hash<String,String>
Optional. Specifies additional options for the MongoDB connection. The options
should be sent as key-value pairs, for example: additional_options ="
serverSelectionTimeoutMS": "10000", "directConnection": "true"`. Keys are
case-sensitive and should match the official MongoDB connection string options:
https://www.mongodb.com/docs/manual/reference/connection-string-options/ The
server will not modify the values provided by the user.
Corresponds to the JSON propertyadditionalOptions`
1901 1902 1903 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 1901 def @additional_options end |
#host_addresses ⇒ Array<Google::Apis::DatastreamV1::HostAddress>
Required. List of host addresses for a MongoDB cluster. For SRV connection
format, this list must contain exactly one DNS host without a port. For
Standard connection format, this list must contain all the required hosts in
the cluster with their respective ports.
Corresponds to the JSON property hostAddresses
1909 1910 1911 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 1909 def host_addresses @host_addresses end |
#password ⇒ String
Optional. Password for the MongoDB connection. Mutually exclusive with the
secret_manager_stored_password field.
Corresponds to the JSON property password
1915 1916 1917 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 1915 def password @password end |
#replica_set ⇒ String
Optional. Name of the replica set. Only needed for self hosted replica set
type MongoDB cluster. For SRV connection format, this field must be empty. For
Standard connection format, this field must be specified.
Corresponds to the JSON property replicaSet
1922 1923 1924 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 1922 def replica_set @replica_set end |
#secret_manager_stored_password ⇒ String
Optional. A reference to a Secret Manager resource name storing the SQLServer
connection password. Mutually exclusive with the password field.
Corresponds to the JSON property secretManagerStoredPassword
1928 1929 1930 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 1928 def secret_manager_stored_password @secret_manager_stored_password end |
#srv_connection_format ⇒ Google::Apis::DatastreamV1::SrvConnectionFormat
Srv connection format.
Corresponds to the JSON property srvConnectionFormat
1933 1934 1935 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 1933 def srv_connection_format @srv_connection_format end |
#ssl_config ⇒ Google::Apis::DatastreamV1::MongodbSslConfig
MongoDB SSL configuration information.
Corresponds to the JSON property sslConfig
1938 1939 1940 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 1938 def ssl_config @ssl_config end |
#standard_connection_format ⇒ Google::Apis::DatastreamV1::StandardConnectionFormat
Standard connection format.
Corresponds to the JSON property standardConnectionFormat
1943 1944 1945 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 1943 def standard_connection_format @standard_connection_format end |
#username ⇒ String
Required. Username for the MongoDB connection.
Corresponds to the JSON property username
1948 1949 1950 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 1948 def username @username end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 1955 def update!(**args) @additional_options = args[:additional_options] if args.key?(:additional_options) @host_addresses = args[:host_addresses] if args.key?(:host_addresses) @password = args[:password] if args.key?(:password) @replica_set = args[:replica_set] if args.key?(:replica_set) @secret_manager_stored_password = args[:secret_manager_stored_password] if args.key?(:secret_manager_stored_password) @srv_connection_format = args[:srv_connection_format] if args.key?(:srv_connection_format) @ssl_config = args[:ssl_config] if args.key?(:ssl_config) @standard_connection_format = args[:standard_connection_format] if args.key?(:standard_connection_format) @username = args[:username] if args.key?(:username) end |