Class: Google::Apis::DatastreamV1::MongodbSslConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

MongoDB SSL configuration information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MongodbSslConfig

Returns a new instance of MongodbSslConfig.



2164
2165
2166
# File 'lib/google/apis/datastream_v1/classes.rb', line 2164

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ca_certificateString

Optional. Input only. PEM-encoded certificate of the CA that signed the source database server's certificate. Corresponds to the JSON property caCertificate

Returns:

  • (String)


2122
2123
2124
# File 'lib/google/apis/datastream_v1/classes.rb', line 2122

def ca_certificate
  @ca_certificate
end

#ca_certificate_setBoolean Also known as: ca_certificate_set?

Output only. Indicates whether the ca_certificate field is set. Corresponds to the JSON property caCertificateSet

Returns:

  • (Boolean)


2127
2128
2129
# File 'lib/google/apis/datastream_v1/classes.rb', line 2127

def ca_certificate_set
  @ca_certificate_set
end

#client_certificateString

Optional. Input only. PEM-encoded certificate that will be used by the replica to authenticate against the source database server. If this field is used then the 'client_key' and the 'ca_certificate' fields are mandatory. Corresponds to the JSON property clientCertificate

Returns:

  • (String)


2135
2136
2137
# File 'lib/google/apis/datastream_v1/classes.rb', line 2135

def client_certificate
  @client_certificate
end

#client_certificate_setBoolean Also known as: client_certificate_set?

Output only. Indicates whether the client_certificate field is set. Corresponds to the JSON property clientCertificateSet

Returns:

  • (Boolean)


2140
2141
2142
# File 'lib/google/apis/datastream_v1/classes.rb', line 2140

def client_certificate_set
  @client_certificate_set
end

#client_keyString

Optional. Input only. PEM-encoded private key associated with the Client Certificate. If this field is used then the 'client_certificate' and the ' ca_certificate' fields are mandatory. Corresponds to the JSON property clientKey

Returns:

  • (String)


2148
2149
2150
# File 'lib/google/apis/datastream_v1/classes.rb', line 2148

def client_key
  @client_key
end

#client_key_setBoolean Also known as: client_key_set?

Output only. Indicates whether the client_key field is set. Corresponds to the JSON property clientKeySet

Returns:

  • (Boolean)


2153
2154
2155
# File 'lib/google/apis/datastream_v1/classes.rb', line 2153

def client_key_set
  @client_key_set
end

#secret_manager_stored_client_keyString

Optional. Input only. A reference to a Secret Manager resource name storing the PEM-encoded private key associated with the Client Certificate. If this field is used then the 'client_certificate' and the 'ca_certificate' fields are mandatory. Mutually exclusive with the client_key field. Corresponds to the JSON property secretManagerStoredClientKey

Returns:

  • (String)


2162
2163
2164
# File 'lib/google/apis/datastream_v1/classes.rb', line 2162

def secret_manager_stored_client_key
  @secret_manager_stored_client_key
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2169
2170
2171
2172
2173
2174
2175
2176
2177
# File 'lib/google/apis/datastream_v1/classes.rb', line 2169

def update!(**args)
  @ca_certificate = args[:ca_certificate] if args.key?(:ca_certificate)
  @ca_certificate_set = args[:ca_certificate_set] if args.key?(:ca_certificate_set)
  @client_certificate = args[:client_certificate] if args.key?(:client_certificate)
  @client_certificate_set = args[:client_certificate_set] if args.key?(:client_certificate_set)
  @client_key = args[:client_key] if args.key?(:client_key)
  @client_key_set = args[:client_key_set] if args.key?(:client_key_set)
  @secret_manager_stored_client_key = args[:secret_manager_stored_client_key] if args.key?(:secret_manager_stored_client_key)
end