Class: Google::Apis::DatastreamV1::MongodbSslConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

MongoDB SSL configuration information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MongodbSslConfig

Returns a new instance of MongodbSslConfig.



1807
1808
1809
# File 'lib/google/apis/datastream_v1/classes.rb', line 1807

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ca_certificateString

Optional. Input only. PEM-encoded certificate of the CA that signed the source database server's certificate. Corresponds to the JSON property caCertificate

Returns:

  • (String)


1765
1766
1767
# File 'lib/google/apis/datastream_v1/classes.rb', line 1765

def ca_certificate
  @ca_certificate
end

#ca_certificate_setBoolean Also known as: ca_certificate_set?

Output only. Indicates whether the ca_certificate field is set. Corresponds to the JSON property caCertificateSet

Returns:

  • (Boolean)


1770
1771
1772
# File 'lib/google/apis/datastream_v1/classes.rb', line 1770

def ca_certificate_set
  @ca_certificate_set
end

#client_certificateString

Optional. Input only. PEM-encoded certificate that will be used by the replica to authenticate against the source database server. If this field is used then the 'client_key' and the 'ca_certificate' fields are mandatory. Corresponds to the JSON property clientCertificate

Returns:

  • (String)


1778
1779
1780
# File 'lib/google/apis/datastream_v1/classes.rb', line 1778

def client_certificate
  @client_certificate
end

#client_certificate_setBoolean Also known as: client_certificate_set?

Output only. Indicates whether the client_certificate field is set. Corresponds to the JSON property clientCertificateSet

Returns:

  • (Boolean)


1783
1784
1785
# File 'lib/google/apis/datastream_v1/classes.rb', line 1783

def client_certificate_set
  @client_certificate_set
end

#client_keyString

Optional. Input only. PEM-encoded private key associated with the Client Certificate. If this field is used then the 'client_certificate' and the ' ca_certificate' fields are mandatory. Corresponds to the JSON property clientKey

Returns:

  • (String)


1791
1792
1793
# File 'lib/google/apis/datastream_v1/classes.rb', line 1791

def client_key
  @client_key
end

#client_key_setBoolean Also known as: client_key_set?

Output only. Indicates whether the client_key field is set. Corresponds to the JSON property clientKeySet

Returns:

  • (Boolean)


1796
1797
1798
# File 'lib/google/apis/datastream_v1/classes.rb', line 1796

def client_key_set
  @client_key_set
end

#secret_manager_stored_client_keyString

Optional. Input only. A reference to a Secret Manager resource name storing the PEM-encoded private key associated with the Client Certificate. If this field is used then the 'client_certificate' and the 'ca_certificate' fields are mandatory. Mutually exclusive with the client_key field. Corresponds to the JSON property secretManagerStoredClientKey

Returns:

  • (String)


1805
1806
1807
# File 'lib/google/apis/datastream_v1/classes.rb', line 1805

def secret_manager_stored_client_key
  @secret_manager_stored_client_key
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1812
1813
1814
1815
1816
1817
1818
1819
1820
# File 'lib/google/apis/datastream_v1/classes.rb', line 1812

def update!(**args)
  @ca_certificate = args[:ca_certificate] if args.key?(:ca_certificate)
  @ca_certificate_set = args[:ca_certificate_set] if args.key?(:ca_certificate_set)
  @client_certificate = args[:client_certificate] if args.key?(:client_certificate)
  @client_certificate_set = args[:client_certificate_set] if args.key?(:client_certificate_set)
  @client_key = args[:client_key] if args.key?(:client_key)
  @client_key_set = args[:client_key_set] if args.key?(:client_key_set)
  @secret_manager_stored_client_key = args[:secret_manager_stored_client_key] if args.key?(:secret_manager_stored_client_key)
end