Class: Google::Apis::DatastreamV1::MysqlColumn

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

MySQL Column.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MysqlColumn

Returns a new instance of MysqlColumn.



2245
2246
2247
# File 'lib/google/apis/datastream_v1/classes.rb', line 2245

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#collationString

Column collation. Corresponds to the JSON property collation

Returns:

  • (String)


2200
2201
2202
# File 'lib/google/apis/datastream_v1/classes.rb', line 2200

def collation
  @collation
end

#columnString

The column name. Corresponds to the JSON property column

Returns:

  • (String)


2205
2206
2207
# File 'lib/google/apis/datastream_v1/classes.rb', line 2205

def column
  @column
end

#data_typeString

The MySQL data type. Full data types list can be found here: https://dev.mysql. com/doc/refman/8.0/en/data-types.html Corresponds to the JSON property dataType

Returns:

  • (String)


2211
2212
2213
# File 'lib/google/apis/datastream_v1/classes.rb', line 2211

def data_type
  @data_type
end

#lengthFixnum

Column length. Corresponds to the JSON property length

Returns:

  • (Fixnum)


2216
2217
2218
# File 'lib/google/apis/datastream_v1/classes.rb', line 2216

def length
  @length
end

#nullableBoolean Also known as: nullable?

Whether or not the column can accept a null value. Corresponds to the JSON property nullable

Returns:

  • (Boolean)


2221
2222
2223
# File 'lib/google/apis/datastream_v1/classes.rb', line 2221

def nullable
  @nullable
end

#ordinal_positionFixnum

The ordinal position of the column in the table. Corresponds to the JSON property ordinalPosition

Returns:

  • (Fixnum)


2227
2228
2229
# File 'lib/google/apis/datastream_v1/classes.rb', line 2227

def ordinal_position
  @ordinal_position
end

#precisionFixnum

Column precision. Corresponds to the JSON property precision

Returns:

  • (Fixnum)


2232
2233
2234
# File 'lib/google/apis/datastream_v1/classes.rb', line 2232

def precision
  @precision
end

#primary_keyBoolean Also known as: primary_key?

Whether or not the column represents a primary key. Corresponds to the JSON property primaryKey

Returns:

  • (Boolean)


2237
2238
2239
# File 'lib/google/apis/datastream_v1/classes.rb', line 2237

def primary_key
  @primary_key
end

#scaleFixnum

Column scale. Corresponds to the JSON property scale

Returns:

  • (Fixnum)


2243
2244
2245
# File 'lib/google/apis/datastream_v1/classes.rb', line 2243

def scale
  @scale
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2250
2251
2252
2253
2254
2255
2256
2257
2258
2259
2260
# File 'lib/google/apis/datastream_v1/classes.rb', line 2250

def update!(**args)
  @collation = args[:collation] if args.key?(:collation)
  @column = args[:column] if args.key?(:column)
  @data_type = args[:data_type] if args.key?(:data_type)
  @length = args[:length] if args.key?(:length)
  @nullable = args[:nullable] if args.key?(:nullable)
  @ordinal_position = args[:ordinal_position] if args.key?(:ordinal_position)
  @precision = args[:precision] if args.key?(:precision)
  @primary_key = args[:primary_key] if args.key?(:primary_key)
  @scale = args[:scale] if args.key?(:scale)
end