Class: Google::Apis::DatastreamV1::MysqlColumn

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

MySQL Column.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MysqlColumn

Returns a new instance of MysqlColumn.



2138
2139
2140
# File 'lib/google/apis/datastream_v1/classes.rb', line 2138

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#collationString

Column collation. Corresponds to the JSON property collation

Returns:

  • (String)


2093
2094
2095
# File 'lib/google/apis/datastream_v1/classes.rb', line 2093

def collation
  @collation
end

#columnString

The column name. Corresponds to the JSON property column

Returns:

  • (String)


2098
2099
2100
# File 'lib/google/apis/datastream_v1/classes.rb', line 2098

def column
  @column
end

#data_typeString

The MySQL data type. Full data types list can be found here: https://dev.mysql. com/doc/refman/8.0/en/data-types.html Corresponds to the JSON property dataType

Returns:

  • (String)


2104
2105
2106
# File 'lib/google/apis/datastream_v1/classes.rb', line 2104

def data_type
  @data_type
end

#lengthFixnum

Column length. Corresponds to the JSON property length

Returns:

  • (Fixnum)


2109
2110
2111
# File 'lib/google/apis/datastream_v1/classes.rb', line 2109

def length
  @length
end

#nullableBoolean Also known as: nullable?

Whether or not the column can accept a null value. Corresponds to the JSON property nullable

Returns:

  • (Boolean)


2114
2115
2116
# File 'lib/google/apis/datastream_v1/classes.rb', line 2114

def nullable
  @nullable
end

#ordinal_positionFixnum

The ordinal position of the column in the table. Corresponds to the JSON property ordinalPosition

Returns:

  • (Fixnum)


2120
2121
2122
# File 'lib/google/apis/datastream_v1/classes.rb', line 2120

def ordinal_position
  @ordinal_position
end

#precisionFixnum

Column precision. Corresponds to the JSON property precision

Returns:

  • (Fixnum)


2125
2126
2127
# File 'lib/google/apis/datastream_v1/classes.rb', line 2125

def precision
  @precision
end

#primary_keyBoolean Also known as: primary_key?

Whether or not the column represents a primary key. Corresponds to the JSON property primaryKey

Returns:

  • (Boolean)


2130
2131
2132
# File 'lib/google/apis/datastream_v1/classes.rb', line 2130

def primary_key
  @primary_key
end

#scaleFixnum

Column scale. Corresponds to the JSON property scale

Returns:

  • (Fixnum)


2136
2137
2138
# File 'lib/google/apis/datastream_v1/classes.rb', line 2136

def scale
  @scale
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
# File 'lib/google/apis/datastream_v1/classes.rb', line 2143

def update!(**args)
  @collation = args[:collation] if args.key?(:collation)
  @column = args[:column] if args.key?(:column)
  @data_type = args[:data_type] if args.key?(:data_type)
  @length = args[:length] if args.key?(:length)
  @nullable = args[:nullable] if args.key?(:nullable)
  @ordinal_position = args[:ordinal_position] if args.key?(:ordinal_position)
  @precision = args[:precision] if args.key?(:precision)
  @primary_key = args[:primary_key] if args.key?(:primary_key)
  @scale = args[:scale] if args.key?(:scale)
end