Class: Google::Apis::DatastreamV1::MysqlColumn
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1::MysqlColumn
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb
Overview
MySQL Column.
Instance Attribute Summary collapse
-
#collation ⇒ String
Column collation.
-
#column ⇒ String
The column name.
-
#data_type ⇒ String
The MySQL data type.
-
#length ⇒ Fixnum
Column length.
-
#nullable ⇒ Boolean
(also: #nullable?)
Whether or not the column can accept a null value.
-
#ordinal_position ⇒ Fixnum
The ordinal position of the column in the table.
-
#precision ⇒ Fixnum
Column precision.
-
#primary_key ⇒ Boolean
(also: #primary_key?)
Whether or not the column represents a primary key.
-
#scale ⇒ Fixnum
Column scale.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MysqlColumn
constructor
A new instance of MysqlColumn.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MysqlColumn
Returns a new instance of MysqlColumn.
2138 2139 2140 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 2138 def initialize(**args) update!(**args) end |
Instance Attribute Details
#collation ⇒ String
Column collation.
Corresponds to the JSON property collation
2093 2094 2095 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 2093 def collation @collation end |
#column ⇒ String
The column name.
Corresponds to the JSON property column
2098 2099 2100 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 2098 def column @column end |
#data_type ⇒ String
The MySQL data type. Full data types list can be found here: https://dev.mysql.
com/doc/refman/8.0/en/data-types.html
Corresponds to the JSON property dataType
2104 2105 2106 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 2104 def data_type @data_type end |
#length ⇒ Fixnum
Column length.
Corresponds to the JSON property length
2109 2110 2111 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 2109 def length @length end |
#nullable ⇒ Boolean Also known as: nullable?
Whether or not the column can accept a null value.
Corresponds to the JSON property nullable
2114 2115 2116 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 2114 def nullable @nullable end |
#ordinal_position ⇒ Fixnum
The ordinal position of the column in the table.
Corresponds to the JSON property ordinalPosition
2120 2121 2122 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 2120 def ordinal_position @ordinal_position end |
#precision ⇒ Fixnum
Column precision.
Corresponds to the JSON property precision
2125 2126 2127 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 2125 def precision @precision end |
#primary_key ⇒ Boolean Also known as: primary_key?
Whether or not the column represents a primary key.
Corresponds to the JSON property primaryKey
2130 2131 2132 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 2130 def primary_key @primary_key end |
#scale ⇒ Fixnum
Column scale.
Corresponds to the JSON property scale
2136 2137 2138 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 2136 def scale @scale end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 2143 def update!(**args) @collation = args[:collation] if args.key?(:collation) @column = args[:column] if args.key?(:column) @data_type = args[:data_type] if args.key?(:data_type) @length = args[:length] if args.key?(:length) @nullable = args[:nullable] if args.key?(:nullable) @ordinal_position = args[:ordinal_position] if args.key?(:ordinal_position) @precision = args[:precision] if args.key?(:precision) @primary_key = args[:primary_key] if args.key?(:primary_key) @scale = args[:scale] if args.key?(:scale) end |