Class: Google::Apis::DatastreamV1::MysqlColumn
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1::MysqlColumn
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb
Overview
MySQL Column.
Instance Attribute Summary collapse
-
#collation ⇒ String
Column collation.
-
#column ⇒ String
Column name.
-
#data_type ⇒ String
The MySQL data type.
-
#length ⇒ Fixnum
Column length.
-
#nullable ⇒ Boolean
(also: #nullable?)
Whether or not the column can accept a null value.
-
#ordinal_position ⇒ Fixnum
The ordinal position of the column in the table.
-
#precision ⇒ Fixnum
Column precision.
-
#primary_key ⇒ Boolean
(also: #primary_key?)
Whether or not the column represents a primary key.
-
#scale ⇒ Fixnum
Column scale.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MysqlColumn
constructor
A new instance of MysqlColumn.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MysqlColumn
Returns a new instance of MysqlColumn.
1888 1889 1890 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 1888 def initialize(**args) update!(**args) end |
Instance Attribute Details
#collation ⇒ String
Column collation.
Corresponds to the JSON property collation
1843 1844 1845 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 1843 def collation @collation end |
#column ⇒ String
Column name.
Corresponds to the JSON property column
1848 1849 1850 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 1848 def column @column end |
#data_type ⇒ String
The MySQL data type. Full data types list can be found here: https://dev.mysql.
com/doc/refman/8.0/en/data-types.html
Corresponds to the JSON property dataType
1854 1855 1856 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 1854 def data_type @data_type end |
#length ⇒ Fixnum
Column length.
Corresponds to the JSON property length
1859 1860 1861 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 1859 def length @length end |
#nullable ⇒ Boolean Also known as: nullable?
Whether or not the column can accept a null value.
Corresponds to the JSON property nullable
1864 1865 1866 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 1864 def nullable @nullable end |
#ordinal_position ⇒ Fixnum
The ordinal position of the column in the table.
Corresponds to the JSON property ordinalPosition
1870 1871 1872 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 1870 def ordinal_position @ordinal_position end |
#precision ⇒ Fixnum
Column precision.
Corresponds to the JSON property precision
1875 1876 1877 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 1875 def precision @precision end |
#primary_key ⇒ Boolean Also known as: primary_key?
Whether or not the column represents a primary key.
Corresponds to the JSON property primaryKey
1880 1881 1882 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 1880 def primary_key @primary_key end |
#scale ⇒ Fixnum
Column scale.
Corresponds to the JSON property scale
1886 1887 1888 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 1886 def scale @scale end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1893 1894 1895 1896 1897 1898 1899 1900 1901 1902 1903 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 1893 def update!(**args) @collation = args[:collation] if args.key?(:collation) @column = args[:column] if args.key?(:column) @data_type = args[:data_type] if args.key?(:data_type) @length = args[:length] if args.key?(:length) @nullable = args[:nullable] if args.key?(:nullable) @ordinal_position = args[:ordinal_position] if args.key?(:ordinal_position) @precision = args[:precision] if args.key?(:precision) @primary_key = args[:primary_key] if args.key?(:primary_key) @scale = args[:scale] if args.key?(:scale) end |