Class: Google::Apis::DatastreamV1::OauthRefreshTokenCredentials
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1::OauthRefreshTokenCredentials
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb
Overview
OAuth Refresh Token Credentials.
Instance Attribute Summary collapse
-
#oauth_client_credentials ⇒ Google::Apis::DatastreamV1::OauthClientCredentials
OAuth Client Credentials.
-
#refresh_token ⇒ Google::Apis::DatastreamV1::Secret
A confidential piece of information where the actual value is either directly specified in the message as a raw string or stored in GCP secret manager.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OauthRefreshTokenCredentials
constructor
A new instance of OauthRefreshTokenCredentials.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OauthRefreshTokenCredentials
Returns a new instance of OauthRefreshTokenCredentials.
2655 2656 2657 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 2655 def initialize(**args) update!(**args) end |
Instance Attribute Details
#oauth_client_credentials ⇒ Google::Apis::DatastreamV1::OauthClientCredentials
OAuth Client Credentials.
Corresponds to the JSON property oauthClientCredentials
2647 2648 2649 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 2647 def oauth_client_credentials @oauth_client_credentials end |
#refresh_token ⇒ Google::Apis::DatastreamV1::Secret
A confidential piece of information where the actual value is either directly
specified in the message as a raw string or stored in GCP secret manager.
Corresponds to the JSON property refreshToken
2653 2654 2655 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 2653 def refresh_token @refresh_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2660 2661 2662 2663 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 2660 def update!(**args) @oauth_client_credentials = args[:oauth_client_credentials] if args.key?(:oauth_client_credentials) @refresh_token = args[:refresh_token] if args.key?(:refresh_token) end |