Class: Google::Apis::DatastreamV1::ObjectFilter
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1::ObjectFilter
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb
Overview
Object filter to apply the rules to.
Instance Attribute Summary collapse
-
#source_object_identifier ⇒ Google::Apis::DatastreamV1::SourceObjectIdentifier
Represents an identifier of an object in the data source.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ObjectFilter
constructor
A new instance of ObjectFilter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ObjectFilter
Returns a new instance of ObjectFilter.
2260 2261 2262 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 2260 def initialize(**args) update!(**args) end |
Instance Attribute Details
#source_object_identifier ⇒ Google::Apis::DatastreamV1::SourceObjectIdentifier
Represents an identifier of an object in the data source.
Corresponds to the JSON property sourceObjectIdentifier
2258 2259 2260 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 2258 def source_object_identifier @source_object_identifier end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2265 2266 2267 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 2265 def update!(**args) @source_object_identifier = args[:source_object_identifier] if args.key?(:source_object_identifier) end |