Class: Google::Apis::DatastreamV1::OperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

Represents the metadata of the long-running operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationMetadata

Returns a new instance of OperationMetadata.



2380
2381
2382
# File 'lib/google/apis/datastream_v1/classes.rb', line 2380

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Output only. API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


2339
2340
2341
# File 'lib/google/apis/datastream_v1/classes.rb', line 2339

def api_version
  @api_version
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2344
2345
2346
# File 'lib/google/apis/datastream_v1/classes.rb', line 2344

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


2349
2350
2351
# File 'lib/google/apis/datastream_v1/classes.rb', line 2349

def end_time
  @end_time
end

#requested_cancellationBoolean Also known as: requested_cancellation?

Output only. Identifies whether the user has requested cancellation of the operation. Operations that have successfully been cancelled have google. longrunning.Operation.error value with a google.rpc.Status.code of 1, corresponding to Code.CANCELLED. Corresponds to the JSON property requestedCancellation

Returns:

  • (Boolean)


2357
2358
2359
# File 'lib/google/apis/datastream_v1/classes.rb', line 2357

def requested_cancellation
  @requested_cancellation
end

#status_messageString

Output only. Human-readable status of the operation, if any. Corresponds to the JSON property statusMessage

Returns:

  • (String)


2363
2364
2365
# File 'lib/google/apis/datastream_v1/classes.rb', line 2363

def status_message
  @status_message
end

#targetString

Output only. Server-defined resource path for the target of the operation. Corresponds to the JSON property target

Returns:

  • (String)


2368
2369
2370
# File 'lib/google/apis/datastream_v1/classes.rb', line 2368

def target
  @target
end

#validation_resultGoogle::Apis::DatastreamV1::ValidationResult

Contains the current validation results. Corresponds to the JSON property validationResult



2373
2374
2375
# File 'lib/google/apis/datastream_v1/classes.rb', line 2373

def validation_result
  @validation_result
end

#verbString

Output only. Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


2378
2379
2380
# File 'lib/google/apis/datastream_v1/classes.rb', line 2378

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2385
2386
2387
2388
2389
2390
2391
2392
2393
2394
# File 'lib/google/apis/datastream_v1/classes.rb', line 2385

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target = args[:target] if args.key?(:target)
  @validation_result = args[:validation_result] if args.key?(:validation_result)
  @verb = args[:verb] if args.key?(:verb)
end