Class: Google::Apis::DatastreamV1::OracleColumn

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

Oracle Column.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OracleColumn

Returns a new instance of OracleColumn.



2907
2908
2909
# File 'lib/google/apis/datastream_v1/classes.rb', line 2907

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#columnString

The column name. Corresponds to the JSON property column

Returns:

  • (String)


2863
2864
2865
# File 'lib/google/apis/datastream_v1/classes.rb', line 2863

def column
  @column
end

#data_typeString

The Oracle data type. Corresponds to the JSON property dataType

Returns:

  • (String)


2868
2869
2870
# File 'lib/google/apis/datastream_v1/classes.rb', line 2868

def data_type
  @data_type
end

#encodingString

Column encoding. Corresponds to the JSON property encoding

Returns:

  • (String)


2873
2874
2875
# File 'lib/google/apis/datastream_v1/classes.rb', line 2873

def encoding
  @encoding
end

#lengthFixnum

Column length. Corresponds to the JSON property length

Returns:

  • (Fixnum)


2878
2879
2880
# File 'lib/google/apis/datastream_v1/classes.rb', line 2878

def length
  @length
end

#nullableBoolean Also known as: nullable?

Whether or not the column can accept a null value. Corresponds to the JSON property nullable

Returns:

  • (Boolean)


2883
2884
2885
# File 'lib/google/apis/datastream_v1/classes.rb', line 2883

def nullable
  @nullable
end

#ordinal_positionFixnum

The ordinal position of the column in the table. Corresponds to the JSON property ordinalPosition

Returns:

  • (Fixnum)


2889
2890
2891
# File 'lib/google/apis/datastream_v1/classes.rb', line 2889

def ordinal_position
  @ordinal_position
end

#precisionFixnum

Column precision. Corresponds to the JSON property precision

Returns:

  • (Fixnum)


2894
2895
2896
# File 'lib/google/apis/datastream_v1/classes.rb', line 2894

def precision
  @precision
end

#primary_keyBoolean Also known as: primary_key?

Whether or not the column represents a primary key. Corresponds to the JSON property primaryKey

Returns:

  • (Boolean)


2899
2900
2901
# File 'lib/google/apis/datastream_v1/classes.rb', line 2899

def primary_key
  @primary_key
end

#scaleFixnum

Column scale. Corresponds to the JSON property scale

Returns:

  • (Fixnum)


2905
2906
2907
# File 'lib/google/apis/datastream_v1/classes.rb', line 2905

def scale
  @scale
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
# File 'lib/google/apis/datastream_v1/classes.rb', line 2912

def update!(**args)
  @column = args[:column] if args.key?(:column)
  @data_type = args[:data_type] if args.key?(:data_type)
  @encoding = args[:encoding] if args.key?(:encoding)
  @length = args[:length] if args.key?(:length)
  @nullable = args[:nullable] if args.key?(:nullable)
  @ordinal_position = args[:ordinal_position] if args.key?(:ordinal_position)
  @precision = args[:precision] if args.key?(:precision)
  @primary_key = args[:primary_key] if args.key?(:primary_key)
  @scale = args[:scale] if args.key?(:scale)
end