Class: Google::Apis::DatastreamV1::OracleColumn
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1::OracleColumn
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb
Overview
Oracle Column.
Instance Attribute Summary collapse
-
#column ⇒ String
The column name.
-
#data_type ⇒ String
The Oracle data type.
-
#encoding ⇒ String
Column encoding.
-
#length ⇒ Fixnum
Column length.
-
#nullable ⇒ Boolean
(also: #nullable?)
Whether or not the column can accept a null value.
-
#ordinal_position ⇒ Fixnum
The ordinal position of the column in the table.
-
#precision ⇒ Fixnum
Column precision.
-
#primary_key ⇒ Boolean
(also: #primary_key?)
Whether or not the column represents a primary key.
-
#scale ⇒ Fixnum
Column scale.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OracleColumn
constructor
A new instance of OracleColumn.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OracleColumn
Returns a new instance of OracleColumn.
2907 2908 2909 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 2907 def initialize(**args) update!(**args) end |
Instance Attribute Details
#column ⇒ String
The column name.
Corresponds to the JSON property column
2863 2864 2865 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 2863 def column @column end |
#data_type ⇒ String
The Oracle data type.
Corresponds to the JSON property dataType
2868 2869 2870 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 2868 def data_type @data_type end |
#encoding ⇒ String
Column encoding.
Corresponds to the JSON property encoding
2873 2874 2875 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 2873 def encoding @encoding end |
#length ⇒ Fixnum
Column length.
Corresponds to the JSON property length
2878 2879 2880 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 2878 def length @length end |
#nullable ⇒ Boolean Also known as: nullable?
Whether or not the column can accept a null value.
Corresponds to the JSON property nullable
2883 2884 2885 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 2883 def nullable @nullable end |
#ordinal_position ⇒ Fixnum
The ordinal position of the column in the table.
Corresponds to the JSON property ordinalPosition
2889 2890 2891 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 2889 def ordinal_position @ordinal_position end |
#precision ⇒ Fixnum
Column precision.
Corresponds to the JSON property precision
2894 2895 2896 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 2894 def precision @precision end |
#primary_key ⇒ Boolean Also known as: primary_key?
Whether or not the column represents a primary key.
Corresponds to the JSON property primaryKey
2899 2900 2901 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 2899 def primary_key @primary_key end |
#scale ⇒ Fixnum
Column scale.
Corresponds to the JSON property scale
2905 2906 2907 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 2905 def scale @scale end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2912 2913 2914 2915 2916 2917 2918 2919 2920 2921 2922 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 2912 def update!(**args) @column = args[:column] if args.key?(:column) @data_type = args[:data_type] if args.key?(:data_type) @encoding = args[:encoding] if args.key?(:encoding) @length = args[:length] if args.key?(:length) @nullable = args[:nullable] if args.key?(:nullable) @ordinal_position = args[:ordinal_position] if args.key?(:ordinal_position) @precision = args[:precision] if args.key?(:precision) @primary_key = args[:primary_key] if args.key?(:primary_key) @scale = args[:scale] if args.key?(:scale) end |