Class: Google::Apis::DatastreamV1::OracleColumn

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

Oracle Column.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OracleColumn

Returns a new instance of OracleColumn.



2780
2781
2782
# File 'lib/google/apis/datastream_v1/classes.rb', line 2780

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#columnString

The column name. Corresponds to the JSON property column

Returns:

  • (String)


2736
2737
2738
# File 'lib/google/apis/datastream_v1/classes.rb', line 2736

def column
  @column
end

#data_typeString

The Oracle data type. Corresponds to the JSON property dataType

Returns:

  • (String)


2741
2742
2743
# File 'lib/google/apis/datastream_v1/classes.rb', line 2741

def data_type
  @data_type
end

#encodingString

Column encoding. Corresponds to the JSON property encoding

Returns:

  • (String)


2746
2747
2748
# File 'lib/google/apis/datastream_v1/classes.rb', line 2746

def encoding
  @encoding
end

#lengthFixnum

Column length. Corresponds to the JSON property length

Returns:

  • (Fixnum)


2751
2752
2753
# File 'lib/google/apis/datastream_v1/classes.rb', line 2751

def length
  @length
end

#nullableBoolean Also known as: nullable?

Whether or not the column can accept a null value. Corresponds to the JSON property nullable

Returns:

  • (Boolean)


2756
2757
2758
# File 'lib/google/apis/datastream_v1/classes.rb', line 2756

def nullable
  @nullable
end

#ordinal_positionFixnum

The ordinal position of the column in the table. Corresponds to the JSON property ordinalPosition

Returns:

  • (Fixnum)


2762
2763
2764
# File 'lib/google/apis/datastream_v1/classes.rb', line 2762

def ordinal_position
  @ordinal_position
end

#precisionFixnum

Column precision. Corresponds to the JSON property precision

Returns:

  • (Fixnum)


2767
2768
2769
# File 'lib/google/apis/datastream_v1/classes.rb', line 2767

def precision
  @precision
end

#primary_keyBoolean Also known as: primary_key?

Whether or not the column represents a primary key. Corresponds to the JSON property primaryKey

Returns:

  • (Boolean)


2772
2773
2774
# File 'lib/google/apis/datastream_v1/classes.rb', line 2772

def primary_key
  @primary_key
end

#scaleFixnum

Column scale. Corresponds to the JSON property scale

Returns:

  • (Fixnum)


2778
2779
2780
# File 'lib/google/apis/datastream_v1/classes.rb', line 2778

def scale
  @scale
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2785
2786
2787
2788
2789
2790
2791
2792
2793
2794
2795
# File 'lib/google/apis/datastream_v1/classes.rb', line 2785

def update!(**args)
  @column = args[:column] if args.key?(:column)
  @data_type = args[:data_type] if args.key?(:data_type)
  @encoding = args[:encoding] if args.key?(:encoding)
  @length = args[:length] if args.key?(:length)
  @nullable = args[:nullable] if args.key?(:nullable)
  @ordinal_position = args[:ordinal_position] if args.key?(:ordinal_position)
  @precision = args[:precision] if args.key?(:precision)
  @primary_key = args[:primary_key] if args.key?(:primary_key)
  @scale = args[:scale] if args.key?(:scale)
end