Class: Google::Apis::DatastreamV1::OracleProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

Profile for connecting to an Oracle source.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OracleProfile

Returns a new instance of OracleProfile.



3001
3002
3003
# File 'lib/google/apis/datastream_v1/classes.rb', line 3001

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connection_attributesHash<String,String>

Connection string attributes Corresponds to the JSON property connectionAttributes

Returns:

  • (Hash<String,String>)


2957
2958
2959
# File 'lib/google/apis/datastream_v1/classes.rb', line 2957

def connection_attributes
  @connection_attributes
end

#database_serviceString

Required. Database for the Oracle connection. Corresponds to the JSON property databaseService

Returns:

  • (String)


2962
2963
2964
# File 'lib/google/apis/datastream_v1/classes.rb', line 2962

def database_service
  @database_service
end

#hostnameString

Required. Hostname for the Oracle connection. Corresponds to the JSON property hostname

Returns:

  • (String)


2967
2968
2969
# File 'lib/google/apis/datastream_v1/classes.rb', line 2967

def hostname
  @hostname
end

#oracle_asm_configGoogle::Apis::DatastreamV1::OracleAsmConfig

Configuration for Oracle Automatic Storage Management (ASM) connection. Corresponds to the JSON property oracleAsmConfig



2972
2973
2974
# File 'lib/google/apis/datastream_v1/classes.rb', line 2972

def oracle_asm_config
  @oracle_asm_config
end

#oracle_ssl_configGoogle::Apis::DatastreamV1::OracleSslConfig

Oracle SSL configuration information. Corresponds to the JSON property oracleSslConfig



2977
2978
2979
# File 'lib/google/apis/datastream_v1/classes.rb', line 2977

def oracle_ssl_config
  @oracle_ssl_config
end

#passwordString

Optional. Password for the Oracle connection. Mutually exclusive with the secret_manager_stored_password field. Corresponds to the JSON property password

Returns:

  • (String)


2983
2984
2985
# File 'lib/google/apis/datastream_v1/classes.rb', line 2983

def password
  @password
end

#portFixnum

Port for the Oracle connection, default value is 1521. Corresponds to the JSON property port

Returns:

  • (Fixnum)


2988
2989
2990
# File 'lib/google/apis/datastream_v1/classes.rb', line 2988

def port
  @port
end

#secret_manager_stored_passwordString

Optional. A reference to a Secret Manager resource name storing the Oracle connection password. Mutually exclusive with the password field. Corresponds to the JSON property secretManagerStoredPassword

Returns:

  • (String)


2994
2995
2996
# File 'lib/google/apis/datastream_v1/classes.rb', line 2994

def secret_manager_stored_password
  @secret_manager_stored_password
end

#usernameString

Required. Username for the Oracle connection. Corresponds to the JSON property username

Returns:

  • (String)


2999
3000
3001
# File 'lib/google/apis/datastream_v1/classes.rb', line 2999

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3006
3007
3008
3009
3010
3011
3012
3013
3014
3015
3016
# File 'lib/google/apis/datastream_v1/classes.rb', line 3006

def update!(**args)
  @connection_attributes = args[:connection_attributes] if args.key?(:connection_attributes)
  @database_service = args[:database_service] if args.key?(:database_service)
  @hostname = args[:hostname] if args.key?(:hostname)
  @oracle_asm_config = args[:oracle_asm_config] if args.key?(:oracle_asm_config)
  @oracle_ssl_config = args[:oracle_ssl_config] if args.key?(:oracle_ssl_config)
  @password = args[:password] if args.key?(:password)
  @port = args[:port] if args.key?(:port)
  @secret_manager_stored_password = args[:secret_manager_stored_password] if args.key?(:secret_manager_stored_password)
  @username = args[:username] if args.key?(:username)
end