Class: Google::Apis::DatastreamV1::OracleProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

Profile for connecting to an Oracle source.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OracleProfile

Returns a new instance of OracleProfile.



2868
2869
2870
# File 'lib/google/apis/datastream_v1/classes.rb', line 2868

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connection_attributesHash<String,String>

Connection string attributes Corresponds to the JSON property connectionAttributes

Returns:

  • (Hash<String,String>)


2824
2825
2826
# File 'lib/google/apis/datastream_v1/classes.rb', line 2824

def connection_attributes
  @connection_attributes
end

#database_serviceString

Required. Database for the Oracle connection. Corresponds to the JSON property databaseService

Returns:

  • (String)


2829
2830
2831
# File 'lib/google/apis/datastream_v1/classes.rb', line 2829

def database_service
  @database_service
end

#hostnameString

Required. Hostname for the Oracle connection. Corresponds to the JSON property hostname

Returns:

  • (String)


2834
2835
2836
# File 'lib/google/apis/datastream_v1/classes.rb', line 2834

def hostname
  @hostname
end

#oracle_asm_configGoogle::Apis::DatastreamV1::OracleAsmConfig

Configuration for Oracle Automatic Storage Management (ASM) connection. Corresponds to the JSON property oracleAsmConfig



2839
2840
2841
# File 'lib/google/apis/datastream_v1/classes.rb', line 2839

def oracle_asm_config
  @oracle_asm_config
end

#oracle_ssl_configGoogle::Apis::DatastreamV1::OracleSslConfig

Oracle SSL configuration information. Corresponds to the JSON property oracleSslConfig



2844
2845
2846
# File 'lib/google/apis/datastream_v1/classes.rb', line 2844

def oracle_ssl_config
  @oracle_ssl_config
end

#passwordString

Optional. Password for the Oracle connection. Mutually exclusive with the secret_manager_stored_password field. Corresponds to the JSON property password

Returns:

  • (String)


2850
2851
2852
# File 'lib/google/apis/datastream_v1/classes.rb', line 2850

def password
  @password
end

#portFixnum

Port for the Oracle connection, default value is 1521. Corresponds to the JSON property port

Returns:

  • (Fixnum)


2855
2856
2857
# File 'lib/google/apis/datastream_v1/classes.rb', line 2855

def port
  @port
end

#secret_manager_stored_passwordString

Optional. A reference to a Secret Manager resource name storing the Oracle connection password. Mutually exclusive with the password field. Corresponds to the JSON property secretManagerStoredPassword

Returns:

  • (String)


2861
2862
2863
# File 'lib/google/apis/datastream_v1/classes.rb', line 2861

def secret_manager_stored_password
  @secret_manager_stored_password
end

#usernameString

Required. Username for the Oracle connection. Corresponds to the JSON property username

Returns:

  • (String)


2866
2867
2868
# File 'lib/google/apis/datastream_v1/classes.rb', line 2866

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2873
2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
# File 'lib/google/apis/datastream_v1/classes.rb', line 2873

def update!(**args)
  @connection_attributes = args[:connection_attributes] if args.key?(:connection_attributes)
  @database_service = args[:database_service] if args.key?(:database_service)
  @hostname = args[:hostname] if args.key?(:hostname)
  @oracle_asm_config = args[:oracle_asm_config] if args.key?(:oracle_asm_config)
  @oracle_ssl_config = args[:oracle_ssl_config] if args.key?(:oracle_ssl_config)
  @password = args[:password] if args.key?(:password)
  @port = args[:port] if args.key?(:port)
  @secret_manager_stored_password = args[:secret_manager_stored_password] if args.key?(:secret_manager_stored_password)
  @username = args[:username] if args.key?(:username)
end