Class: Google::Apis::DatastreamV1::OracleProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

Oracle database profile.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OracleProfile

Returns a new instance of OracleProfile.



2618
2619
2620
# File 'lib/google/apis/datastream_v1/classes.rb', line 2618

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connection_attributesHash<String,String>

Connection string attributes Corresponds to the JSON property connectionAttributes

Returns:

  • (Hash<String,String>)


2574
2575
2576
# File 'lib/google/apis/datastream_v1/classes.rb', line 2574

def connection_attributes
  @connection_attributes
end

#database_serviceString

Required. Database for the Oracle connection. Corresponds to the JSON property databaseService

Returns:

  • (String)


2579
2580
2581
# File 'lib/google/apis/datastream_v1/classes.rb', line 2579

def database_service
  @database_service
end

#hostnameString

Required. Hostname for the Oracle connection. Corresponds to the JSON property hostname

Returns:

  • (String)


2584
2585
2586
# File 'lib/google/apis/datastream_v1/classes.rb', line 2584

def hostname
  @hostname
end

#oracle_asm_configGoogle::Apis::DatastreamV1::OracleAsmConfig

Configuration for Oracle Automatic Storage Management (ASM) connection. Corresponds to the JSON property oracleAsmConfig



2589
2590
2591
# File 'lib/google/apis/datastream_v1/classes.rb', line 2589

def oracle_asm_config
  @oracle_asm_config
end

#oracle_ssl_configGoogle::Apis::DatastreamV1::OracleSslConfig

Oracle SSL configuration information. Corresponds to the JSON property oracleSslConfig



2594
2595
2596
# File 'lib/google/apis/datastream_v1/classes.rb', line 2594

def oracle_ssl_config
  @oracle_ssl_config
end

#passwordString

Optional. Password for the Oracle connection. Mutually exclusive with the secret_manager_stored_password field. Corresponds to the JSON property password

Returns:

  • (String)


2600
2601
2602
# File 'lib/google/apis/datastream_v1/classes.rb', line 2600

def password
  @password
end

#portFixnum

Port for the Oracle connection, default value is 1521. Corresponds to the JSON property port

Returns:

  • (Fixnum)


2605
2606
2607
# File 'lib/google/apis/datastream_v1/classes.rb', line 2605

def port
  @port
end

#secret_manager_stored_passwordString

Optional. A reference to a Secret Manager resource name storing the Oracle connection password. Mutually exclusive with the password field. Corresponds to the JSON property secretManagerStoredPassword

Returns:

  • (String)


2611
2612
2613
# File 'lib/google/apis/datastream_v1/classes.rb', line 2611

def secret_manager_stored_password
  @secret_manager_stored_password
end

#usernameString

Required. Username for the Oracle connection. Corresponds to the JSON property username

Returns:

  • (String)


2616
2617
2618
# File 'lib/google/apis/datastream_v1/classes.rb', line 2616

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
# File 'lib/google/apis/datastream_v1/classes.rb', line 2623

def update!(**args)
  @connection_attributes = args[:connection_attributes] if args.key?(:connection_attributes)
  @database_service = args[:database_service] if args.key?(:database_service)
  @hostname = args[:hostname] if args.key?(:hostname)
  @oracle_asm_config = args[:oracle_asm_config] if args.key?(:oracle_asm_config)
  @oracle_ssl_config = args[:oracle_ssl_config] if args.key?(:oracle_ssl_config)
  @password = args[:password] if args.key?(:password)
  @port = args[:port] if args.key?(:port)
  @secret_manager_stored_password = args[:secret_manager_stored_password] if args.key?(:secret_manager_stored_password)
  @username = args[:username] if args.key?(:username)
end