Class: Google::Apis::DatastreamV1::PostgresqlColumn

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

PostgreSQL Column.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PostgresqlColumn

Returns a new instance of PostgresqlColumn.



3255
3256
3257
# File 'lib/google/apis/datastream_v1/classes.rb', line 3255

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#columnString

The column name. Corresponds to the JSON property column

Returns:

  • (String)


3216
3217
3218
# File 'lib/google/apis/datastream_v1/classes.rb', line 3216

def column
  @column
end

#data_typeString

The PostgreSQL data type. Corresponds to the JSON property dataType

Returns:

  • (String)


3221
3222
3223
# File 'lib/google/apis/datastream_v1/classes.rb', line 3221

def data_type
  @data_type
end

#lengthFixnum

Column length. Corresponds to the JSON property length

Returns:

  • (Fixnum)


3226
3227
3228
# File 'lib/google/apis/datastream_v1/classes.rb', line 3226

def length
  @length
end

#nullableBoolean Also known as: nullable?

Whether or not the column can accept a null value. Corresponds to the JSON property nullable

Returns:

  • (Boolean)


3231
3232
3233
# File 'lib/google/apis/datastream_v1/classes.rb', line 3231

def nullable
  @nullable
end

#ordinal_positionFixnum

The ordinal position of the column in the table. Corresponds to the JSON property ordinalPosition

Returns:

  • (Fixnum)


3237
3238
3239
# File 'lib/google/apis/datastream_v1/classes.rb', line 3237

def ordinal_position
  @ordinal_position
end

#precisionFixnum

Column precision. Corresponds to the JSON property precision

Returns:

  • (Fixnum)


3242
3243
3244
# File 'lib/google/apis/datastream_v1/classes.rb', line 3242

def precision
  @precision
end

#primary_keyBoolean Also known as: primary_key?

Whether or not the column represents a primary key. Corresponds to the JSON property primaryKey

Returns:

  • (Boolean)


3247
3248
3249
# File 'lib/google/apis/datastream_v1/classes.rb', line 3247

def primary_key
  @primary_key
end

#scaleFixnum

Column scale. Corresponds to the JSON property scale

Returns:

  • (Fixnum)


3253
3254
3255
# File 'lib/google/apis/datastream_v1/classes.rb', line 3253

def scale
  @scale
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3260
3261
3262
3263
3264
3265
3266
3267
3268
3269
# File 'lib/google/apis/datastream_v1/classes.rb', line 3260

def update!(**args)
  @column = args[:column] if args.key?(:column)
  @data_type = args[:data_type] if args.key?(:data_type)
  @length = args[:length] if args.key?(:length)
  @nullable = args[:nullable] if args.key?(:nullable)
  @ordinal_position = args[:ordinal_position] if args.key?(:ordinal_position)
  @precision = args[:precision] if args.key?(:precision)
  @primary_key = args[:primary_key] if args.key?(:primary_key)
  @scale = args[:scale] if args.key?(:scale)
end