Class: Google::Apis::DatastreamV1::PostgresqlColumn
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1::PostgresqlColumn
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb
Overview
PostgreSQL Column.
Instance Attribute Summary collapse
-
#column ⇒ String
The column name.
-
#data_type ⇒ String
The PostgreSQL data type.
-
#length ⇒ Fixnum
Column length.
-
#nullable ⇒ Boolean
(also: #nullable?)
Whether or not the column can accept a null value.
-
#ordinal_position ⇒ Fixnum
The ordinal position of the column in the table.
-
#precision ⇒ Fixnum
Column precision.
-
#primary_key ⇒ Boolean
(also: #primary_key?)
Whether or not the column represents a primary key.
-
#scale ⇒ Fixnum
Column scale.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PostgresqlColumn
constructor
A new instance of PostgresqlColumn.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PostgresqlColumn
Returns a new instance of PostgresqlColumn.
3255 3256 3257 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3255 def initialize(**args) update!(**args) end |
Instance Attribute Details
#column ⇒ String
The column name.
Corresponds to the JSON property column
3216 3217 3218 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3216 def column @column end |
#data_type ⇒ String
The PostgreSQL data type.
Corresponds to the JSON property dataType
3221 3222 3223 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3221 def data_type @data_type end |
#length ⇒ Fixnum
Column length.
Corresponds to the JSON property length
3226 3227 3228 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3226 def length @length end |
#nullable ⇒ Boolean Also known as: nullable?
Whether or not the column can accept a null value.
Corresponds to the JSON property nullable
3231 3232 3233 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3231 def nullable @nullable end |
#ordinal_position ⇒ Fixnum
The ordinal position of the column in the table.
Corresponds to the JSON property ordinalPosition
3237 3238 3239 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3237 def ordinal_position @ordinal_position end |
#precision ⇒ Fixnum
Column precision.
Corresponds to the JSON property precision
3242 3243 3244 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3242 def precision @precision end |
#primary_key ⇒ Boolean Also known as: primary_key?
Whether or not the column represents a primary key.
Corresponds to the JSON property primaryKey
3247 3248 3249 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3247 def primary_key @primary_key end |
#scale ⇒ Fixnum
Column scale.
Corresponds to the JSON property scale
3253 3254 3255 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3253 def scale @scale end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3260 3261 3262 3263 3264 3265 3266 3267 3268 3269 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3260 def update!(**args) @column = args[:column] if args.key?(:column) @data_type = args[:data_type] if args.key?(:data_type) @length = args[:length] if args.key?(:length) @nullable = args[:nullable] if args.key?(:nullable) @ordinal_position = args[:ordinal_position] if args.key?(:ordinal_position) @precision = args[:precision] if args.key?(:precision) @primary_key = args[:primary_key] if args.key?(:primary_key) @scale = args[:scale] if args.key?(:scale) end |