Class: Google::Apis::DatastreamV1::PostgresqlColumn

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

PostgreSQL Column.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PostgresqlColumn

Returns a new instance of PostgresqlColumn.



3122
3123
3124
# File 'lib/google/apis/datastream_v1/classes.rb', line 3122

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#columnString

The column name. Corresponds to the JSON property column

Returns:

  • (String)


3083
3084
3085
# File 'lib/google/apis/datastream_v1/classes.rb', line 3083

def column
  @column
end

#data_typeString

The PostgreSQL data type. Corresponds to the JSON property dataType

Returns:

  • (String)


3088
3089
3090
# File 'lib/google/apis/datastream_v1/classes.rb', line 3088

def data_type
  @data_type
end

#lengthFixnum

Column length. Corresponds to the JSON property length

Returns:

  • (Fixnum)


3093
3094
3095
# File 'lib/google/apis/datastream_v1/classes.rb', line 3093

def length
  @length
end

#nullableBoolean Also known as: nullable?

Whether or not the column can accept a null value. Corresponds to the JSON property nullable

Returns:

  • (Boolean)


3098
3099
3100
# File 'lib/google/apis/datastream_v1/classes.rb', line 3098

def nullable
  @nullable
end

#ordinal_positionFixnum

The ordinal position of the column in the table. Corresponds to the JSON property ordinalPosition

Returns:

  • (Fixnum)


3104
3105
3106
# File 'lib/google/apis/datastream_v1/classes.rb', line 3104

def ordinal_position
  @ordinal_position
end

#precisionFixnum

Column precision. Corresponds to the JSON property precision

Returns:

  • (Fixnum)


3109
3110
3111
# File 'lib/google/apis/datastream_v1/classes.rb', line 3109

def precision
  @precision
end

#primary_keyBoolean Also known as: primary_key?

Whether or not the column represents a primary key. Corresponds to the JSON property primaryKey

Returns:

  • (Boolean)


3114
3115
3116
# File 'lib/google/apis/datastream_v1/classes.rb', line 3114

def primary_key
  @primary_key
end

#scaleFixnum

Column scale. Corresponds to the JSON property scale

Returns:

  • (Fixnum)


3120
3121
3122
# File 'lib/google/apis/datastream_v1/classes.rb', line 3120

def scale
  @scale
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3127
3128
3129
3130
3131
3132
3133
3134
3135
3136
# File 'lib/google/apis/datastream_v1/classes.rb', line 3127

def update!(**args)
  @column = args[:column] if args.key?(:column)
  @data_type = args[:data_type] if args.key?(:data_type)
  @length = args[:length] if args.key?(:length)
  @nullable = args[:nullable] if args.key?(:nullable)
  @ordinal_position = args[:ordinal_position] if args.key?(:ordinal_position)
  @precision = args[:precision] if args.key?(:precision)
  @primary_key = args[:primary_key] if args.key?(:primary_key)
  @scale = args[:scale] if args.key?(:scale)
end