Class: Google::Apis::DatastreamV1::PostgresqlSourceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

Configuration for syncing data from a PostgreSQL source.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PostgresqlSourceConfig

Returns a new instance of PostgresqlSourceConfig.



3303
3304
3305
# File 'lib/google/apis/datastream_v1/classes.rb', line 3303

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#exclude_objectsGoogle::Apis::DatastreamV1::PostgresqlRdbms

PostgreSQL database structure. Corresponds to the JSON property excludeObjects



3278
3279
3280
# File 'lib/google/apis/datastream_v1/classes.rb', line 3278

def exclude_objects
  @exclude_objects
end

#include_objectsGoogle::Apis::DatastreamV1::PostgresqlRdbms

PostgreSQL database structure. Corresponds to the JSON property includeObjects



3283
3284
3285
# File 'lib/google/apis/datastream_v1/classes.rb', line 3283

def include_objects
  @include_objects
end

#max_concurrent_backfill_tasksFixnum

Maximum number of concurrent backfill tasks. The number should be non negative. If not set (or set to 0), the system's default value will be used. Corresponds to the JSON property maxConcurrentBackfillTasks

Returns:

  • (Fixnum)


3289
3290
3291
# File 'lib/google/apis/datastream_v1/classes.rb', line 3289

def max_concurrent_backfill_tasks
  @max_concurrent_backfill_tasks
end

#publicationString

Required. The name of the publication that includes the set of all tables that are defined in the stream's include_objects. Corresponds to the JSON property publication

Returns:

  • (String)


3295
3296
3297
# File 'lib/google/apis/datastream_v1/classes.rb', line 3295

def publication
  @publication
end

#replication_slotString

Required. Immutable. The name of the logical replication slot that's configured with the pgoutput plugin. Corresponds to the JSON property replicationSlot

Returns:

  • (String)


3301
3302
3303
# File 'lib/google/apis/datastream_v1/classes.rb', line 3301

def replication_slot
  @replication_slot
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3308
3309
3310
3311
3312
3313
3314
# File 'lib/google/apis/datastream_v1/classes.rb', line 3308

def update!(**args)
  @exclude_objects = args[:exclude_objects] if args.key?(:exclude_objects)
  @include_objects = args[:include_objects] if args.key?(:include_objects)
  @max_concurrent_backfill_tasks = args[:max_concurrent_backfill_tasks] if args.key?(:max_concurrent_backfill_tasks)
  @publication = args[:publication] if args.key?(:publication)
  @replication_slot = args[:replication_slot] if args.key?(:replication_slot)
end