Class: Google::Apis::DatastreamV1::PostgresqlSourceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

PostgreSQL data source configuration

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PostgresqlSourceConfig

Returns a new instance of PostgresqlSourceConfig.



3047
3048
3049
# File 'lib/google/apis/datastream_v1/classes.rb', line 3047

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#exclude_objectsGoogle::Apis::DatastreamV1::PostgresqlRdbms

PostgreSQL database structure. Corresponds to the JSON property excludeObjects



3022
3023
3024
# File 'lib/google/apis/datastream_v1/classes.rb', line 3022

def exclude_objects
  @exclude_objects
end

#include_objectsGoogle::Apis::DatastreamV1::PostgresqlRdbms

PostgreSQL database structure. Corresponds to the JSON property includeObjects



3027
3028
3029
# File 'lib/google/apis/datastream_v1/classes.rb', line 3027

def include_objects
  @include_objects
end

#max_concurrent_backfill_tasksFixnum

Maximum number of concurrent backfill tasks. The number should be non negative. If not set (or set to 0), the system's default value will be used. Corresponds to the JSON property maxConcurrentBackfillTasks

Returns:

  • (Fixnum)


3033
3034
3035
# File 'lib/google/apis/datastream_v1/classes.rb', line 3033

def max_concurrent_backfill_tasks
  @max_concurrent_backfill_tasks
end

#publicationString

Required. The name of the publication that includes the set of all tables that are defined in the stream's include_objects. Corresponds to the JSON property publication

Returns:

  • (String)


3039
3040
3041
# File 'lib/google/apis/datastream_v1/classes.rb', line 3039

def publication
  @publication
end

#replication_slotString

Required. Immutable. The name of the logical replication slot that's configured with the pgoutput plugin. Corresponds to the JSON property replicationSlot

Returns:

  • (String)


3045
3046
3047
# File 'lib/google/apis/datastream_v1/classes.rb', line 3045

def replication_slot
  @replication_slot
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3052
3053
3054
3055
3056
3057
3058
# File 'lib/google/apis/datastream_v1/classes.rb', line 3052

def update!(**args)
  @exclude_objects = args[:exclude_objects] if args.key?(:exclude_objects)
  @include_objects = args[:include_objects] if args.key?(:include_objects)
  @max_concurrent_backfill_tasks = args[:max_concurrent_backfill_tasks] if args.key?(:max_concurrent_backfill_tasks)
  @publication = args[:publication] if args.key?(:publication)
  @replication_slot = args[:replication_slot] if args.key?(:replication_slot)
end