Class: Google::Apis::DatastreamV1::PostgresqlSslConfig
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1::PostgresqlSslConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb
Overview
PostgreSQL SSL configuration information.
Instance Attribute Summary collapse
-
#server_and_client_verification ⇒ Google::Apis::DatastreamV1::ServerAndClientVerification
Message represents the option where Datastream will enforce the encryption and authenticate the server identity as well as the client identity.
-
#server_verification ⇒ Google::Apis::DatastreamV1::ServerVerification
Message represents the option where Datastream will enforce the encryption and authenticate the server identity.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PostgresqlSslConfig
constructor
A new instance of PostgresqlSslConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PostgresqlSslConfig
Returns a new instance of PostgresqlSslConfig.
3080 3081 3082 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3080 def initialize(**args) update!(**args) end |
Instance Attribute Details
#server_and_client_verification ⇒ Google::Apis::DatastreamV1::ServerAndClientVerification
Message represents the option where Datastream will enforce the encryption and
authenticate the server identity as well as the client identity.
ca_certificate, client_certificate and client_key must be set if user selects
this option.
Corresponds to the JSON property serverAndClientVerification
3071 3072 3073 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3071 def server_and_client_verification @server_and_client_verification end |
#server_verification ⇒ Google::Apis::DatastreamV1::ServerVerification
Message represents the option where Datastream will enforce the encryption and
authenticate the server identity. ca_certificate must be set if user selects
this option.
Corresponds to the JSON property serverVerification
3078 3079 3080 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3078 def server_verification @server_verification end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3085 3086 3087 3088 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3085 def update!(**args) @server_and_client_verification = args[:server_and_client_verification] if args.key?(:server_and_client_verification) @server_verification = args[:server_verification] if args.key?(:server_verification) end |