Class: Google::Apis::DatastreamV1::RequestInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

Contains metadata about the request that clients can attach when filing a bug or providing other forms of feedback.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RequestInfo

Returns a new instance of RequestInfo.



3822
3823
3824
# File 'lib/google/apis/datastream_v1/classes.rb', line 3822

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#request_idString

An opaque string that should only be interpreted by the service generating it. For example, it can be used to identify requests in the service's logs. Corresponds to the JSON property requestId

Returns:

  • (String)


3814
3815
3816
# File 'lib/google/apis/datastream_v1/classes.rb', line 3814

def request_id
  @request_id
end

#serving_dataString

Any data that was used to serve this request. For example, an encrypted stack trace that can be sent back to the service provider for debugging. Corresponds to the JSON property servingData

Returns:

  • (String)


3820
3821
3822
# File 'lib/google/apis/datastream_v1/classes.rb', line 3820

def serving_data
  @serving_data
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3827
3828
3829
3830
# File 'lib/google/apis/datastream_v1/classes.rb', line 3827

def update!(**args)
  @request_id = args[:request_id] if args.key?(:request_id)
  @serving_data = args[:serving_data] if args.key?(:serving_data)
end