Class: Google::Apis::DatastreamV1::RetryInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

Describes when the clients can retry a failed request. Clients could ignore the recommendation here or retry when this information is missing from error responses. It's always recommended that clients should use exponential backoff when retrying. Clients should wait until retry_delay amount of time has passed since receiving the error response before retrying. If retrying requests also fail, clients should use an exponential backoff scheme to gradually increase the delay between retries based on retry_delay, until either a maximum number of retries have been reached or a maximum retry delay cap has been reached.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RetryInfo

Returns a new instance of RetryInfo.



3766
3767
3768
# File 'lib/google/apis/datastream_v1/classes.rb', line 3766

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#retry_delayString

Clients should wait at least this long between retrying the same request. Corresponds to the JSON property retryDelay

Returns:

  • (String)


3764
3765
3766
# File 'lib/google/apis/datastream_v1/classes.rb', line 3764

def retry_delay
  @retry_delay
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3771
3772
3773
# File 'lib/google/apis/datastream_v1/classes.rb', line 3771

def update!(**args)
  @retry_delay = args[:retry_delay] if args.key?(:retry_delay)
end