Class: Google::Apis::DatastreamV1::SalesforceMarketingCloudProfile
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1::SalesforceMarketingCloudProfile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb
Overview
Profile for connecting to a Salesforce Marketing Cloud source.
Instance Attribute Summary collapse
-
#oauth_client_credentials ⇒ Google::Apis::DatastreamV1::OauthClientCredentials
OAuth Client Credentials.
-
#subdomain ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SalesforceMarketingCloudProfile
constructor
A new instance of SalesforceMarketingCloudProfile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SalesforceMarketingCloudProfile
Returns a new instance of SalesforceMarketingCloudProfile.
4060 4061 4062 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4060 def initialize(**args) update!(**args) end |
Instance Attribute Details
#oauth_client_credentials ⇒ Google::Apis::DatastreamV1::OauthClientCredentials
OAuth Client Credentials.
Corresponds to the JSON property oauthClientCredentials
4049 4050 4051 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4049 def oauth_client_credentials @oauth_client_credentials end |
#subdomain ⇒ String
Required. Subdomain for the Salesforce Marketing Cloud connection. Example: if
your specific endpoint is https://your-specific-subdomain.rest.
marketingcloudapis.com/, the subdomain is your-specific-subdomain. Must
be 1-63 characters, start and end with an alphanumeric character, and contain
only lowercase letters, numbers, and hyphens (-).
Corresponds to the JSON property subdomain
4058 4059 4060 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4058 def subdomain @subdomain end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4065 4066 4067 4068 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4065 def update!(**args) @oauth_client_credentials = args[:oauth_client_credentials] if args.key?(:oauth_client_credentials) @subdomain = args[:subdomain] if args.key?(:subdomain) end |