Class: Google::Apis::DatastreamV1::SalesforceMarketingCloudSourceConfig
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1::SalesforceMarketingCloudSourceConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb
Overview
Configuration for syncing data from a Salesforce Marketing Cloud source.
Instance Attribute Summary collapse
-
#exclude_objects ⇒ Google::Apis::DatastreamV1::SourceCatalog
Source catalog.
-
#full_refresh_polling_interval ⇒ String
Required.
-
#include_objects ⇒ Google::Apis::DatastreamV1::SourceCatalog
Source catalog.
-
#polling_interval ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SalesforceMarketingCloudSourceConfig
constructor
A new instance of SalesforceMarketingCloudSourceConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SalesforceMarketingCloudSourceConfig
Returns a new instance of SalesforceMarketingCloudSourceConfig.
4099 4100 4101 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4099 def initialize(**args) update!(**args) end |
Instance Attribute Details
#exclude_objects ⇒ Google::Apis::DatastreamV1::SourceCatalog
Source catalog.
Corresponds to the JSON property excludeObjects
4078 4079 4080 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4078 def exclude_objects @exclude_objects end |
#full_refresh_polling_interval ⇒ String
Required. Specifies the polling interval for a full refresh of objects that do
not support incremental sync. If not set, a default value of 24 hours is used.
The duration must be between 1 and 24 hours, inclusive.
Corresponds to the JSON property fullRefreshPollingInterval
4085 4086 4087 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4085 def full_refresh_polling_interval @full_refresh_polling_interval end |
#include_objects ⇒ Google::Apis::DatastreamV1::SourceCatalog
Source catalog.
Corresponds to the JSON property includeObjects
4090 4091 4092 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4090 def include_objects @include_objects end |
#polling_interval ⇒ String
Required. Incremental sync polling interval for all objects. If not set, a
default value of 5 minutes is used. The duration must be from 5 minutes to
24 hours, inclusive.
Corresponds to the JSON property pollingInterval
4097 4098 4099 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4097 def polling_interval @polling_interval end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4104 4105 4106 4107 4108 4109 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4104 def update!(**args) @exclude_objects = args[:exclude_objects] if args.key?(:exclude_objects) @full_refresh_polling_interval = args[:full_refresh_polling_interval] if args.key?(:full_refresh_polling_interval) @include_objects = args[:include_objects] if args.key?(:include_objects) @polling_interval = args[:polling_interval] if args.key?(:polling_interval) end |