Class: Google::Apis::DatastreamV1::SalesforceObject

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

Salesforce object.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SalesforceObject

Returns a new instance of SalesforceObject.



4127
4128
4129
# File 'lib/google/apis/datastream_v1/classes.rb', line 4127

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fieldsArray<Google::Apis::DatastreamV1::SalesforceField>

Salesforce fields. When unspecified as part of include objects, includes everything, when unspecified as part of exclude objects, excludes nothing. Corresponds to the JSON property fields



4120
4121
4122
# File 'lib/google/apis/datastream_v1/classes.rb', line 4120

def fields
  @fields
end

#object_nameString

The object name. Corresponds to the JSON property objectName

Returns:

  • (String)


4125
4126
4127
# File 'lib/google/apis/datastream_v1/classes.rb', line 4125

def object_name
  @object_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4132
4133
4134
4135
# File 'lib/google/apis/datastream_v1/classes.rb', line 4132

def update!(**args)
  @fields = args[:fields] if args.key?(:fields)
  @object_name = args[:object_name] if args.key?(:object_name)
end