Class: Google::Apis::DatastreamV1::SalesforceObject

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

Salesforce object.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SalesforceObject

Returns a new instance of SalesforceObject.



3924
3925
3926
# File 'lib/google/apis/datastream_v1/classes.rb', line 3924

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fieldsArray<Google::Apis::DatastreamV1::SalesforceField>

Salesforce fields. When unspecified as part of include objects, includes everything, when unspecified as part of exclude objects, excludes nothing. Corresponds to the JSON property fields



3917
3918
3919
# File 'lib/google/apis/datastream_v1/classes.rb', line 3917

def fields
  @fields
end

#object_nameString

The object name. Corresponds to the JSON property objectName

Returns:

  • (String)


3922
3923
3924
# File 'lib/google/apis/datastream_v1/classes.rb', line 3922

def object_name
  @object_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3929
3930
3931
3932
# File 'lib/google/apis/datastream_v1/classes.rb', line 3929

def update!(**args)
  @fields = args[:fields] if args.key?(:fields)
  @object_name = args[:object_name] if args.key?(:object_name)
end