Class: Google::Apis::DatastreamV1::SalesforceObject

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

Salesforce object.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SalesforceObject

Returns a new instance of SalesforceObject.



3397
3398
3399
# File 'lib/google/apis/datastream_v1/classes.rb', line 3397

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fieldsArray<Google::Apis::DatastreamV1::SalesforceField>

Salesforce fields. When unspecified as part of include objects, includes everything, when unspecified as part of exclude objects, excludes nothing. Corresponds to the JSON property fields



3390
3391
3392
# File 'lib/google/apis/datastream_v1/classes.rb', line 3390

def fields
  @fields
end

#object_nameString

Object name. Corresponds to the JSON property objectName

Returns:

  • (String)


3395
3396
3397
# File 'lib/google/apis/datastream_v1/classes.rb', line 3395

def object_name
  @object_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3402
3403
3404
3405
# File 'lib/google/apis/datastream_v1/classes.rb', line 3402

def update!(**args)
  @fields = args[:fields] if args.key?(:fields)
  @object_name = args[:object_name] if args.key?(:object_name)
end