Class: Google::Apis::DatastreamV1::ServerAndClientVerification
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1::ServerAndClientVerification
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb
Overview
Message represents the option where Datastream will enforce the encryption and authenticate the server identity as well as the client identity. ca_certificate, client_certificate and client_key must be set if user selects this option.
Instance Attribute Summary collapse
-
#ca_certificate ⇒ String
Required.
-
#client_certificate ⇒ String
Required.
-
#client_key ⇒ String
Optional.
-
#server_certificate_hostname ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServerAndClientVerification
constructor
A new instance of ServerAndClientVerification.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServerAndClientVerification
Returns a new instance of ServerAndClientVerification.
4305 4306 4307 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4305 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ca_certificate ⇒ String
Required. Input only. PEM-encoded server root CA certificate.
Corresponds to the JSON property caCertificate
4279 4280 4281 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4279 def ca_certificate @ca_certificate end |
#client_certificate ⇒ String
Required. Input only. PEM-encoded certificate used by the source database to
authenticate the client identity (i.e., the Datastream's identity). This
certificate is signed by either a root certificate trusted by the server or
one or more intermediate certificates (which is stored with the leaf
certificate) to link the this certificate to the trusted root certificate.
Corresponds to the JSON property clientCertificate
4288 4289 4290 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4288 def client_certificate @client_certificate end |
#client_key ⇒ String
Optional. Input only. PEM-encoded private key associated with the client
certificate. This value will be used during the SSL/TLS handshake, allowing
the PostgreSQL server to authenticate the client's identity, i.e. identity of
the Datastream.
Corresponds to the JSON property clientKey
4296 4297 4298 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4296 def client_key @client_key end |
#server_certificate_hostname ⇒ String
Optional. The hostname mentioned in the Subject or SAN extension of the server
certificate. If this field is not provided, the hostname in the server
certificate is not validated.
Corresponds to the JSON property serverCertificateHostname
4303 4304 4305 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4303 def server_certificate_hostname @server_certificate_hostname end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4310 4311 4312 4313 4314 4315 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4310 def update!(**args) @ca_certificate = args[:ca_certificate] if args.key?(:ca_certificate) @client_certificate = args[:client_certificate] if args.key?(:client_certificate) @client_key = args[:client_key] if args.key?(:client_key) @server_certificate_hostname = args[:server_certificate_hostname] if args.key?(:server_certificate_hostname) end |