Class: Google::Apis::DatastreamV1::ServerAndClientVerification

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

Message represents the option where Datastream will enforce the encryption and authenticate the server identity as well as the client identity. ca_certificate, client_certificate and client_key must be set if user selects this option.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServerAndClientVerification

Returns a new instance of ServerAndClientVerification.



4079
4080
4081
# File 'lib/google/apis/datastream_v1/classes.rb', line 4079

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ca_certificateString

Required. Input only. PEM-encoded server root CA certificate. Corresponds to the JSON property caCertificate

Returns:

  • (String)


4053
4054
4055
# File 'lib/google/apis/datastream_v1/classes.rb', line 4053

def ca_certificate
  @ca_certificate
end

#client_certificateString

Required. Input only. PEM-encoded certificate used by the source database to authenticate the client identity (i.e., the Datastream's identity). This certificate is signed by either a root certificate trusted by the server or one or more intermediate certificates (which is stored with the leaf certificate) to link the this certificate to the trusted root certificate. Corresponds to the JSON property clientCertificate

Returns:

  • (String)


4062
4063
4064
# File 'lib/google/apis/datastream_v1/classes.rb', line 4062

def client_certificate
  @client_certificate
end

#client_keyString

Optional. Input only. PEM-encoded private key associated with the client certificate. This value will be used during the SSL/TLS handshake, allowing the PostgreSQL server to authenticate the client's identity, i.e. identity of the Datastream. Corresponds to the JSON property clientKey

Returns:

  • (String)


4070
4071
4072
# File 'lib/google/apis/datastream_v1/classes.rb', line 4070

def client_key
  @client_key
end

#server_certificate_hostnameString

Optional. The hostname mentioned in the Subject or SAN extension of the server certificate. If this field is not provided, the hostname in the server certificate is not validated. Corresponds to the JSON property serverCertificateHostname

Returns:

  • (String)


4077
4078
4079
# File 'lib/google/apis/datastream_v1/classes.rb', line 4077

def server_certificate_hostname
  @server_certificate_hostname
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4084
4085
4086
4087
4088
4089
# File 'lib/google/apis/datastream_v1/classes.rb', line 4084

def update!(**args)
  @ca_certificate = args[:ca_certificate] if args.key?(:ca_certificate)
  @client_certificate = args[:client_certificate] if args.key?(:client_certificate)
  @client_key = args[:client_key] if args.key?(:client_key)
  @server_certificate_hostname = args[:server_certificate_hostname] if args.key?(:server_certificate_hostname)
end