Class: Google::Apis::DatastreamV1::ServerVerification

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

Message represents the option where Datastream will enforce the encryption and authenticate the server identity. ca_certificate must be set if user selects this option.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServerVerification

Returns a new instance of ServerVerification.



4336
4337
4338
# File 'lib/google/apis/datastream_v1/classes.rb', line 4336

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ca_certificateString

Required. Input only. PEM-encoded server root CA certificate. Corresponds to the JSON property caCertificate

Returns:

  • (String)


4327
4328
4329
# File 'lib/google/apis/datastream_v1/classes.rb', line 4327

def ca_certificate
  @ca_certificate
end

#server_certificate_hostnameString

Optional. The hostname mentioned in the Subject or SAN extension of the server certificate. If this field is not provided, the hostname in the server certificate is not validated. Corresponds to the JSON property serverCertificateHostname

Returns:

  • (String)


4334
4335
4336
# File 'lib/google/apis/datastream_v1/classes.rb', line 4334

def server_certificate_hostname
  @server_certificate_hostname
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4341
4342
4343
4344
# File 'lib/google/apis/datastream_v1/classes.rb', line 4341

def update!(**args)
  @ca_certificate = args[:ca_certificate] if args.key?(:ca_certificate)
  @server_certificate_hostname = args[:server_certificate_hostname] if args.key?(:server_certificate_hostname)
end