Class: Google::Apis::DatastreamV1::ServerVerification
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1::ServerVerification
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb
Overview
Message represents the option where Datastream will enforce the encryption and authenticate the server identity. ca_certificate must be set if user selects this option.
Instance Attribute Summary collapse
-
#ca_certificate ⇒ String
Required.
-
#server_certificate_hostname ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServerVerification
constructor
A new instance of ServerVerification.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServerVerification
Returns a new instance of ServerVerification.
4104 4105 4106 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4104 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ca_certificate ⇒ String
Required. Input only. PEM-encoded server root CA certificate.
Corresponds to the JSON property caCertificate
4095 4096 4097 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4095 def ca_certificate @ca_certificate end |
#server_certificate_hostname ⇒ String
Optional. The hostname mentioned in the Subject or SAN extension of the server
certificate. If this field is not provided, the hostname in the server
certificate is not validated.
Corresponds to the JSON property serverCertificateHostname
4102 4103 4104 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4102 def server_certificate_hostname @server_certificate_hostname end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4109 4110 4111 4112 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4109 def update!(**args) @ca_certificate = args[:ca_certificate] if args.key?(:ca_certificate) @server_certificate_hostname = args[:server_certificate_hostname] if args.key?(:server_certificate_hostname) end |