Class: Google::Apis::DatastreamV1::SourceConfig
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1::SourceConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb
Overview
The configuration of the stream source.
Instance Attribute Summary collapse
-
#dataverse_source_config ⇒ Google::Apis::DatastreamV1::DataverseSourceConfig
Configuration for syncing data from a Dataverse source.
-
#mongodb_source_config ⇒ Google::Apis::DatastreamV1::MongodbSourceConfig
Configuration for syncing data from a MongoDB source.
-
#mysql_source_config ⇒ Google::Apis::DatastreamV1::MysqlSourceConfig
Configuration for syncing data from a MySQL source.
-
#oracle_source_config ⇒ Google::Apis::DatastreamV1::OracleSourceConfig
Configuration for syncing data from an Oracle source.
-
#postgresql_source_config ⇒ Google::Apis::DatastreamV1::PostgresqlSourceConfig
Configuration for syncing data from a PostgreSQL source.
-
#salesforce_marketing_cloud_source_config ⇒ Google::Apis::DatastreamV1::SalesforceMarketingCloudSourceConfig
Configuration for syncing data from a Salesforce Marketing Cloud source.
-
#salesforce_source_config ⇒ Google::Apis::DatastreamV1::SalesforceSourceConfig
Configuration for syncing data from a Salesforce source.
-
#service_now_source_config ⇒ Google::Apis::DatastreamV1::ServiceNowSourceConfig
Configuration for syncing data from a ServiceNow source.
-
#source_connection_profile ⇒ String
Required.
-
#spanner_source_config ⇒ Google::Apis::DatastreamV1::SpannerSourceConfig
Configuration for syncing data from a Spanner source.
-
#sql_server_source_config ⇒ Google::Apis::DatastreamV1::SqlServerSourceConfig
Configuration for syncing data from a SQLServer source.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SourceConfig
constructor
A new instance of SourceConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SourceConfig
Returns a new instance of SourceConfig.
4511 4512 4513 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4511 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dataverse_source_config ⇒ Google::Apis::DatastreamV1::DataverseSourceConfig
Configuration for syncing data from a Dataverse source.
Corresponds to the JSON property dataverseSourceConfig
4458 4459 4460 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4458 def dataverse_source_config @dataverse_source_config end |
#mongodb_source_config ⇒ Google::Apis::DatastreamV1::MongodbSourceConfig
Configuration for syncing data from a MongoDB source.
Corresponds to the JSON property mongodbSourceConfig
4463 4464 4465 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4463 def mongodb_source_config @mongodb_source_config end |
#mysql_source_config ⇒ Google::Apis::DatastreamV1::MysqlSourceConfig
Configuration for syncing data from a MySQL source.
Corresponds to the JSON property mysqlSourceConfig
4468 4469 4470 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4468 def mysql_source_config @mysql_source_config end |
#oracle_source_config ⇒ Google::Apis::DatastreamV1::OracleSourceConfig
Configuration for syncing data from an Oracle source.
Corresponds to the JSON property oracleSourceConfig
4473 4474 4475 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4473 def oracle_source_config @oracle_source_config end |
#postgresql_source_config ⇒ Google::Apis::DatastreamV1::PostgresqlSourceConfig
Configuration for syncing data from a PostgreSQL source.
Corresponds to the JSON property postgresqlSourceConfig
4478 4479 4480 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4478 def postgresql_source_config @postgresql_source_config end |
#salesforce_marketing_cloud_source_config ⇒ Google::Apis::DatastreamV1::SalesforceMarketingCloudSourceConfig
Configuration for syncing data from a Salesforce Marketing Cloud source.
Corresponds to the JSON property salesforceMarketingCloudSourceConfig
4483 4484 4485 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4483 def salesforce_marketing_cloud_source_config @salesforce_marketing_cloud_source_config end |
#salesforce_source_config ⇒ Google::Apis::DatastreamV1::SalesforceSourceConfig
Configuration for syncing data from a Salesforce source.
Corresponds to the JSON property salesforceSourceConfig
4488 4489 4490 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4488 def salesforce_source_config @salesforce_source_config end |
#service_now_source_config ⇒ Google::Apis::DatastreamV1::ServiceNowSourceConfig
Configuration for syncing data from a ServiceNow source.
Corresponds to the JSON property serviceNowSourceConfig
4493 4494 4495 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4493 def service_now_source_config @service_now_source_config end |
#source_connection_profile ⇒ String
Required. Source connection profile resource. Format: projects/project/
locations/location/connectionProfiles/name`
Corresponds to the JSON propertysourceConnectionProfile`
4499 4500 4501 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4499 def source_connection_profile @source_connection_profile end |
#spanner_source_config ⇒ Google::Apis::DatastreamV1::SpannerSourceConfig
Configuration for syncing data from a Spanner source.
Corresponds to the JSON property spannerSourceConfig
4504 4505 4506 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4504 def spanner_source_config @spanner_source_config end |
#sql_server_source_config ⇒ Google::Apis::DatastreamV1::SqlServerSourceConfig
Configuration for syncing data from a SQLServer source.
Corresponds to the JSON property sqlServerSourceConfig
4509 4510 4511 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4509 def sql_server_source_config @sql_server_source_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4516 4517 4518 4519 4520 4521 4522 4523 4524 4525 4526 4527 4528 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4516 def update!(**args) @dataverse_source_config = args[:dataverse_source_config] if args.key?(:dataverse_source_config) @mongodb_source_config = args[:mongodb_source_config] if args.key?(:mongodb_source_config) @mysql_source_config = args[:mysql_source_config] if args.key?(:mysql_source_config) @oracle_source_config = args[:oracle_source_config] if args.key?(:oracle_source_config) @postgresql_source_config = args[:postgresql_source_config] if args.key?(:postgresql_source_config) @salesforce_marketing_cloud_source_config = args[:salesforce_marketing_cloud_source_config] if args.key?(:salesforce_marketing_cloud_source_config) @salesforce_source_config = args[:salesforce_source_config] if args.key?(:salesforce_source_config) @service_now_source_config = args[:service_now_source_config] if args.key?(:service_now_source_config) @source_connection_profile = args[:source_connection_profile] if args.key?(:source_connection_profile) @spanner_source_config = args[:spanner_source_config] if args.key?(:spanner_source_config) @sql_server_source_config = args[:sql_server_source_config] if args.key?(:sql_server_source_config) end |