Class: Google::Apis::DatastreamV1::SourceHierarchyDatasets

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

Destination datasets are created so that hierarchy of the destination data objects matches the source hierarchy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SourceHierarchyDatasets

Returns a new instance of SourceHierarchyDatasets.



4548
4549
4550
# File 'lib/google/apis/datastream_v1/classes.rb', line 4548

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataset_templateGoogle::Apis::DatastreamV1::DatasetTemplate

Dataset template used for dynamic dataset creation. Corresponds to the JSON property datasetTemplate



4540
4541
4542
# File 'lib/google/apis/datastream_v1/classes.rb', line 4540

def dataset_template
  @dataset_template
end

#project_idString

Optional. The project id of the BigQuery dataset. If not specified, the project will be inferred from the stream resource. Corresponds to the JSON property projectId

Returns:

  • (String)


4546
4547
4548
# File 'lib/google/apis/datastream_v1/classes.rb', line 4546

def project_id
  @project_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4553
4554
4555
4556
# File 'lib/google/apis/datastream_v1/classes.rb', line 4553

def update!(**args)
  @dataset_template = args[:dataset_template] if args.key?(:dataset_template)
  @project_id = args[:project_id] if args.key?(:project_id)
end