Class: Google::Apis::DatastreamV1::SourceHierarchyDatasets

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

Destination datasets are created so that hierarchy of the destination data objects matches the source hierarchy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SourceHierarchyDatasets

Returns a new instance of SourceHierarchyDatasets.



3680
3681
3682
# File 'lib/google/apis/datastream_v1/classes.rb', line 3680

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataset_templateGoogle::Apis::DatastreamV1::DatasetTemplate

Dataset template used for dynamic dataset creation. Corresponds to the JSON property datasetTemplate



3672
3673
3674
# File 'lib/google/apis/datastream_v1/classes.rb', line 3672

def dataset_template
  @dataset_template
end

#project_idString

Optional. The project id of the BigQuery dataset. If not specified, the project will be inferred from the stream resource. Corresponds to the JSON property projectId

Returns:

  • (String)


3678
3679
3680
# File 'lib/google/apis/datastream_v1/classes.rb', line 3678

def project_id
  @project_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3685
3686
3687
3688
# File 'lib/google/apis/datastream_v1/classes.rb', line 3685

def update!(**args)
  @dataset_template = args[:dataset_template] if args.key?(:dataset_template)
  @project_id = args[:project_id] if args.key?(:project_id)
end