Class: Google::Apis::DatastreamV1::SourceObject

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

Source object.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SourceObject

Returns a new instance of SourceObject.



4574
4575
4576
# File 'lib/google/apis/datastream_v1/classes.rb', line 4574

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#object_nameString

Required. The object name. Corresponds to the JSON property objectName

Returns:

  • (String)


4565
4566
4567
# File 'lib/google/apis/datastream_v1/classes.rb', line 4565

def object_name
  @object_name
end

#propertiesArray<Google::Apis::DatastreamV1::SourceProperty>

Optional. Source properties. When unspecified as part of include objects, includes everything, when unspecified as part of exclude objects, excludes nothing. Corresponds to the JSON property properties



4572
4573
4574
# File 'lib/google/apis/datastream_v1/classes.rb', line 4572

def properties
  @properties
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4579
4580
4581
4582
# File 'lib/google/apis/datastream_v1/classes.rb', line 4579

def update!(**args)
  @object_name = args[:object_name] if args.key?(:object_name)
  @properties = args[:properties] if args.key?(:properties)
end