Class: Google::Apis::DatastreamV1::SourceProperty
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1::SourceProperty
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb
Overview
Source property.
Instance Attribute Summary collapse
-
#primary_key ⇒ Boolean
(also: #primary_key?)
Optional.
-
#properties ⇒ Array<Google::Apis::DatastreamV1::SourceProperty>
Optional.
-
#property_name ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SourceProperty
constructor
A new instance of SourceProperty.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SourceProperty
Returns a new instance of SourceProperty.
4664 4665 4666 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4664 def initialize(**args) update!(**args) end |
Instance Attribute Details
#primary_key ⇒ Boolean Also known as: primary_key?
Optional. Whether or not the property is a primary key.
Corresponds to the JSON property primaryKey
4648 4649 4650 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4648 def primary_key @primary_key end |
#properties ⇒ Array<Google::Apis::DatastreamV1::SourceProperty>
Optional. Source properties. When specified, it means that the current
property contains nested properties of its own. When unspecified as part of
include objects, includes everything, when unspecified as part of exclude
objects, excludes nothing.
Corresponds to the JSON property properties
4657 4658 4659 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4657 def properties @properties end |
#property_name ⇒ String
Required. The property name.
Corresponds to the JSON property propertyName
4662 4663 4664 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4662 def property_name @property_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4669 4670 4671 4672 4673 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4669 def update!(**args) @primary_key = args[:primary_key] if args.key?(:primary_key) @properties = args[:properties] if args.key?(:properties) @property_name = args[:property_name] if args.key?(:property_name) end |