Class: Google::Apis::DatastreamV1::SourceProperty

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

Source property.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SourceProperty

Returns a new instance of SourceProperty.



4663
4664
4665
# File 'lib/google/apis/datastream_v1/classes.rb', line 4663

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#primary_keyBoolean Also known as: primary_key?

Optional. Whether or not the property is a primary key. Corresponds to the JSON property primaryKey

Returns:

  • (Boolean)


4647
4648
4649
# File 'lib/google/apis/datastream_v1/classes.rb', line 4647

def primary_key
  @primary_key
end

#propertiesArray<Google::Apis::DatastreamV1::SourceProperty>

Optional. Source properties. When specified, it means that the current property contains nested properties of its own. When unspecified as part of include objects, includes everything, when unspecified as part of exclude objects, excludes nothing. Corresponds to the JSON property properties



4656
4657
4658
# File 'lib/google/apis/datastream_v1/classes.rb', line 4656

def properties
  @properties
end

#property_nameString

Required. The property name. Corresponds to the JSON property propertyName

Returns:

  • (String)


4661
4662
4663
# File 'lib/google/apis/datastream_v1/classes.rb', line 4661

def property_name
  @property_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4668
4669
4670
4671
4672
# File 'lib/google/apis/datastream_v1/classes.rb', line 4668

def update!(**args)
  @primary_key = args[:primary_key] if args.key?(:primary_key)
  @properties = args[:properties] if args.key?(:properties)
  @property_name = args[:property_name] if args.key?(:property_name)
end