Class: Google::Apis::DatastreamV1::SpecificStartPosition
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1::SpecificStartPosition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb
Overview
CDC strategy to start replicating from a specific position in the source.
Instance Attribute Summary collapse
-
#mongodb_change_stream_position ⇒ Google::Apis::DatastreamV1::MongodbChangeStreamPosition
MongoDB change stream position Corresponds to the JSON property
mongodbChangeStreamPosition. -
#mysql_gtid_position ⇒ Google::Apis::DatastreamV1::MysqlGtidPosition
MySQL GTID position Corresponds to the JSON property
mysqlGtidPosition. -
#mysql_log_position ⇒ Google::Apis::DatastreamV1::MysqlLogPosition
MySQL log position Corresponds to the JSON property
mysqlLogPosition. -
#oracle_scn_position ⇒ Google::Apis::DatastreamV1::OracleScnPosition
Oracle SCN position Corresponds to the JSON property
oracleScnPosition. -
#spanner_change_stream_position ⇒ Google::Apis::DatastreamV1::SpannerChangeStreamPosition
Represents a position in a Spanner change stream from which to start replicating.
-
#sql_server_lsn_position ⇒ Google::Apis::DatastreamV1::SqlServerLsnPosition
SQL Server LSN position Corresponds to the JSON property
sqlServerLsnPosition.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SpecificStartPosition
constructor
A new instance of SpecificStartPosition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SpecificStartPosition
Returns a new instance of SpecificStartPosition.
4565 4566 4567 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4565 def initialize(**args) update!(**args) end |
Instance Attribute Details
#mongodb_change_stream_position ⇒ Google::Apis::DatastreamV1::MongodbChangeStreamPosition
MongoDB change stream position
Corresponds to the JSON property mongodbChangeStreamPosition
4537 4538 4539 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4537 def mongodb_change_stream_position @mongodb_change_stream_position end |
#mysql_gtid_position ⇒ Google::Apis::DatastreamV1::MysqlGtidPosition
MySQL GTID position
Corresponds to the JSON property mysqlGtidPosition
4542 4543 4544 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4542 def mysql_gtid_position @mysql_gtid_position end |
#mysql_log_position ⇒ Google::Apis::DatastreamV1::MysqlLogPosition
MySQL log position
Corresponds to the JSON property mysqlLogPosition
4547 4548 4549 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4547 def mysql_log_position @mysql_log_position end |
#oracle_scn_position ⇒ Google::Apis::DatastreamV1::OracleScnPosition
Oracle SCN position
Corresponds to the JSON property oracleScnPosition
4552 4553 4554 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4552 def oracle_scn_position @oracle_scn_position end |
#spanner_change_stream_position ⇒ Google::Apis::DatastreamV1::SpannerChangeStreamPosition
Represents a position in a Spanner change stream from which to start
replicating.
Corresponds to the JSON property spannerChangeStreamPosition
4558 4559 4560 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4558 def spanner_change_stream_position @spanner_change_stream_position end |
#sql_server_lsn_position ⇒ Google::Apis::DatastreamV1::SqlServerLsnPosition
SQL Server LSN position
Corresponds to the JSON property sqlServerLsnPosition
4563 4564 4565 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4563 def sql_server_lsn_position @sql_server_lsn_position end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4570 4571 4572 4573 4574 4575 4576 4577 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4570 def update!(**args) @mongodb_change_stream_position = args[:mongodb_change_stream_position] if args.key?(:mongodb_change_stream_position) @mysql_gtid_position = args[:mysql_gtid_position] if args.key?(:mysql_gtid_position) @mysql_log_position = args[:mysql_log_position] if args.key?(:mysql_log_position) @oracle_scn_position = args[:oracle_scn_position] if args.key?(:oracle_scn_position) @spanner_change_stream_position = args[:spanner_change_stream_position] if args.key?(:spanner_change_stream_position) @sql_server_lsn_position = args[:sql_server_lsn_position] if args.key?(:sql_server_lsn_position) end |