Class: Google::Apis::DatastreamV1::SqlServerColumn

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

SQLServer Column.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SqlServerColumn

Returns a new instance of SqlServerColumn.



5030
5031
5032
# File 'lib/google/apis/datastream_v1/classes.rb', line 5030

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#columnString

The column name. Corresponds to the JSON property column

Returns:

  • (String)


4991
4992
4993
# File 'lib/google/apis/datastream_v1/classes.rb', line 4991

def column
  @column
end

#data_typeString

The SQLServer data type. Corresponds to the JSON property dataType

Returns:

  • (String)


4996
4997
4998
# File 'lib/google/apis/datastream_v1/classes.rb', line 4996

def data_type
  @data_type
end

#lengthFixnum

Column length. Corresponds to the JSON property length

Returns:

  • (Fixnum)


5001
5002
5003
# File 'lib/google/apis/datastream_v1/classes.rb', line 5001

def length
  @length
end

#nullableBoolean Also known as: nullable?

Whether or not the column can accept a null value. Corresponds to the JSON property nullable

Returns:

  • (Boolean)


5006
5007
5008
# File 'lib/google/apis/datastream_v1/classes.rb', line 5006

def nullable
  @nullable
end

#ordinal_positionFixnum

The ordinal position of the column in the table. Corresponds to the JSON property ordinalPosition

Returns:

  • (Fixnum)


5012
5013
5014
# File 'lib/google/apis/datastream_v1/classes.rb', line 5012

def ordinal_position
  @ordinal_position
end

#precisionFixnum

Column precision. Corresponds to the JSON property precision

Returns:

  • (Fixnum)


5017
5018
5019
# File 'lib/google/apis/datastream_v1/classes.rb', line 5017

def precision
  @precision
end

#primary_keyBoolean Also known as: primary_key?

Whether or not the column represents a primary key. Corresponds to the JSON property primaryKey

Returns:

  • (Boolean)


5022
5023
5024
# File 'lib/google/apis/datastream_v1/classes.rb', line 5022

def primary_key
  @primary_key
end

#scaleFixnum

Column scale. Corresponds to the JSON property scale

Returns:

  • (Fixnum)


5028
5029
5030
# File 'lib/google/apis/datastream_v1/classes.rb', line 5028

def scale
  @scale
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5035
5036
5037
5038
5039
5040
5041
5042
5043
5044
# File 'lib/google/apis/datastream_v1/classes.rb', line 5035

def update!(**args)
  @column = args[:column] if args.key?(:column)
  @data_type = args[:data_type] if args.key?(:data_type)
  @length = args[:length] if args.key?(:length)
  @nullable = args[:nullable] if args.key?(:nullable)
  @ordinal_position = args[:ordinal_position] if args.key?(:ordinal_position)
  @precision = args[:precision] if args.key?(:precision)
  @primary_key = args[:primary_key] if args.key?(:primary_key)
  @scale = args[:scale] if args.key?(:scale)
end