Class: Google::Apis::DatastreamV1::SqlServerColumn

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

SQLServer Column.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SqlServerColumn

Returns a new instance of SqlServerColumn.



5029
5030
5031
# File 'lib/google/apis/datastream_v1/classes.rb', line 5029

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#columnString

The column name. Corresponds to the JSON property column

Returns:

  • (String)


4990
4991
4992
# File 'lib/google/apis/datastream_v1/classes.rb', line 4990

def column
  @column
end

#data_typeString

The SQLServer data type. Corresponds to the JSON property dataType

Returns:

  • (String)


4995
4996
4997
# File 'lib/google/apis/datastream_v1/classes.rb', line 4995

def data_type
  @data_type
end

#lengthFixnum

Column length. Corresponds to the JSON property length

Returns:

  • (Fixnum)


5000
5001
5002
# File 'lib/google/apis/datastream_v1/classes.rb', line 5000

def length
  @length
end

#nullableBoolean Also known as: nullable?

Whether or not the column can accept a null value. Corresponds to the JSON property nullable

Returns:

  • (Boolean)


5005
5006
5007
# File 'lib/google/apis/datastream_v1/classes.rb', line 5005

def nullable
  @nullable
end

#ordinal_positionFixnum

The ordinal position of the column in the table. Corresponds to the JSON property ordinalPosition

Returns:

  • (Fixnum)


5011
5012
5013
# File 'lib/google/apis/datastream_v1/classes.rb', line 5011

def ordinal_position
  @ordinal_position
end

#precisionFixnum

Column precision. Corresponds to the JSON property precision

Returns:

  • (Fixnum)


5016
5017
5018
# File 'lib/google/apis/datastream_v1/classes.rb', line 5016

def precision
  @precision
end

#primary_keyBoolean Also known as: primary_key?

Whether or not the column represents a primary key. Corresponds to the JSON property primaryKey

Returns:

  • (Boolean)


5021
5022
5023
# File 'lib/google/apis/datastream_v1/classes.rb', line 5021

def primary_key
  @primary_key
end

#scaleFixnum

Column scale. Corresponds to the JSON property scale

Returns:

  • (Fixnum)


5027
5028
5029
# File 'lib/google/apis/datastream_v1/classes.rb', line 5027

def scale
  @scale
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5034
5035
5036
5037
5038
5039
5040
5041
5042
5043
# File 'lib/google/apis/datastream_v1/classes.rb', line 5034

def update!(**args)
  @column = args[:column] if args.key?(:column)
  @data_type = args[:data_type] if args.key?(:data_type)
  @length = args[:length] if args.key?(:length)
  @nullable = args[:nullable] if args.key?(:nullable)
  @ordinal_position = args[:ordinal_position] if args.key?(:ordinal_position)
  @precision = args[:precision] if args.key?(:precision)
  @primary_key = args[:primary_key] if args.key?(:primary_key)
  @scale = args[:scale] if args.key?(:scale)
end