Class: Google::Apis::DatastreamV1::SqlServerColumn
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1::SqlServerColumn
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb
Overview
SQLServer Column.
Instance Attribute Summary collapse
-
#column ⇒ String
The column name.
-
#data_type ⇒ String
The SQLServer data type.
-
#length ⇒ Fixnum
Column length.
-
#nullable ⇒ Boolean
(also: #nullable?)
Whether or not the column can accept a null value.
-
#ordinal_position ⇒ Fixnum
The ordinal position of the column in the table.
-
#precision ⇒ Fixnum
Column precision.
-
#primary_key ⇒ Boolean
(also: #primary_key?)
Whether or not the column represents a primary key.
-
#scale ⇒ Fixnum
Column scale.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SqlServerColumn
constructor
A new instance of SqlServerColumn.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SqlServerColumn
Returns a new instance of SqlServerColumn.
5029 5030 5031 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5029 def initialize(**args) update!(**args) end |
Instance Attribute Details
#column ⇒ String
The column name.
Corresponds to the JSON property column
4990 4991 4992 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4990 def column @column end |
#data_type ⇒ String
The SQLServer data type.
Corresponds to the JSON property dataType
4995 4996 4997 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4995 def data_type @data_type end |
#length ⇒ Fixnum
Column length.
Corresponds to the JSON property length
5000 5001 5002 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5000 def length @length end |
#nullable ⇒ Boolean Also known as: nullable?
Whether or not the column can accept a null value.
Corresponds to the JSON property nullable
5005 5006 5007 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5005 def nullable @nullable end |
#ordinal_position ⇒ Fixnum
The ordinal position of the column in the table.
Corresponds to the JSON property ordinalPosition
5011 5012 5013 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5011 def ordinal_position @ordinal_position end |
#precision ⇒ Fixnum
Column precision.
Corresponds to the JSON property precision
5016 5017 5018 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5016 def precision @precision end |
#primary_key ⇒ Boolean Also known as: primary_key?
Whether or not the column represents a primary key.
Corresponds to the JSON property primaryKey
5021 5022 5023 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5021 def primary_key @primary_key end |
#scale ⇒ Fixnum
Column scale.
Corresponds to the JSON property scale
5027 5028 5029 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5027 def scale @scale end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5034 5035 5036 5037 5038 5039 5040 5041 5042 5043 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5034 def update!(**args) @column = args[:column] if args.key?(:column) @data_type = args[:data_type] if args.key?(:data_type) @length = args[:length] if args.key?(:length) @nullable = args[:nullable] if args.key?(:nullable) @ordinal_position = args[:ordinal_position] if args.key?(:ordinal_position) @precision = args[:precision] if args.key?(:precision) @primary_key = args[:primary_key] if args.key?(:primary_key) @scale = args[:scale] if args.key?(:scale) end |