Class: Google::Apis::DatastreamV1::SqlServerColumn

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

SQLServer Column.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SqlServerColumn

Returns a new instance of SqlServerColumn.



4639
4640
4641
# File 'lib/google/apis/datastream_v1/classes.rb', line 4639

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#columnString

The column name. Corresponds to the JSON property column

Returns:

  • (String)


4600
4601
4602
# File 'lib/google/apis/datastream_v1/classes.rb', line 4600

def column
  @column
end

#data_typeString

The SQLServer data type. Corresponds to the JSON property dataType

Returns:

  • (String)


4605
4606
4607
# File 'lib/google/apis/datastream_v1/classes.rb', line 4605

def data_type
  @data_type
end

#lengthFixnum

Column length. Corresponds to the JSON property length

Returns:

  • (Fixnum)


4610
4611
4612
# File 'lib/google/apis/datastream_v1/classes.rb', line 4610

def length
  @length
end

#nullableBoolean Also known as: nullable?

Whether or not the column can accept a null value. Corresponds to the JSON property nullable

Returns:

  • (Boolean)


4615
4616
4617
# File 'lib/google/apis/datastream_v1/classes.rb', line 4615

def nullable
  @nullable
end

#ordinal_positionFixnum

The ordinal position of the column in the table. Corresponds to the JSON property ordinalPosition

Returns:

  • (Fixnum)


4621
4622
4623
# File 'lib/google/apis/datastream_v1/classes.rb', line 4621

def ordinal_position
  @ordinal_position
end

#precisionFixnum

Column precision. Corresponds to the JSON property precision

Returns:

  • (Fixnum)


4626
4627
4628
# File 'lib/google/apis/datastream_v1/classes.rb', line 4626

def precision
  @precision
end

#primary_keyBoolean Also known as: primary_key?

Whether or not the column represents a primary key. Corresponds to the JSON property primaryKey

Returns:

  • (Boolean)


4631
4632
4633
# File 'lib/google/apis/datastream_v1/classes.rb', line 4631

def primary_key
  @primary_key
end

#scaleFixnum

Column scale. Corresponds to the JSON property scale

Returns:

  • (Fixnum)


4637
4638
4639
# File 'lib/google/apis/datastream_v1/classes.rb', line 4637

def scale
  @scale
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4644
4645
4646
4647
4648
4649
4650
4651
4652
4653
# File 'lib/google/apis/datastream_v1/classes.rb', line 4644

def update!(**args)
  @column = args[:column] if args.key?(:column)
  @data_type = args[:data_type] if args.key?(:data_type)
  @length = args[:length] if args.key?(:length)
  @nullable = args[:nullable] if args.key?(:nullable)
  @ordinal_position = args[:ordinal_position] if args.key?(:ordinal_position)
  @precision = args[:precision] if args.key?(:precision)
  @primary_key = args[:primary_key] if args.key?(:primary_key)
  @scale = args[:scale] if args.key?(:scale)
end