Class: Google::Apis::DatastreamV1::SqlServerColumn
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1::SqlServerColumn
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb
Overview
SQLServer Column.
Instance Attribute Summary collapse
-
#column ⇒ String
The column name.
-
#data_type ⇒ String
The SQLServer data type.
-
#length ⇒ Fixnum
Column length.
-
#nullable ⇒ Boolean
(also: #nullable?)
Whether or not the column can accept a null value.
-
#ordinal_position ⇒ Fixnum
The ordinal position of the column in the table.
-
#precision ⇒ Fixnum
Column precision.
-
#primary_key ⇒ Boolean
(also: #primary_key?)
Whether or not the column represents a primary key.
-
#scale ⇒ Fixnum
Column scale.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SqlServerColumn
constructor
A new instance of SqlServerColumn.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SqlServerColumn
Returns a new instance of SqlServerColumn.
4605 4606 4607 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4605 def initialize(**args) update!(**args) end |
Instance Attribute Details
#column ⇒ String
The column name.
Corresponds to the JSON property column
4566 4567 4568 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4566 def column @column end |
#data_type ⇒ String
The SQLServer data type.
Corresponds to the JSON property dataType
4571 4572 4573 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4571 def data_type @data_type end |
#length ⇒ Fixnum
Column length.
Corresponds to the JSON property length
4576 4577 4578 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4576 def length @length end |
#nullable ⇒ Boolean Also known as: nullable?
Whether or not the column can accept a null value.
Corresponds to the JSON property nullable
4581 4582 4583 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4581 def nullable @nullable end |
#ordinal_position ⇒ Fixnum
The ordinal position of the column in the table.
Corresponds to the JSON property ordinalPosition
4587 4588 4589 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4587 def ordinal_position @ordinal_position end |
#precision ⇒ Fixnum
Column precision.
Corresponds to the JSON property precision
4592 4593 4594 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4592 def precision @precision end |
#primary_key ⇒ Boolean Also known as: primary_key?
Whether or not the column represents a primary key.
Corresponds to the JSON property primaryKey
4597 4598 4599 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4597 def primary_key @primary_key end |
#scale ⇒ Fixnum
Column scale.
Corresponds to the JSON property scale
4603 4604 4605 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4603 def scale @scale end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4610 4611 4612 4613 4614 4615 4616 4617 4618 4619 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4610 def update!(**args) @column = args[:column] if args.key?(:column) @data_type = args[:data_type] if args.key?(:data_type) @length = args[:length] if args.key?(:length) @nullable = args[:nullable] if args.key?(:nullable) @ordinal_position = args[:ordinal_position] if args.key?(:ordinal_position) @precision = args[:precision] if args.key?(:precision) @primary_key = args[:primary_key] if args.key?(:primary_key) @scale = args[:scale] if args.key?(:scale) end |