Class: Google::Apis::DatastreamV1::SqlServerColumn
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1::SqlServerColumn
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb
Overview
SQLServer Column.
Instance Attribute Summary collapse
-
#column ⇒ String
Column name.
-
#data_type ⇒ String
The SQLServer data type.
-
#length ⇒ Fixnum
Column length.
-
#nullable ⇒ Boolean
(also: #nullable?)
Whether or not the column can accept a null value.
-
#ordinal_position ⇒ Fixnum
The ordinal position of the column in the table.
-
#precision ⇒ Fixnum
Column precision.
-
#primary_key ⇒ Boolean
(also: #primary_key?)
Whether or not the column represents a primary key.
-
#scale ⇒ Fixnum
Column scale.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SqlServerColumn
constructor
A new instance of SqlServerColumn.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SqlServerColumn
Returns a new instance of SqlServerColumn.
3842 3843 3844 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3842 def initialize(**args) update!(**args) end |
Instance Attribute Details
#column ⇒ String
Column name.
Corresponds to the JSON property column
3803 3804 3805 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3803 def column @column end |
#data_type ⇒ String
The SQLServer data type.
Corresponds to the JSON property dataType
3808 3809 3810 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3808 def data_type @data_type end |
#length ⇒ Fixnum
Column length.
Corresponds to the JSON property length
3813 3814 3815 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3813 def length @length end |
#nullable ⇒ Boolean Also known as: nullable?
Whether or not the column can accept a null value.
Corresponds to the JSON property nullable
3818 3819 3820 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3818 def nullable @nullable end |
#ordinal_position ⇒ Fixnum
The ordinal position of the column in the table.
Corresponds to the JSON property ordinalPosition
3824 3825 3826 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3824 def ordinal_position @ordinal_position end |
#precision ⇒ Fixnum
Column precision.
Corresponds to the JSON property precision
3829 3830 3831 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3829 def precision @precision end |
#primary_key ⇒ Boolean Also known as: primary_key?
Whether or not the column represents a primary key.
Corresponds to the JSON property primaryKey
3834 3835 3836 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3834 def primary_key @primary_key end |
#scale ⇒ Fixnum
Column scale.
Corresponds to the JSON property scale
3840 3841 3842 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3840 def scale @scale end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3847 3848 3849 3850 3851 3852 3853 3854 3855 3856 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 3847 def update!(**args) @column = args[:column] if args.key?(:column) @data_type = args[:data_type] if args.key?(:data_type) @length = args[:length] if args.key?(:length) @nullable = args[:nullable] if args.key?(:nullable) @ordinal_position = args[:ordinal_position] if args.key?(:ordinal_position) @precision = args[:precision] if args.key?(:precision) @primary_key = args[:primary_key] if args.key?(:primary_key) @scale = args[:scale] if args.key?(:scale) end |