Class: Google::Apis::DatastreamV1::SqlServerSslConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

SQL Server SSL configuration information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SqlServerSslConfig

Returns a new instance of SqlServerSslConfig.



5265
5266
5267
# File 'lib/google/apis/datastream_v1/classes.rb', line 5265

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#basic_encryptionGoogle::Apis::DatastreamV1::BasicEncryption

Message to represent the option where Datastream will enforce encryption without authenticating server identity. Server certificates will be trusted by default. Corresponds to the JSON property basicEncryption



5250
5251
5252
# File 'lib/google/apis/datastream_v1/classes.rb', line 5250

def basic_encryption
  @basic_encryption
end

#encryption_and_server_validationGoogle::Apis::DatastreamV1::EncryptionAndServerValidation

Message to represent the option where Datastream will enforce encryption and authenticate server identity. ca_certificate must be set if user selects this option. Corresponds to the JSON property encryptionAndServerValidation



5257
5258
5259
# File 'lib/google/apis/datastream_v1/classes.rb', line 5257

def encryption_and_server_validation
  @encryption_and_server_validation
end

#encryption_not_enforcedGoogle::Apis::DatastreamV1::EncryptionNotEnforced

Message to represent the option where encryption is not enforced. An empty message right now to allow future extensibility. Corresponds to the JSON property encryptionNotEnforced



5263
5264
5265
# File 'lib/google/apis/datastream_v1/classes.rb', line 5263

def encryption_not_enforced
  @encryption_not_enforced
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5270
5271
5272
5273
5274
# File 'lib/google/apis/datastream_v1/classes.rb', line 5270

def update!(**args)
  @basic_encryption = args[:basic_encryption] if args.key?(:basic_encryption)
  @encryption_and_server_validation = args[:encryption_and_server_validation] if args.key?(:encryption_and_server_validation)
  @encryption_not_enforced = args[:encryption_not_enforced] if args.key?(:encryption_not_enforced)
end