Class: Google::Apis::DatastreamV1::SqlServerSslConfig
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1::SqlServerSslConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb
Overview
SQL Server SSL configuration information.
Instance Attribute Summary collapse
-
#basic_encryption ⇒ Google::Apis::DatastreamV1::BasicEncryption
Message to represent the option where Datastream will enforce encryption without authenticating server identity.
-
#encryption_and_server_validation ⇒ Google::Apis::DatastreamV1::EncryptionAndServerValidation
Message to represent the option where Datastream will enforce encryption and authenticate server identity.
-
#encryption_not_enforced ⇒ Google::Apis::DatastreamV1::EncryptionNotEnforced
Message to represent the option where encryption is not enforced.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SqlServerSslConfig
constructor
A new instance of SqlServerSslConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SqlServerSslConfig
Returns a new instance of SqlServerSslConfig.
4874 4875 4876 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4874 def initialize(**args) update!(**args) end |
Instance Attribute Details
#basic_encryption ⇒ Google::Apis::DatastreamV1::BasicEncryption
Message to represent the option where Datastream will enforce encryption
without authenticating server identity. Server certificates will be trusted by
default.
Corresponds to the JSON property basicEncryption
4859 4860 4861 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4859 def basic_encryption @basic_encryption end |
#encryption_and_server_validation ⇒ Google::Apis::DatastreamV1::EncryptionAndServerValidation
Message to represent the option where Datastream will enforce encryption and
authenticate server identity. ca_certificate must be set if user selects this
option.
Corresponds to the JSON property encryptionAndServerValidation
4866 4867 4868 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4866 def encryption_and_server_validation @encryption_and_server_validation end |
#encryption_not_enforced ⇒ Google::Apis::DatastreamV1::EncryptionNotEnforced
Message to represent the option where encryption is not enforced. An empty
message right now to allow future extensibility.
Corresponds to the JSON property encryptionNotEnforced
4872 4873 4874 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4872 def encryption_not_enforced @encryption_not_enforced end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4879 4880 4881 4882 4883 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4879 def update!(**args) @basic_encryption = args[:basic_encryption] if args.key?(:basic_encryption) @encryption_and_server_validation = args[:encryption_and_server_validation] if args.key?(:encryption_and_server_validation) @encryption_not_enforced = args[:encryption_not_enforced] if args.key?(:encryption_not_enforced) end |