Class: Google::Apis::DatastreamV1::SqlServerSslConfig
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1::SqlServerSslConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb
Overview
SQL Server SSL configuration information.
Instance Attribute Summary collapse
-
#basic_encryption ⇒ Google::Apis::DatastreamV1::BasicEncryption
Message to represent the option where Datastream will enforce encryption without authenticating server identity.
-
#encryption_and_server_validation ⇒ Google::Apis::DatastreamV1::EncryptionAndServerValidation
Message to represent the option where Datastream will enforce encryption and authenticate server identity.
-
#encryption_not_enforced ⇒ Google::Apis::DatastreamV1::EncryptionNotEnforced
Message to represent the option where encryption is not enforced.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SqlServerSslConfig
constructor
A new instance of SqlServerSslConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SqlServerSslConfig
Returns a new instance of SqlServerSslConfig.
4077 4078 4079 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4077 def initialize(**args) update!(**args) end |
Instance Attribute Details
#basic_encryption ⇒ Google::Apis::DatastreamV1::BasicEncryption
Message to represent the option where Datastream will enforce encryption
without authenticating server identity. Server certificates will be trusted by
default.
Corresponds to the JSON property basicEncryption
4062 4063 4064 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4062 def basic_encryption @basic_encryption end |
#encryption_and_server_validation ⇒ Google::Apis::DatastreamV1::EncryptionAndServerValidation
Message to represent the option where Datastream will enforce encryption and
authenticate server identity. ca_certificate must be set if user selects this
option.
Corresponds to the JSON property encryptionAndServerValidation
4069 4070 4071 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4069 def encryption_and_server_validation @encryption_and_server_validation end |
#encryption_not_enforced ⇒ Google::Apis::DatastreamV1::EncryptionNotEnforced
Message to represent the option where encryption is not enforced. An empty
message right now to allow future extensibility.
Corresponds to the JSON property encryptionNotEnforced
4075 4076 4077 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4075 def encryption_not_enforced @encryption_not_enforced end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4082 4083 4084 4085 4086 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4082 def update!(**args) @basic_encryption = args[:basic_encryption] if args.key?(:basic_encryption) @encryption_and_server_validation = args[:encryption_and_server_validation] if args.key?(:encryption_and_server_validation) @encryption_not_enforced = args[:encryption_not_enforced] if args.key?(:encryption_not_enforced) end |