Class: Google::Apis::DatastreamV1::StartBackfillJobRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

Request for manually initiating a backfill job for a specific stream object.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StartBackfillJobRequest

Returns a new instance of StartBackfillJobRequest.



4942
4943
4944
# File 'lib/google/apis/datastream_v1/classes.rb', line 4942

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#event_filterGoogle::Apis::DatastreamV1::EventFilter

Represents a filter for included data on a stream object. Corresponds to the JSON property eventFilter



4940
4941
4942
# File 'lib/google/apis/datastream_v1/classes.rb', line 4940

def event_filter
  @event_filter
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4947
4948
4949
# File 'lib/google/apis/datastream_v1/classes.rb', line 4947

def update!(**args)
  @event_filter = args[:event_filter] if args.key?(:event_filter)
end