Class: Google::Apis::DatastreamV1::StartBackfillJobRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

Request for manually initiating a backfill job for a specific stream object.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StartBackfillJobRequest

Returns a new instance of StartBackfillJobRequest.



4936
4937
4938
# File 'lib/google/apis/datastream_v1/classes.rb', line 4936

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#event_filterGoogle::Apis::DatastreamV1::EventFilter

Represents a filter for included data on a stream object. Corresponds to the JSON property eventFilter



4934
4935
4936
# File 'lib/google/apis/datastream_v1/classes.rb', line 4934

def event_filter
  @event_filter
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4941
4942
4943
# File 'lib/google/apis/datastream_v1/classes.rb', line 4941

def update!(**args)
  @event_filter = args[:event_filter] if args.key?(:event_filter)
end