Class: Google::Apis::DatastreamV1::StartBackfillJobRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

Request for manually initiating a backfill job for a specific stream object.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StartBackfillJobRequest

Returns a new instance of StartBackfillJobRequest.



4173
4174
4175
# File 'lib/google/apis/datastream_v1/classes.rb', line 4173

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#event_filterGoogle::Apis::DatastreamV1::EventFilter

Represents a filter for included data on a stream object. Corresponds to the JSON property eventFilter



4171
4172
4173
# File 'lib/google/apis/datastream_v1/classes.rb', line 4171

def event_filter
  @event_filter
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4178
4179
4180
# File 'lib/google/apis/datastream_v1/classes.rb', line 4178

def update!(**args)
  @event_filter = args[:event_filter] if args.key?(:event_filter)
end