Class: Google::Apis::DatastreamV1::StaticServiceIpConnectivity
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1::StaticServiceIpConnectivity
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb
Overview
Static IP address connectivity. Used when the source database is configured to allow incoming connections from the Datastream public IP addresses for the region specified in the connection profile.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StaticServiceIpConnectivity
constructor
A new instance of StaticServiceIpConnectivity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StaticServiceIpConnectivity
Returns a new instance of StaticServiceIpConnectivity.
4971 4972 4973 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4971 def initialize(**args) update!(**args) end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4976 4977 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 4976 def update!(**args) end |