Class: Google::Apis::DatastreamV1::Stream
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1::Stream
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb
Overview
A resource representing streaming data from a source to a destination.
Instance Attribute Summary collapse
-
#backfill_all ⇒ Google::Apis::DatastreamV1::BackfillAllStrategy
Backfill strategy to automatically backfill the Stream's objects.
-
#backfill_none ⇒ Google::Apis::DatastreamV1::BackfillNoneStrategy
Backfill strategy to disable automatic backfill for the Stream's objects.
-
#create_time ⇒ String
Output only.
-
#customer_managed_encryption_key ⇒ String
Immutable.
-
#destination_config ⇒ Google::Apis::DatastreamV1::DestinationConfig
The configuration of the stream destination.
-
#display_name ⇒ String
Required.
-
#errors ⇒ Array<Google::Apis::DatastreamV1::Error>
Output only.
-
#labels ⇒ Hash<String,String>
Labels.
-
#last_recovery_time ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#rule_sets ⇒ Array<Google::Apis::DatastreamV1::RuleSet>
Optional.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#source_config ⇒ Google::Apis::DatastreamV1::SourceConfig
The configuration of the stream source.
-
#state ⇒ String
The state of the stream.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Stream
constructor
A new instance of Stream.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Stream
Returns a new instance of Stream.
5566 5567 5568 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5566 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backfill_all ⇒ Google::Apis::DatastreamV1::BackfillAllStrategy
Backfill strategy to automatically backfill the Stream's objects. Specific
objects can be excluded.
Corresponds to the JSON property backfillAll
5484 5485 5486 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5484 def backfill_all @backfill_all end |
#backfill_none ⇒ Google::Apis::DatastreamV1::BackfillNoneStrategy
Backfill strategy to disable automatic backfill for the Stream's objects.
Corresponds to the JSON property backfillNone
5489 5490 5491 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5489 def backfill_none @backfill_none end |
#create_time ⇒ String
Output only. The creation time of the stream.
Corresponds to the JSON property createTime
5494 5495 5496 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5494 def create_time @create_time end |
#customer_managed_encryption_key ⇒ String
Immutable. A reference to a KMS encryption key. If provided, it will be used
to encrypt the data. If left blank, data will be encrypted using an internal
Stream-specific encryption key provisioned through KMS.
Corresponds to the JSON property customerManagedEncryptionKey
5501 5502 5503 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5501 def customer_managed_encryption_key @customer_managed_encryption_key end |
#destination_config ⇒ Google::Apis::DatastreamV1::DestinationConfig
The configuration of the stream destination.
Corresponds to the JSON property destinationConfig
5506 5507 5508 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5506 def destination_config @destination_config end |
#display_name ⇒ String
Required. Display name.
Corresponds to the JSON property displayName
5511 5512 5513 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5511 def display_name @display_name end |
#errors ⇒ Array<Google::Apis::DatastreamV1::Error>
Output only. Errors on the Stream.
Corresponds to the JSON property errors
5516 5517 5518 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5516 def errors @errors end |
#labels ⇒ Hash<String,String>
Labels.
Corresponds to the JSON property labels
5521 5522 5523 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5521 def labels @labels end |
#last_recovery_time ⇒ String
Output only. If the stream was recovered, the time of the last recovery. Note:
This field is currently experimental.
Corresponds to the JSON property lastRecoveryTime
5527 5528 5529 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5527 def last_recovery_time @last_recovery_time end |
#name ⇒ String
Output only. Identifier. The stream's name.
Corresponds to the JSON property name
5532 5533 5534 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5532 def name @name end |
#rule_sets ⇒ Array<Google::Apis::DatastreamV1::RuleSet>
Optional. Rule sets to apply to the stream.
Corresponds to the JSON property ruleSets
5537 5538 5539 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5537 def rule_sets @rule_sets end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
5542 5543 5544 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5542 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
5548 5549 5550 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5548 def satisfies_pzs @satisfies_pzs end |
#source_config ⇒ Google::Apis::DatastreamV1::SourceConfig
The configuration of the stream source.
Corresponds to the JSON property sourceConfig
5554 5555 5556 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5554 def source_config @source_config end |
#state ⇒ String
The state of the stream.
Corresponds to the JSON property state
5559 5560 5561 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5559 def state @state end |
#update_time ⇒ String
Output only. The last update time of the stream.
Corresponds to the JSON property updateTime
5564 5565 5566 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5564 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5571 5572 5573 5574 5575 5576 5577 5578 5579 5580 5581 5582 5583 5584 5585 5586 5587 5588 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5571 def update!(**args) @backfill_all = args[:backfill_all] if args.key?(:backfill_all) @backfill_none = args[:backfill_none] if args.key?(:backfill_none) @create_time = args[:create_time] if args.key?(:create_time) @customer_managed_encryption_key = args[:customer_managed_encryption_key] if args.key?(:customer_managed_encryption_key) @destination_config = args[:destination_config] if args.key?(:destination_config) @display_name = args[:display_name] if args.key?(:display_name) @errors = args[:errors] if args.key?(:errors) @labels = args[:labels] if args.key?(:labels) @last_recovery_time = args[:last_recovery_time] if args.key?(:last_recovery_time) @name = args[:name] if args.key?(:name) @rule_sets = args[:rule_sets] if args.key?(:rule_sets) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @source_config = args[:source_config] if args.key?(:source_config) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |