Class: Google::Apis::DatastreamV1::Stream

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

A resource representing streaming data from a source to a destination.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Stream

Returns a new instance of Stream.



5176
5177
5178
# File 'lib/google/apis/datastream_v1/classes.rb', line 5176

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backfill_allGoogle::Apis::DatastreamV1::BackfillAllStrategy

Backfill strategy to automatically backfill the Stream's objects. Specific objects can be excluded. Corresponds to the JSON property backfillAll



5094
5095
5096
# File 'lib/google/apis/datastream_v1/classes.rb', line 5094

def backfill_all
  @backfill_all
end

#backfill_noneGoogle::Apis::DatastreamV1::BackfillNoneStrategy

Backfill strategy to disable automatic backfill for the Stream's objects. Corresponds to the JSON property backfillNone



5099
5100
5101
# File 'lib/google/apis/datastream_v1/classes.rb', line 5099

def backfill_none
  @backfill_none
end

#create_timeString

Output only. The creation time of the stream. Corresponds to the JSON property createTime

Returns:

  • (String)


5104
5105
5106
# File 'lib/google/apis/datastream_v1/classes.rb', line 5104

def create_time
  @create_time
end

#customer_managed_encryption_keyString

Immutable. A reference to a KMS encryption key. If provided, it will be used to encrypt the data. If left blank, data will be encrypted using an internal Stream-specific encryption key provisioned through KMS. Corresponds to the JSON property customerManagedEncryptionKey

Returns:

  • (String)


5111
5112
5113
# File 'lib/google/apis/datastream_v1/classes.rb', line 5111

def customer_managed_encryption_key
  @customer_managed_encryption_key
end

#destination_configGoogle::Apis::DatastreamV1::DestinationConfig

The configuration of the stream destination. Corresponds to the JSON property destinationConfig



5116
5117
5118
# File 'lib/google/apis/datastream_v1/classes.rb', line 5116

def destination_config
  @destination_config
end

#display_nameString

Required. Display name. Corresponds to the JSON property displayName

Returns:

  • (String)


5121
5122
5123
# File 'lib/google/apis/datastream_v1/classes.rb', line 5121

def display_name
  @display_name
end

#errorsArray<Google::Apis::DatastreamV1::Error>

Output only. Errors on the Stream. Corresponds to the JSON property errors



5126
5127
5128
# File 'lib/google/apis/datastream_v1/classes.rb', line 5126

def errors
  @errors
end

#labelsHash<String,String>

Labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


5131
5132
5133
# File 'lib/google/apis/datastream_v1/classes.rb', line 5131

def labels
  @labels
end

#last_recovery_timeString

Output only. If the stream was recovered, the time of the last recovery. Note: This field is currently experimental. Corresponds to the JSON property lastRecoveryTime

Returns:

  • (String)


5137
5138
5139
# File 'lib/google/apis/datastream_v1/classes.rb', line 5137

def last_recovery_time
  @last_recovery_time
end

#nameString

Output only. Identifier. The stream's name. Corresponds to the JSON property name

Returns:

  • (String)


5142
5143
5144
# File 'lib/google/apis/datastream_v1/classes.rb', line 5142

def name
  @name
end

#rule_setsArray<Google::Apis::DatastreamV1::RuleSet>

Optional. Rule sets to apply to the stream. Corresponds to the JSON property ruleSets



5147
5148
5149
# File 'lib/google/apis/datastream_v1/classes.rb', line 5147

def rule_sets
  @rule_sets
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


5152
5153
5154
# File 'lib/google/apis/datastream_v1/classes.rb', line 5152

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


5158
5159
5160
# File 'lib/google/apis/datastream_v1/classes.rb', line 5158

def satisfies_pzs
  @satisfies_pzs
end

#source_configGoogle::Apis::DatastreamV1::SourceConfig

The configuration of the stream source. Corresponds to the JSON property sourceConfig



5164
5165
5166
# File 'lib/google/apis/datastream_v1/classes.rb', line 5164

def source_config
  @source_config
end

#stateString

The state of the stream. Corresponds to the JSON property state

Returns:

  • (String)


5169
5170
5171
# File 'lib/google/apis/datastream_v1/classes.rb', line 5169

def state
  @state
end

#update_timeString

Output only. The last update time of the stream. Corresponds to the JSON property updateTime

Returns:

  • (String)


5174
5175
5176
# File 'lib/google/apis/datastream_v1/classes.rb', line 5174

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5181
5182
5183
5184
5185
5186
5187
5188
5189
5190
5191
5192
5193
5194
5195
5196
5197
5198
# File 'lib/google/apis/datastream_v1/classes.rb', line 5181

def update!(**args)
  @backfill_all = args[:backfill_all] if args.key?(:backfill_all)
  @backfill_none = args[:backfill_none] if args.key?(:backfill_none)
  @create_time = args[:create_time] if args.key?(:create_time)
  @customer_managed_encryption_key = args[:customer_managed_encryption_key] if args.key?(:customer_managed_encryption_key)
  @destination_config = args[:destination_config] if args.key?(:destination_config)
  @display_name = args[:display_name] if args.key?(:display_name)
  @errors = args[:errors] if args.key?(:errors)
  @labels = args[:labels] if args.key?(:labels)
  @last_recovery_time = args[:last_recovery_time] if args.key?(:last_recovery_time)
  @name = args[:name] if args.key?(:name)
  @rule_sets = args[:rule_sets] if args.key?(:rule_sets)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @source_config = args[:source_config] if args.key?(:source_config)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end