Class: Google::Apis::DatastreamV1::Stream

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

A resource representing streaming data from a source to a destination.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Stream

Returns a new instance of Stream.



4379
4380
4381
# File 'lib/google/apis/datastream_v1/classes.rb', line 4379

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backfill_allGoogle::Apis::DatastreamV1::BackfillAllStrategy

Backfill strategy to automatically backfill the Stream's objects. Specific objects can be excluded. Corresponds to the JSON property backfillAll



4297
4298
4299
# File 'lib/google/apis/datastream_v1/classes.rb', line 4297

def backfill_all
  @backfill_all
end

#backfill_noneGoogle::Apis::DatastreamV1::BackfillNoneStrategy

Backfill strategy to disable automatic backfill for the Stream's objects. Corresponds to the JSON property backfillNone



4302
4303
4304
# File 'lib/google/apis/datastream_v1/classes.rb', line 4302

def backfill_none
  @backfill_none
end

#create_timeString

Output only. The creation time of the stream. Corresponds to the JSON property createTime

Returns:

  • (String)


4307
4308
4309
# File 'lib/google/apis/datastream_v1/classes.rb', line 4307

def create_time
  @create_time
end

#customer_managed_encryption_keyString

Immutable. A reference to a KMS encryption key. If provided, it will be used to encrypt the data. If left blank, data will be encrypted using an internal Stream-specific encryption key provisioned through KMS. Corresponds to the JSON property customerManagedEncryptionKey

Returns:

  • (String)


4314
4315
4316
# File 'lib/google/apis/datastream_v1/classes.rb', line 4314

def customer_managed_encryption_key
  @customer_managed_encryption_key
end

#destination_configGoogle::Apis::DatastreamV1::DestinationConfig

The configuration of the stream destination. Corresponds to the JSON property destinationConfig



4319
4320
4321
# File 'lib/google/apis/datastream_v1/classes.rb', line 4319

def destination_config
  @destination_config
end

#display_nameString

Required. Display name. Corresponds to the JSON property displayName

Returns:

  • (String)


4324
4325
4326
# File 'lib/google/apis/datastream_v1/classes.rb', line 4324

def display_name
  @display_name
end

#errorsArray<Google::Apis::DatastreamV1::Error>

Output only. Errors on the Stream. Corresponds to the JSON property errors



4329
4330
4331
# File 'lib/google/apis/datastream_v1/classes.rb', line 4329

def errors
  @errors
end

#labelsHash<String,String>

Labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4334
4335
4336
# File 'lib/google/apis/datastream_v1/classes.rb', line 4334

def labels
  @labels
end

#last_recovery_timeString

Output only. If the stream was recovered, the time of the last recovery. Note: This field is currently experimental. Corresponds to the JSON property lastRecoveryTime

Returns:

  • (String)


4340
4341
4342
# File 'lib/google/apis/datastream_v1/classes.rb', line 4340

def last_recovery_time
  @last_recovery_time
end

#nameString

Output only. Identifier. The stream's name. Corresponds to the JSON property name

Returns:

  • (String)


4345
4346
4347
# File 'lib/google/apis/datastream_v1/classes.rb', line 4345

def name
  @name
end

#rule_setsArray<Google::Apis::DatastreamV1::RuleSet>

Optional. Rule sets to apply to the stream. Corresponds to the JSON property ruleSets



4350
4351
4352
# File 'lib/google/apis/datastream_v1/classes.rb', line 4350

def rule_sets
  @rule_sets
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


4355
4356
4357
# File 'lib/google/apis/datastream_v1/classes.rb', line 4355

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


4361
4362
4363
# File 'lib/google/apis/datastream_v1/classes.rb', line 4361

def satisfies_pzs
  @satisfies_pzs
end

#source_configGoogle::Apis::DatastreamV1::SourceConfig

The configuration of the stream source. Corresponds to the JSON property sourceConfig



4367
4368
4369
# File 'lib/google/apis/datastream_v1/classes.rb', line 4367

def source_config
  @source_config
end

#stateString

The state of the stream. Corresponds to the JSON property state

Returns:

  • (String)


4372
4373
4374
# File 'lib/google/apis/datastream_v1/classes.rb', line 4372

def state
  @state
end

#update_timeString

Output only. The last update time of the stream. Corresponds to the JSON property updateTime

Returns:

  • (String)


4377
4378
4379
# File 'lib/google/apis/datastream_v1/classes.rb', line 4377

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4384
4385
4386
4387
4388
4389
4390
4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
# File 'lib/google/apis/datastream_v1/classes.rb', line 4384

def update!(**args)
  @backfill_all = args[:backfill_all] if args.key?(:backfill_all)
  @backfill_none = args[:backfill_none] if args.key?(:backfill_none)
  @create_time = args[:create_time] if args.key?(:create_time)
  @customer_managed_encryption_key = args[:customer_managed_encryption_key] if args.key?(:customer_managed_encryption_key)
  @destination_config = args[:destination_config] if args.key?(:destination_config)
  @display_name = args[:display_name] if args.key?(:display_name)
  @errors = args[:errors] if args.key?(:errors)
  @labels = args[:labels] if args.key?(:labels)
  @last_recovery_time = args[:last_recovery_time] if args.key?(:last_recovery_time)
  @name = args[:name] if args.key?(:name)
  @rule_sets = args[:rule_sets] if args.key?(:rule_sets)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @source_config = args[:source_config] if args.key?(:source_config)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end