Class: Google::Apis::DatastreamV1::StreamObject
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1::StreamObject
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb
Overview
A specific stream object (e.g a specific DB table).
Instance Attribute Summary collapse
-
#backfill_job ⇒ Google::Apis::DatastreamV1::BackfillJob
Represents a backfill job on a specific stream object.
-
#create_time ⇒ String
Output only.
-
#customization_rules ⇒ Array<Google::Apis::DatastreamV1::CustomizationRule>
Output only.
-
#display_name ⇒ String
Required.
-
#errors ⇒ Array<Google::Apis::DatastreamV1::Error>
Output only.
-
#name ⇒ String
Output only.
-
#source_object ⇒ Google::Apis::DatastreamV1::SourceObjectIdentifier
Represents an identifier of an object in the data source.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StreamObject
constructor
A new instance of StreamObject.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StreamObject
Returns a new instance of StreamObject.
5650 5651 5652 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5650 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backfill_job ⇒ Google::Apis::DatastreamV1::BackfillJob
Represents a backfill job on a specific stream object.
Corresponds to the JSON property backfillJob
5611 5612 5613 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5611 def backfill_job @backfill_job end |
#create_time ⇒ String
Output only. The creation time of the object.
Corresponds to the JSON property createTime
5616 5617 5618 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5616 def create_time @create_time end |
#customization_rules ⇒ Array<Google::Apis::DatastreamV1::CustomizationRule>
Output only. The customization rules for the object. These rules are derived
from the parent Stream's rule_sets and represent the intended configuration
for the object.
Corresponds to the JSON property customizationRules
5623 5624 5625 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5623 def customization_rules @customization_rules end |
#display_name ⇒ String
Required. Display name.
Corresponds to the JSON property displayName
5628 5629 5630 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5628 def display_name @display_name end |
#errors ⇒ Array<Google::Apis::DatastreamV1::Error>
Output only. Active errors on the object.
Corresponds to the JSON property errors
5633 5634 5635 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5633 def errors @errors end |
#name ⇒ String
Output only. Identifier. The object resource's name.
Corresponds to the JSON property name
5638 5639 5640 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5638 def name @name end |
#source_object ⇒ Google::Apis::DatastreamV1::SourceObjectIdentifier
Represents an identifier of an object in the data source.
Corresponds to the JSON property sourceObject
5643 5644 5645 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5643 def source_object @source_object end |
#update_time ⇒ String
Output only. The last update time of the object.
Corresponds to the JSON property updateTime
5648 5649 5650 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5648 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5655 5656 5657 5658 5659 5660 5661 5662 5663 5664 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5655 def update!(**args) @backfill_job = args[:backfill_job] if args.key?(:backfill_job) @create_time = args[:create_time] if args.key?(:create_time) @customization_rules = args[:customization_rules] if args.key?(:customization_rules) @display_name = args[:display_name] if args.key?(:display_name) @errors = args[:errors] if args.key?(:errors) @name = args[:name] if args.key?(:name) @source_object = args[:source_object] if args.key?(:source_object) @update_time = args[:update_time] if args.key?(:update_time) end |