Class: Google::Apis::DatastreamV1::StreamObject
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1::StreamObject
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb
Overview
A specific stream object (e.g a specific DB table).
Instance Attribute Summary collapse
-
#backfill_job ⇒ Google::Apis::DatastreamV1::BackfillJob
Represents a backfill job on a specific stream object.
-
#create_time ⇒ String
Output only.
-
#customization_rules ⇒ Array<Google::Apis::DatastreamV1::CustomizationRule>
Output only.
-
#display_name ⇒ String
Required.
-
#errors ⇒ Array<Google::Apis::DatastreamV1::Error>
Output only.
-
#name ⇒ String
Output only.
-
#source_object ⇒ Google::Apis::DatastreamV1::SourceObjectIdentifier
Represents an identifier of an object in the data source.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StreamObject
constructor
A new instance of StreamObject.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StreamObject
Returns a new instance of StreamObject.
5260 5261 5262 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5260 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backfill_job ⇒ Google::Apis::DatastreamV1::BackfillJob
Represents a backfill job on a specific stream object.
Corresponds to the JSON property backfillJob
5221 5222 5223 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5221 def backfill_job @backfill_job end |
#create_time ⇒ String
Output only. The creation time of the object.
Corresponds to the JSON property createTime
5226 5227 5228 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5226 def create_time @create_time end |
#customization_rules ⇒ Array<Google::Apis::DatastreamV1::CustomizationRule>
Output only. The customization rules for the object. These rules are derived
from the parent Stream's rule_sets and represent the intended configuration
for the object.
Corresponds to the JSON property customizationRules
5233 5234 5235 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5233 def customization_rules @customization_rules end |
#display_name ⇒ String
Required. Display name.
Corresponds to the JSON property displayName
5238 5239 5240 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5238 def display_name @display_name end |
#errors ⇒ Array<Google::Apis::DatastreamV1::Error>
Output only. Active errors on the object.
Corresponds to the JSON property errors
5243 5244 5245 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5243 def errors @errors end |
#name ⇒ String
Output only. Identifier. The object resource's name.
Corresponds to the JSON property name
5248 5249 5250 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5248 def name @name end |
#source_object ⇒ Google::Apis::DatastreamV1::SourceObjectIdentifier
Represents an identifier of an object in the data source.
Corresponds to the JSON property sourceObject
5253 5254 5255 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5253 def source_object @source_object end |
#update_time ⇒ String
Output only. The last update time of the object.
Corresponds to the JSON property updateTime
5258 5259 5260 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5258 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5265 5266 5267 5268 5269 5270 5271 5272 5273 5274 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5265 def update!(**args) @backfill_job = args[:backfill_job] if args.key?(:backfill_job) @create_time = args[:create_time] if args.key?(:create_time) @customization_rules = args[:customization_rules] if args.key?(:customization_rules) @display_name = args[:display_name] if args.key?(:display_name) @errors = args[:errors] if args.key?(:errors) @name = args[:name] if args.key?(:name) @source_object = args[:source_object] if args.key?(:source_object) @update_time = args[:update_time] if args.key?(:update_time) end |