Class: Google::Apis::DatastreamV1::StreamObject

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

A specific stream object (e.g a specific DB table).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StreamObject

Returns a new instance of StreamObject.



4463
4464
4465
# File 'lib/google/apis/datastream_v1/classes.rb', line 4463

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backfill_jobGoogle::Apis::DatastreamV1::BackfillJob

Represents a backfill job on a specific stream object. Corresponds to the JSON property backfillJob



4424
4425
4426
# File 'lib/google/apis/datastream_v1/classes.rb', line 4424

def backfill_job
  @backfill_job
end

#create_timeString

Output only. The creation time of the object. Corresponds to the JSON property createTime

Returns:

  • (String)


4429
4430
4431
# File 'lib/google/apis/datastream_v1/classes.rb', line 4429

def create_time
  @create_time
end

#customization_rulesArray<Google::Apis::DatastreamV1::CustomizationRule>

Output only. The customization rules for the object. These rules are derived from the parent Stream's rule_sets and represent the intended configuration for the object. Corresponds to the JSON property customizationRules



4436
4437
4438
# File 'lib/google/apis/datastream_v1/classes.rb', line 4436

def customization_rules
  @customization_rules
end

#display_nameString

Required. Display name. Corresponds to the JSON property displayName

Returns:

  • (String)


4441
4442
4443
# File 'lib/google/apis/datastream_v1/classes.rb', line 4441

def display_name
  @display_name
end

#errorsArray<Google::Apis::DatastreamV1::Error>

Output only. Active errors on the object. Corresponds to the JSON property errors



4446
4447
4448
# File 'lib/google/apis/datastream_v1/classes.rb', line 4446

def errors
  @errors
end

#nameString

Output only. Identifier. The object resource's name. Corresponds to the JSON property name

Returns:

  • (String)


4451
4452
4453
# File 'lib/google/apis/datastream_v1/classes.rb', line 4451

def name
  @name
end

#source_objectGoogle::Apis::DatastreamV1::SourceObjectIdentifier

Represents an identifier of an object in the data source. Corresponds to the JSON property sourceObject



4456
4457
4458
# File 'lib/google/apis/datastream_v1/classes.rb', line 4456

def source_object
  @source_object
end

#update_timeString

Output only. The last update time of the object. Corresponds to the JSON property updateTime

Returns:

  • (String)


4461
4462
4463
# File 'lib/google/apis/datastream_v1/classes.rb', line 4461

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4468
4469
4470
4471
4472
4473
4474
4475
4476
4477
# File 'lib/google/apis/datastream_v1/classes.rb', line 4468

def update!(**args)
  @backfill_job = args[:backfill_job] if args.key?(:backfill_job)
  @create_time = args[:create_time] if args.key?(:create_time)
  @customization_rules = args[:customization_rules] if args.key?(:customization_rules)
  @display_name = args[:display_name] if args.key?(:display_name)
  @errors = args[:errors] if args.key?(:errors)
  @name = args[:name] if args.key?(:name)
  @source_object = args[:source_object] if args.key?(:source_object)
  @update_time = args[:update_time] if args.key?(:update_time)
end