Class: Google::Apis::DatastreamV1::UserCredentials

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

Deprecated: Salesforce is retiring Username-Password authentication. Use Oauth2ClientCredentials instead.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserCredentials

Returns a new instance of UserCredentials.



5729
5730
5731
# File 'lib/google/apis/datastream_v1/classes.rb', line 5729

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#passwordString

Optional. Password for the Salesforce connection. Mutually exclusive with the secret_manager_stored_password field. Corresponds to the JSON property password

Returns:

  • (String)


5703
5704
5705
# File 'lib/google/apis/datastream_v1/classes.rb', line 5703

def password
  @password
end

#secret_manager_stored_passwordString

Optional. A reference to a Secret Manager resource name storing the Salesforce connection's password. Mutually exclusive with the password field. Corresponds to the JSON property secretManagerStoredPassword

Returns:

  • (String)


5709
5710
5711
# File 'lib/google/apis/datastream_v1/classes.rb', line 5709

def secret_manager_stored_password
  @secret_manager_stored_password
end

#secret_manager_stored_security_tokenString

Optional. A reference to a Secret Manager resource name storing the Salesforce connection's security token. Mutually exclusive with the security_token field. Corresponds to the JSON property secretManagerStoredSecurityToken

Returns:

  • (String)


5716
5717
5718
# File 'lib/google/apis/datastream_v1/classes.rb', line 5716

def secret_manager_stored_security_token
  @secret_manager_stored_security_token
end

#security_tokenString

Optional. Security token for the Salesforce connection. Mutually exclusive with the secret_manager_stored_security_token field. Corresponds to the JSON property securityToken

Returns:

  • (String)


5722
5723
5724
# File 'lib/google/apis/datastream_v1/classes.rb', line 5722

def security_token
  @security_token
end

#usernameString

Required. Username for the Salesforce connection. Corresponds to the JSON property username

Returns:

  • (String)


5727
5728
5729
# File 'lib/google/apis/datastream_v1/classes.rb', line 5727

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5734
5735
5736
5737
5738
5739
5740
# File 'lib/google/apis/datastream_v1/classes.rb', line 5734

def update!(**args)
  @password = args[:password] if args.key?(:password)
  @secret_manager_stored_password = args[:secret_manager_stored_password] if args.key?(:secret_manager_stored_password)
  @secret_manager_stored_security_token = args[:secret_manager_stored_security_token] if args.key?(:secret_manager_stored_security_token)
  @security_token = args[:security_token] if args.key?(:security_token)
  @username = args[:username] if args.key?(:username)
end