Class: Google::Apis::DatastreamV1::UserCredentials

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb

Overview

Username-password credentials.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserCredentials

Returns a new instance of UserCredentials.



5303
5304
5305
# File 'lib/google/apis/datastream_v1/classes.rb', line 5303

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#passwordString

Optional. Password for the Salesforce connection. Mutually exclusive with the secret_manager_stored_password field. Corresponds to the JSON property password

Returns:

  • (String)


5277
5278
5279
# File 'lib/google/apis/datastream_v1/classes.rb', line 5277

def password
  @password
end

#secret_manager_stored_passwordString

Optional. A reference to a Secret Manager resource name storing the Salesforce connection's password. Mutually exclusive with the password field. Corresponds to the JSON property secretManagerStoredPassword

Returns:

  • (String)


5283
5284
5285
# File 'lib/google/apis/datastream_v1/classes.rb', line 5283

def secret_manager_stored_password
  @secret_manager_stored_password
end

#secret_manager_stored_security_tokenString

Optional. A reference to a Secret Manager resource name storing the Salesforce connection's security token. Mutually exclusive with the security_token field. Corresponds to the JSON property secretManagerStoredSecurityToken

Returns:

  • (String)


5290
5291
5292
# File 'lib/google/apis/datastream_v1/classes.rb', line 5290

def secret_manager_stored_security_token
  @secret_manager_stored_security_token
end

#security_tokenString

Optional. Security token for the Salesforce connection. Mutually exclusive with the secret_manager_stored_security_token field. Corresponds to the JSON property securityToken

Returns:

  • (String)


5296
5297
5298
# File 'lib/google/apis/datastream_v1/classes.rb', line 5296

def security_token
  @security_token
end

#usernameString

Required. Username for the Salesforce connection. Corresponds to the JSON property username

Returns:

  • (String)


5301
5302
5303
# File 'lib/google/apis/datastream_v1/classes.rb', line 5301

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5308
5309
5310
5311
5312
5313
5314
# File 'lib/google/apis/datastream_v1/classes.rb', line 5308

def update!(**args)
  @password = args[:password] if args.key?(:password)
  @secret_manager_stored_password = args[:secret_manager_stored_password] if args.key?(:secret_manager_stored_password)
  @secret_manager_stored_security_token = args[:secret_manager_stored_security_token] if args.key?(:secret_manager_stored_security_token)
  @security_token = args[:security_token] if args.key?(:security_token)
  @username = args[:username] if args.key?(:username)
end