Class: Google::Apis::DatastreamV1::UserCredentials
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1::UserCredentials
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb
Overview
Username-password credentials.
Instance Attribute Summary collapse
-
#password ⇒ String
Optional.
-
#secret_manager_stored_password ⇒ String
Optional.
-
#secret_manager_stored_security_token ⇒ String
Optional.
-
#security_token ⇒ String
Optional.
-
#username ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserCredentials
constructor
A new instance of UserCredentials.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserCredentials
Returns a new instance of UserCredentials.
5303 5304 5305 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5303 def initialize(**args) update!(**args) end |
Instance Attribute Details
#password ⇒ String
Optional. Password for the Salesforce connection. Mutually exclusive with the
secret_manager_stored_password field.
Corresponds to the JSON property password
5277 5278 5279 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5277 def password @password end |
#secret_manager_stored_password ⇒ String
Optional. A reference to a Secret Manager resource name storing the Salesforce
connection's password. Mutually exclusive with the password field.
Corresponds to the JSON property secretManagerStoredPassword
5283 5284 5285 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5283 def secret_manager_stored_password @secret_manager_stored_password end |
#secret_manager_stored_security_token ⇒ String
Optional. A reference to a Secret Manager resource name storing the Salesforce
connection's security token. Mutually exclusive with the security_token
field.
Corresponds to the JSON property secretManagerStoredSecurityToken
5290 5291 5292 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5290 def secret_manager_stored_security_token @secret_manager_stored_security_token end |
#security_token ⇒ String
Optional. Security token for the Salesforce connection. Mutually exclusive
with the secret_manager_stored_security_token field.
Corresponds to the JSON property securityToken
5296 5297 5298 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5296 def security_token @security_token end |
#username ⇒ String
Required. Username for the Salesforce connection.
Corresponds to the JSON property username
5301 5302 5303 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5301 def username @username end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5308 5309 5310 5311 5312 5313 5314 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5308 def update!(**args) @password = args[:password] if args.key?(:password) @secret_manager_stored_password = args[:secret_manager_stored_password] if args.key?(:secret_manager_stored_password) @secret_manager_stored_security_token = args[:secret_manager_stored_security_token] if args.key?(:secret_manager_stored_security_token) @security_token = args[:security_token] if args.key?(:security_token) @username = args[:username] if args.key?(:username) end |