Class: Google::Apis::DatastreamV1::UserPasswordCredentials
- Inherits:
-
Object
- Object
- Google::Apis::DatastreamV1::UserPasswordCredentials
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastream_v1/classes.rb,
lib/google/apis/datastream_v1/representations.rb,
lib/google/apis/datastream_v1/representations.rb
Overview
User-password credentials.
Instance Attribute Summary collapse
-
#password ⇒ Google::Apis::DatastreamV1::Secret
A confidential piece of information where the actual value is either directly specified in the message as a raw string or stored in GCP secret manager.
-
#username ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserPasswordCredentials
constructor
A new instance of UserPasswordCredentials.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserPasswordCredentials
Returns a new instance of UserPasswordCredentials.
5756 5757 5758 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5756 def initialize(**args) update!(**args) end |
Instance Attribute Details
#password ⇒ Google::Apis::DatastreamV1::Secret
A confidential piece of information where the actual value is either directly
specified in the message as a raw string or stored in GCP secret manager.
Corresponds to the JSON property password
5749 5750 5751 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5749 def password @password end |
#username ⇒ String
Required. Username for the connection.
Corresponds to the JSON property username
5754 5755 5756 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5754 def username @username end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5761 5762 5763 5764 |
# File 'lib/google/apis/datastream_v1/classes.rb', line 5761 def update!(**args) @password = args[:password] if args.key?(:password) @username = args[:username] if args.key?(:username) end |